@@ -12,8 +12,8 @@ COMPILE_CFG="FIXME"
 COMPILE_DATE=`date`
 COMPILE_USER=`whoami`
 COMPILE_HOST=`hostname`
-COMPILER=`$CXX -v 2>&1 | grep version`
-CFLAGS="$AM_CPPFLAGS $AM_CXXFLAGS"
+COMPILER=`$CXX -v 2>&1 | tail -n 1 | tr -d \'\"`
+CFLAGS="$AM_CPPFLAGS $AM_CXXFLAGS $CXXFLAGS"
 LDFLAGS="$LDADD"
 
 sed -e "s!%%COMMENT%%!${COMMENT}!g; s!%%COMPILE_CFG%%!${COMPILE_CFG}!g;\
