@@ -39,8 +39,9 @@
 #include "misc.h"
 //#include "modeIO.h"
 #include "configuration.h"
+#include "status.h"
 
-void cw::tx_init(cSound *sc)
+void cw::tx_init(SoundBase *sc)
 {
 	scard = sc;
 	phaseacc = 0;
@@ -89,10 +90,10 @@ cw::cw() : modem()
 
 	mode = MODE_CW;
 	freqlock = false;
+	usedefaultWPM = false;
 	frequency = progdefaults.CWsweetspot;
 	tx_frequency = get_txfreq_woffset();
 	risetime = progdefaults.CWrisetime;
-//	keyshape = new double[KNUM];
 	
 	samplerate = CWSampleRate;
 	fragmentsize = CWMaxSymLen;
@@ -233,11 +234,11 @@ void cw::update_Status()
 {
 	static char RXmsg[20];
 	static char TXmsg[20];
-	sprintf(RXmsg,"Rx %d", cw_receive_speed);
+	snprintf(RXmsg, sizeof(RXmsg), "Rx %d", cw_receive_speed);
 	if (usedefaultWPM)
-		sprintf(TXmsg,"Tx %d **", progdefaults.defCWspeed);
+		snprintf(TXmsg, sizeof(TXmsg), "Tx %d **", progdefaults.defCWspeed);
 	else
-		sprintf(TXmsg,"Tx %d", progdefaults.CWspeed);
+		snprintf(TXmsg, sizeof(TXmsg), "Tx %d", progdefaults.CWspeed);
 	put_Status1(RXmsg);
 	put_Status2(TXmsg);	
 }
@@ -317,7 +318,7 @@ int cw::rx_process(const double *buf, int len)
 			if (pipeptr == pipesize - 1)
 				update_syncscope();
 
-			if (!squelchon || metric > squelch ) {
+			if (!progStatus.sqlonoff || metric > progStatus.sldrSquelchValue ) {
 // upward trend means tone starting 
 				if ((value > 0.66 * agc_peak) && (cw_receive_state != RS_IN_TONE))
 					handle_event(CW_KEYDOWN_EVENT, NULL);
@@ -712,7 +713,7 @@ void cw::send_ch(int ch)
         FL_AWAKE();
 	}
 
-	if (ch != 0)
+	if (ch != -1)
 		put_echo_char(ch);
 }
 
