@@ -26,6 +26,8 @@
  *
  */
 
+#include <config.h>
+
 #include "morse.h"
 
 /* ---------------------------------------------------------------------- */
@@ -84,7 +86,7 @@ static CW_TABLE cw_table[] = {
 	{"'",		".----.",	CW_ENTRY_NORMAL},
 	{"$",		"...-..-",	CW_ENTRY_NORMAL},
 //	{"(",		"-.--.",	CW_ENTRY_NORMAL},
-	{")",		"-.--.-",	CW_ENTRY_NORMAL},
+//	{")",		"-.--.-",	CW_ENTRY_NORMAL},
 //	{"+",		".-.-.",	CW_ENTRY_NORMAL},
 	{",",		"--..--",	CW_ENTRY_NORMAL},
 	{"-",		"-....-",	CW_ENTRY_NORMAL},
@@ -139,10 +141,10 @@ static CW_TABLE cw_table[] = {
  * is viewable as an integer in the range 2 (".") to 255 ("-------"), and can
  * be used as an index into a fast lookup array.
  */
-unsigned int morse::tokenize_representation(char *representation)
+unsigned int morse::tokenize_representation(const char *representation)
 {
 	unsigned int token;	/* Return token value */
-	char *sptr;	/* Pointer through string */
+	const char *sptr;	/* Pointer through string */
 
 	/*
 	 * Our algorithm can handle only 6 characters of representation.
@@ -182,7 +184,7 @@ bool morse::init()
 {
 	CW_TABLE *cw;	/* Pointer to table entry */
 	unsigned int i;
-	char *p;
+	const char *p;
 	long code;
 	int len;
 
@@ -206,7 +208,7 @@ bool morse::init()
 		if (cw->type == CW_ENTRY_EXTENDED)
 			continue;
 		len = strlen(cw->rpr);
-		code = 4;
+		code = 0x04;
 		while (len-- > 0) {
 			if (cw->rpr[len] == CW_DASH_REPRESENTATION) {
 				code = (code << 1) | 1;
@@ -222,7 +224,7 @@ bool morse::init()
 	return true;
 }
 
-char *morse::rx_lookup(char *r)
+const char *morse::rx_lookup(char *r)
 {
 	static char chr[2];	/* FIXME */
 	int			token;
