@@ -28,8 +28,9 @@
 
 #include "rtty.h"
 #include "waterfall.h"
-#include "Config.h"
+#include "confdialog.h"
 #include "configuration.h"
+#include "status.h"
 
 //static char rttymsg[80];
 static char msg1[20];
@@ -39,7 +40,7 @@ double _SHIFT[] = {23, 85, 160, 170, 182, 200, 240, 350, 425, 850};
 double _BAUD[] = {45, 45.45, 50, 56, 75, 100, 110, 150, 200, 300};
 int    _BITS[] = {5, 7, 8};
 
-void rtty::tx_init(cSound *sc)
+void rtty::tx_init(SoundBase *sc)
 {
 // start each new transmission 20 bit lengths MARK tone
 	scard = sc;
@@ -66,9 +67,9 @@ void rtty::init()
 	modem::init();
 	rx_init();
 	put_MODEstatus(mode);
-	sprintf(msg1,"Shft %-4.0f", rtty_shift); 
+	snprintf(msg1, sizeof(msg1), "Shft %-4.0f", rtty_shift); 
 	put_Status1(msg1);
-	sprintf(msg2,"Baud %-4.1f", rtty_baud); 
+	snprintf(msg2, sizeof(msg2), "Baud %-4.1f", rtty_baud); 
 	put_Status2(msg2);
 	if (progdefaults.PreferXhairScope)
 		digiscope->mode(Digiscope::XHAIRS);
@@ -137,9 +138,9 @@ void rtty::restart()
 	
 	metric = 0.0;
 
-	sprintf(msg1,"Shft %-4.0f", rtty_shift); 
+	snprintf(msg1, sizeof(msg1), "Shft %-4.0f", rtty_shift); 
 	put_Status1(msg1);
-	sprintf(msg2,"Baud %-4.1f", rtty_baud); 
+	snprintf(msg2, sizeof(msg2), "Baud %-4.1f", rtty_baud); 
 	put_Status2(msg2);
 	put_MODEstatus(mode);
 }
@@ -156,7 +157,6 @@ rtty::rtty(trx_mode tty_mode)
 	
 	hilbert = new C_FIR_filter();
 	hilbert->init_hilbert(37, 1);
-//	wfid = new id(this);
 
 	restart();
 }
@@ -310,7 +310,7 @@ int rtty::rx(bool bit)
 	case RTTY_RX_STATE_STOP:
 		if (--counter == 0) {
 			if (bit) {
-				if ((metric >= squelch && squelchon)|| !squelchon) {				
+				if ((metric >= progStatus.sldrSquelchValue && progStatus.sqlonoff)|| !progStatus.sqlonoff) {				
 					c = decode_char();
 					if ( c != 0 )
 						put_rx_char(c);
@@ -449,7 +449,7 @@ int rtty::rx_process(const double *buf, int len)
 			rxflag = rx (reverse ? bit : !bit);
 
 			if (rxflag == 2 || dspcnt == 0) {
-				if ((metric > squelch && squelchon) || !squelchon) {
+				if ((metric > progStatus.sldrSquelchValue && progStatus.sqlonoff) || !progStatus.sqlonoff) {
 					set_scope(pipe, symbollen, false);
 					pipe.next(); // change buffers
 				}
@@ -483,8 +483,8 @@ int rtty::rx_process(const double *buf, int len)
 				poscnt = 0; posfreq = 0.0;
 				negcnt = 0; negfreq = 0.0;
 
-				if (afcon) {
-					if (metric > squelch || !squelchon || sigsearch) {
+				if (progStatus.afconoff) {
+					if (metric > progStatus.sldrSquelchValue || !progStatus.sqlonoff || sigsearch) {
 						set_freq(frequency + freqerr);
 					}
 				}
