@@ -4,6 +4,8 @@
 // Copyright (C) 2006
 //		Dave Freese, W1HKJ
 //
+// This modem code owes much to the efforts of Joe Veldhius, N8FQ
+//
 // This file is part of fldigi.  Adapted from code contained in gmfsk source code 
 // distribution.
 //  gmfsk Copyright (C) 2001, 2002, 2003
@@ -34,17 +36,16 @@
 
 #include "feld.h"
 #include "fontdef.h"
-#include "Config.h"
+#include "confdialog.h"
 #include "qrunner.h"
+#include "status.h"
 
-#undef  MAX
-#define MAX(a,b)		(((a)>(b))?(a):(b))
-#undef  CLAMP
-#define CLAMP(x,low,high)       (((x)>(high))?(high):(((x)<(low))?(low):(x)))
+#include <FL/Fl.H>
+#include <FL/Fl_Value_Slider.H>
 
 char feldmsg[80];
 
-void feld::tx_init(cSound *sc)
+void feld::tx_init(SoundBase *sc)
 {
 	scard = sc;
 	txcounter = 0.0;
@@ -81,39 +82,59 @@ feld::~feld()
 	if (hilbert) delete hilbert;
 	if (bpfilt) delete bpfilt;
 	if (bbfilt) delete bbfilt;
-//	if (wfid) delete wfid;
 }
 
 feld::feld(trx_mode m)
 {
 	double lp;
-	double flo, fhi;
 	mode = m;
 	samplerate = FeldSampleRate;
-	FL_LOCK_D();
-	bandwidth = sldrHellBW->value();
-	FL_UNLOCK_D();
 	
-	switch (mode) { 
-		case MODE_FSKHELL: bandwidth = 122.5; break; 
-		case MODE_FSKH105: bandwidth = 55; break; 
-		default :
+ 	switch (mode) {
+// Amplitude modulation modes
+		case MODE_FELDHELL:
+ 			feldcolumnrate = 17.5;
+ 			break; 
+		case MODE_SLOWHELL: 
+			feldcolumnrate = 2.1875; 
+			break;
+		case MODE_HELLX5: 
+			feldcolumnrate = 87.5; 
+			break;
+		case MODE_HELLX9: 
+			feldcolumnrate = 157.5; 
+			break;
+// Frequency modulation modes
+		case MODE_FSKHELL: 
+			feldcolumnrate = 17.5; 
 			break; 
-	}
-	hell_bandwidth = bandwidth;
+		case MODE_FSKH105: 
+			feldcolumnrate = 17.5; 
+			break; 
+		case MODE_HELL80: 
+			feldcolumnrate = 35; 
+			break;
+ 		default :
+ 			feldcolumnrate = 17.5;
+ 			break; 
+ 	}
+
+	rxpixrate = (RxColumnLen * feldcolumnrate);
+	txpixrate = (TxColumnLen * feldcolumnrate);
+	downsampleinc = (double)(rxpixrate/samplerate);
+	upsampleinc = (double)(txpixrate/samplerate);
+	phi2freq = samplerate / txpixrate / 2.0 / M_PI;
+	
+	hell_bandwidth = txpixrate;
+
+	set_bandwidth(hell_bandwidth);
 	
 	hilbert = new C_FIR_filter();
 	hilbert->init_hilbert(37, 1);
 
-	lp = 1.5 * bandwidth / 2.0 / samplerate;
+	lp = 1.5 * bandwidth / samplerate;
 	
-	fhi = (bandwidth / 2 + TxPixRate * 1.5) / samplerate;
-	flo = (bandwidth / 2 - TxPixRate * 1.5) / samplerate;
-	
-	if (mode == MODE_FSKHELL || mode == MODE_FSKH105)
-		bpfilt = new fftfilt (flo, fhi, 1024);
-	else
-		bpfilt = new fftfilt(0, lp, 1024);
+	bpfilt = new fftfilt(0, lp, 1024);
 	
 	bbfilt = new Cmovavg(8);
 	
@@ -121,7 +142,6 @@ feld::feld(trx_mode m)
 	
 	blackboard = false;
 	hardkeying = false;
-//	wfid = new id(this);
 
 	rxphacc = 0.0;
 	txphacc = 0.0;
@@ -153,42 +173,36 @@ complex feld::mixer(complex in)
 
 void feld::FSKHELL_rx(complex z)
 {
-	double f;//, x;
+	double f;
 	int vid;
-	
-	f = (prev % z).arg() * samplerate / M_PI / bandwidth / 2.0;
+
+	f = (prev % z).arg() * phi2freq;
 	prev = z;
 	
 	f = bbfilt->run(f);
 
-	rxcounter += DownSampleInc;
+	rxcounter += downsampleinc;
 	if (rxcounter < 1.0)
 		return;
 
 	rxcounter -= 1.0;
-
-	f += 0.5;
-
-	if (reverse)
-		vid = (int)(255 * CLAMP(1.0 - f, 0.0, 1.0));
-	else
-		vid = (int)(255 * CLAMP(f, 0.0, 1.0));
-
-	if (blackboard)
-		vid = 255 - vid;
-
-//	x = z.mag();
-//	if (x > peakhold)
-//		peakhold = x;
-//	else
-//		peakhold *= (1 - 0.02 / RxColumnLen);
 	
+	f = CLAMP(f + 0.5, 0.0, 1.0);
+	if (mode == MODE_HELL80)
+		f = 1.0 - f;
+	
+	if (reverse)
+		f = 1.0 - f;
+	if (blackboard)
+		f = 1.0 - f;
+	vid = (int)(255 * f);
+
 	col_data[col_pointer + RxColumnLen] = vid;
 	col_pointer++;
 	if (col_pointer == RxColumnLen) {
-		QUEUE(CMP_CB(put_rx_data, col_data, col_data.size())); //put_rx_data(col_data, 2*RxColumnLen);
+		REQ(put_rx_data, col_data, col_data.size());
 		if (!halfwidth)
-			QUEUE(CMP_CB(put_rx_data, col_data, col_data.size())); //put_rx_data(col_data, 2*RxColumnLen);
+			REQ(put_rx_data, col_data, col_data.size());
 		col_pointer = 0;
 		for (int i = 0; i < RxColumnLen; i++)
 			col_data[i] = col_data[i + RxColumnLen];
@@ -202,7 +216,7 @@ void feld::rx(complex z)
 
 	x = bbfilt->run(z.mag());
 	
-	rxcounter += DownSampleInc;
+	rxcounter += downsampleinc;
 	if (rxcounter < 1.0)
 		return;
 
@@ -219,8 +233,6 @@ void feld::rx(complex z)
 	
 	x = CLAMP (x / peakhold, 0.0, 1.0);
 
-//	agc = decayavg(agc, peakhold - minhold, 40);
-	
 	agc = minmaxfilt->run(peakhold - minhold);
 	
 	metric = CLAMP(100*agc, 0.0, 100.0); 
@@ -234,10 +246,10 @@ void feld::rx(complex z)
 	col_data[col_pointer + RxColumnLen] = (int)x;
 	col_pointer++;
 	if (col_pointer == RxColumnLen) {
-		if (metric > squelch || squelchon == false) {
-			QUEUE(CMP_CB(put_rx_data, col_data, col_data.size())); //put_rx_data(col_data, 2*RxColumnLen);
+		if (metric > progStatus.sldrSquelchValue || progStatus.sqlonoff == false) {
+			REQ(put_rx_data, col_data, col_data.size());
 			if (!halfwidth)
-				QUEUE(CMP_CB(put_rx_data, col_data, col_data.size())); //put_rx_data(col_data, 2*RxColumnLen);
+				REQ(put_rx_data, col_data, col_data.size());
 		}
 		col_pointer = 0;
 		for (int i = 0; i < RxColumnLen; i++)
@@ -254,23 +266,24 @@ int feld::rx_process(const double *buf, int len)
 	FL_LOCK_D();
 	halfwidth = btnHellRcvWidth->value();
 	blackboard = btnBlackboard->value();
-	squelch = progdefaults.sldrSquelchValue;
-	squelchon = progdefaults.sqlonoff;
+//	squelch = progdefaults.sldrSquelchValue;
+//	squelchon = progdefaults.sqlonoff;
 	FL_UNLOCK_D();
 	
-	switch (mode) {
-		default:
+//	switch (mode) {
+//		default:
 			if (bandwidth != hell_bandwidth) {
 				double lp;
 				hell_bandwidth = bandwidth;
 				lp = 1.5 * bandwidth / 2.0 / samplerate;
 				bpfilt->create_filter(0, lp);
 			}
-			break;
-		case MODE_FSKHELL:
-		case MODE_FSKH105:
-			break;
-	}
+//			break;
+//		case MODE_FSKHELL:
+//		case MODE_FSKH105:
+//		case MODE_HELL80:
+//			break;
+//	}
 
 	while (len-- > 0) {
 		/* create analytic signal... */
@@ -284,16 +297,17 @@ int feld::rx_process(const double *buf, int len)
 		n = bpfilt->run(z, &zp);
 
 		switch (mode) {
-		case MODE_FSKHELL:
-		case MODE_FSKH105:
-			for (i = 0; i < n; i++) {
-				FSKHELL_rx(zp[i]);
-			}
-			break;
-		default:
-			for (i = 0; i < n; i++)
-				rx(zp[i]);
-			break;
+			case MODE_FSKHELL:
+			case MODE_FSKH105:
+			case MODE_HELL80:
+				for (i = 0; i < n; i++) {
+					FSKHELL_rx(zp[i]);
+				}
+				break;
+			default:
+				for (i = 0; i < n; i++)
+					rx(zp[i]);
+				break;
 		}
 	}
 
@@ -366,6 +380,7 @@ double feld::nco(double freq)
 void feld::send_symbol(int currsymb, int nextsymb)
 {
 	double tone = get_txfreq_woffset();
+	double midtone = tone;
 	double Amp;
 	int outlen = 0;
 	
@@ -374,9 +389,15 @@ void feld::send_symbol(int currsymb, int nextsymb)
 		switch (mode) {
 			case MODE_FSKHELL :
 			case MODE_FSKH105 :
-				tone = get_txfreq_woffset() + (reverse ? -1 : 1) * (currsymb ? -1 : 1) * bandwidth / 2.0;
+				tone = midtone + (reverse ? -1 : 1) * (currsymb ? -1 : 1) * txpixrate / 2.0;
 				break;
-			case MODE_FELDHELL :
+			case MODE_HELL80:
+				tone = midtone - (reverse ? -1 : 1) * (currsymb ? -1 : 1) * txpixrate / 2.0;
+				break;
+			case MODE_HELLX5 : case MODE_HELLX9 :
+				Amp = currsymb;
+				break;
+			case MODE_FELDHELL : case MODE_SLOWHELL :
 			default :
 				if (prevsymb == 0 && currsymb == 1) {
 					Amp = OnShape[outlen];
@@ -388,9 +409,11 @@ void feld::send_symbol(int currsymb, int nextsymb)
 		}
 		outbuf[outlen++] = Amp * nco(tone);
 
-		if (outlen >= OUTBUFSIZE)
+		if (outlen >= OUTBUFSIZE) {
+std::cout << "reset\n"; std::cout.flush();
 			break;
-		txcounter += UpSampleInc;
+		}
+		txcounter += upsampleinc;
 		if (txcounter < 1.0)
 			continue;
 		txcounter -= 1.0;
@@ -400,8 +423,6 @@ void feld::send_symbol(int currsymb, int nextsymb)
 
 // write to soundcard & display
 	ModulateXmtr(outbuf, outlen);
-
-// rx echo
 	rx_process(outbuf, outlen);
 	
 }
@@ -484,7 +505,7 @@ int feld::tx_process()
 
 // if TX buffer empty
 // send idle character
-	if (c == -1)
+	if (c == -1) {
 		if (progdefaults.FELD_IDLE == true)
 			c = '.';
 		else {
@@ -492,7 +513,7 @@ int feld::tx_process()
 			send_null_column();
 			return 0;
 		}
-
+	}
 	if (c == '\r' || c == '\n')
 		c = ' ';
 
@@ -503,7 +524,7 @@ int feld::tx_process()
 
 void feld::initKeyWaveform()
 {
-	for (int i = 0; i < 80; i++) {
+	for (int i = 0; i < MAXLEN; i++) {
 		OnShape[i] = 1.0;
 		OffShape[i] = 0.0;
 	}
