@@ -53,7 +53,8 @@ void fftfilt::create_filter(double f1, double f2)
 {
 	int len = filterlen / 2 + 1;
 	double t, h, x, it;
-	Cfft *tmpfft = new Cfft(filterlen);
+	Cfft *tmpfft;
+	tmpfft = new Cfft(filterlen);
 	
 // initialize the filter to zero	
 	for (int i = 0; i < filterlen; i++)
