@@ -74,7 +74,7 @@ void C_FIR_filter::init(int len, int dec, double *itaps, double *qtaps) {
 		ibuffer[i] = qbuffer[i] = 0.0;
 	
 	if (itaps) {
-		ifilter = new double[len];
+            ifilter = new double[len];
 		for (int i = 0; i < len; i++) ifilter[i] = itaps[i];
 	}
 	if (qtaps) {
@@ -274,6 +274,9 @@ Cmovavg::~Cmovavg()
 
 double Cmovavg::run(double a)
 {
+	if (!in) {
+		return a;
+	}
 	if (empty) {
 		empty = false;
 		for (int i = 0; i < len; i++) {
@@ -284,15 +287,15 @@ double Cmovavg::run(double a)
 		return a;
 	}
 	out = out - in[pint] + a;
-	in[pint++] = a;
-	pint %= len;
+	in[pint] = a;
+	if (++pint >= len) pint = 0;
 	return out / len;
 }
 
 void Cmovavg::setLength(int filtlen)
 {
 	if (filtlen > len) {
-		delete [] in;
+		if (in) delete [] in;
 		in = new double[filtlen];
 	}
 	len = filtlen;
