@@ -24,6 +24,9 @@
 // ----------------------------------------------------------------------------
 
 #include <config.h>
+#include <iosfwd>
+#include <iomanip>
+#include <sstream>
 
 #include "globals.h"
 #include "modem.h"
@@ -50,12 +53,20 @@ const struct mode_info_t mode_info[NUM_MODES] = {
 	{ MODE_DOMINOEX22, &dominoex22_modem, "DomX22", "DominoEX 22", "DOMINOEX22" },
 
 	{ MODE_FELDHELL, &feld_modem, "FELDHELL", "Feld Hell", "" },
+	{ MODE_SLOWHELL, &feld_slowmodem, "SLOWHELL", "Slow Hell", "" },
+	{ MODE_HELLX5, &feld_x5modem, "HELLX5", "Feld Hell X5", "" },
+	{ MODE_HELLX9, &feld_x9modem, "HELLX9", "Feld Hell X9", "" },	
 	{ MODE_FSKHELL, &feld_FMmodem, "FSK-HELL", "FSK Hell", "" },
 	{ MODE_FSKH105, &feld_FM105modem, "FSK-H105", "FSK Hell-105", "" },
+	{ MODE_HELL80, &feld_80modem, "HELL80", "Hell 80", "" },
 
 	{ MODE_MFSK8, &mfsk8_modem, "MFSK-8", "MFSK-8", "MFSK16" },
 	{ MODE_MFSK16, &mfsk16_modem, "MFSK16", "MFSK-16", "MFSK8" },
 
+	{ MODE_MT63_500, &mt63_500_modem, "MT63-500", "MT63-500", "" },
+	{ MODE_MT63_1000, &mt63_1000_modem, "MT63-1XX", "MT63-1000", "" },
+	{ MODE_MT63_2000, &mt63_2000_modem, "MT63-2XX", "MT63-2000", "" },
+
 	{ MODE_BPSK31, &psk31_modem, "BPSK31", "BPSK-31", "PSK31" },
 	{ MODE_QPSK31, &qpsk31_modem, "QPSK31", "QPSK-31", "QPSK31" },
 	{ MODE_PSK63, &psk63_modem, "PSK-63", "BPSK-63", "PSK63" },
@@ -76,9 +87,64 @@ const struct mode_info_t mode_info[NUM_MODES] = {
 	{ MODE_THROBX2, &throbx2_modem, "THRBX2", "ThrobX 2", "" },
 	{ MODE_THROBX4, &throbx4_modem, "THRBX4", "ThrobX 4", "" },
 
-//	{ MODE_MT63, 0, "MT63", "MT-63", "" },
-
 	{ MODE_WWV, &wwv_modem, "WWV", "WWV", "" },
 
 	{ MODE_ANALYSIS, &anal_modem, "ANALYSIS", "Freq Analysis", "" }
 };
+
+std::ostream& operator<<(std::ostream& s, const qrg_mode_t& m)
+{
+	return s << m.rfcarrier << ' ' << m.rmode << ' ' << m.carrier << ' ' << mode_info[m.mode].sname;
+}
+
+std::istream& operator>>(std::istream& s, qrg_mode_t& m)
+{
+	string sMode;
+	int mnbr;
+	s >> m.rfcarrier >> m.rmode >> m.carrier >> sMode;
+// handle case for reading older type of specification string
+	if (sscanf(sMode.c_str(), "%d", &mnbr)) {
+		m.mode = mnbr;
+		return s;
+	}
+	m.mode = MODE_BPSK31;
+	for (mnbr = MODE_CW; mnbr < NUM_MODES; mnbr++)
+		if (sMode == mode_info[mnbr].sname) {
+			m.mode = mnbr;
+			break;
+		}
+	return s;
+}
+
+std::string qrg_mode_t::str(void)
+{
+	ostringstream s;
+	s << setiosflags(ios::fixed) << setprecision(3) << rfcarrier/1000.0 << '\t'
+          << rmode << '\t'
+          << (mode < NUM_MODES ? mode_info[mode].sname : "NONE") << '\t'
+          << carrier;
+	return s.str();
+
+
+	// This an example of how we would do things if we were not using
+	// Fl_Browser and had to format the fields manually and add the string
+	// to a menu
+
+	// static unsigned max_mode_sname = 0;
+
+	// if (max_mode_sname == 0)
+	//	   for (size_t i = 0; i < NUM_MODES; i++)
+	//		   if (max_mode_sname < strlen(mode_info[i].sname))
+	//			   max_mode_sname = strlen(mode_info[i].sname);
+
+	// ostringstream s;
+
+	// s << setw(11) << setiosflags(ios::right) << setiosflags(ios::fixed) << setprecision(3)
+	//   << rfcarrier/1000.0 << ' '
+	//   << setw(max_mode_sname) << resetiosflags(ios::right) << setiosflags(ios::left)
+	//   << (mode < NUM_MODES ? mode_info[mode].sname : "NONE") << ' '
+	//   << setw(4) << resetiosflags(ios::left) << setiosflags(ios::right)
+	//   << carrier << ' ' << rmode;
+
+	// return s.str();
+}
