@@ -13,7 +13,6 @@ using namespace std;
 
 struct configuration {
 	bool	changed;
-	double 	squelch;
 	double	wfRefLevel;
 	double	wfAmpSpan;
 	int		LowFreqCutoff;
@@ -21,12 +20,13 @@ struct configuration {
 	double	RTTYsweetspot;
 	double	PSKsweetspot;
 	bool	StartAtSweetSpot;
-// for PSK mail interface
+// for PSK  & PSK mail interface
 	bool	PSKmailSweetSpot;
 	int		SearchRange;
 	int		ServerOffset;
+	double	ACQsn;
 // RTTY
-	double		rtty_squelch;
+//	double		rtty_squelch;
 	int			rtty_shift;
 	int			rtty_baud;
 	int 		rtty_bits;
@@ -38,9 +38,9 @@ struct configuration {
 	bool		rtty_autocrlf;
 	int			rtty_autocount;
 	int			rtty_afcspeed;
-	bool		afconoff;
-	bool		sqlonoff;
-	double		sldrSquelchValue;
+//	bool		afconoff;
+//	bool		sqlonoff;
+//	double		sldrSquelchValue;
 	bool		useFSKkeyline;		// use RTS for FSK
 	bool		useFSKkeylineDTR;	// use DTR for FSK
 	bool		FSKisLSB;
@@ -66,23 +66,26 @@ struct configuration {
 	double		CWpost;
 	bool		CWid;
 	int			CWIDwpm;
-
 // FELD-HELL
 	bool		FELD_IDLE;
 // OLIVIA
 	int			oliviatones;
 	int			oliviabw;
+	int			oliviasmargin;
+	int			oliviasinteg;
+	bool			olivia8bit;
 // DOMINOEX
 	double		DOMINOEX_BW;
+// MT63
+	bool 		mt63_8bit;
+	int			mt63_interleave;
 // User interface data
-	int		Fontnbr;
-	int		FontSize;
-	int		FontColor;
 	uchar	red;
 	uchar	green;
 	uchar	blue;
 	bool	MultiColorWF;
 	int		wfPreFilter;
+	bool	WFaveraging;
 	bool	UseCursorLines;
 	bool	UseCursorCenterLine;
 	bool	UseBWTracks;
@@ -104,8 +107,6 @@ struct configuration {
 // Rig Interface data
 	bool	btnusb;
 	int		btnPTTis;
-	int		btnRTSDTRis; // obsolete
-	int		btnPTTREVis; // obsolete
 	bool	RTSptt;
 	bool	DTRptt;
 	bool	RTSplus;
@@ -127,10 +128,15 @@ struct configuration {
 	string	secText;
 // Sound card
 	int	btnAudioIOis;
-	string	SCdevice;
 	string	OSSdevice;
 	string	PAdevice;
+	string	PortInDevice;
+	string	PortOutDevice;
+	string	PulseServer;
 	int		sample_rate;
+	int		in_sample_rate;
+	int		out_sample_rate;
+	string		sample_converter;
 	int		RX_corr;
 	int		TX_corr;
 	int		TxOffset;
@@ -145,8 +151,6 @@ struct configuration {
 	
 // Mixer configuration
 	string	MXdevice;
-	double	RcvMixer;
-	double	XmtMixer;
 	bool	MicIn;
 	bool	LineIn;
 	bool	EnableMixer;
@@ -155,6 +159,23 @@ struct configuration {
 	
 // waterfall palette
 	RGBint	cfgpal[9];
+
+// Button key color palette
+	bool	useGroupColors;
+	RGBint	btnGroup1;
+	RGBint	btnGroup2;
+	RGBint	btnGroup3;
+	RGBint  btnFkeyTextColor;
+	
+// Rx / Tx fonts & palettes
+	int 	RxFontnbr;
+	int 	RxFontsize;
+	int		RxFontcolor;
+	int 	TxFontnbr;
+	int 	TxFontsize;
+	int		TxFontcolor;
+	RGBint	RxColor;
+	RGBint	TxColor;
 	
 	bool alt_text_widgets;
 	
@@ -162,6 +183,14 @@ struct configuration {
 	
 	int rx_msgid;
 	int tx_msgid;
+	
+// PSK viewer parameters
+	bool	VIEWERmarquee;
+	bool	VIEWERshowfreq;
+	int		VIEWERstart;
+	int		VIEWERchannels;
+	double	VIEWERsquelch;
+	int		VIEWERtimeout;
 
 public:
 	void writeDefaultsXML();
@@ -169,7 +198,7 @@ public:
 	bool readDefaultsXML();
 	void loadDefaults();
 	void saveDefaults();
-	int  openDefaults();
+	int  setDefaults();
 	void initOperator();
 	void initInterface();
 	void initMixerDevices();
@@ -187,4 +216,6 @@ extern configuration progdefaults;
 extern void mixerInputs();
 extern void enableMixer(bool);
 
+enum { SAMPLE_RATE_UNSET = -1, SAMPLE_RATE_AUTO, SAMPLE_RATE_NATIVE, SAMPLE_RATE_OTHER };
+
 #endif
