@@ -37,20 +37,13 @@
 
 #define	FeldSampleRate	8000
 #define FeldMaxSymLen	1024
-#define	FeldColumnRate	17.5
-#define FeldBandWidth	245.0
 
 #define	RxColumnLen	30
 #define	TxColumnLen	14
 
-#define	RxPixRate	((RxColumnLen)*(FeldColumnRate))
-#define	TxPixRate	((TxColumnLen)*(FeldColumnRate))
-
-#define	DownSampleInc	((double)(RxPixRate)/(samplerate))
-#define	UpSampleInc	((double)(TxPixRate)/(samplerate))
-
 #define	PIXMAP_W	14
 #define	PIXMAP_H	(TxColumnLen)
+#define MAXLEN 512
 
 class feld : public modem {
 enum FELD_STATE {PREAMBLE, POSTAMBLE, DATA};
@@ -61,14 +54,17 @@ protected:
 	double agc;
 	double peakhold;
 	double minhold;
+	
+	double rxpixrate;
+	double txpixrate;
+	double downsampleinc;
+	double upsampleinc;
+	double phi2freq;
 
 	C_FIR_filter	*hilbert;
 	fftfilt			*bpfilt;
 	Cmovavg			*bbfilt;
 	Cmovavg			*minmaxfilt;
-//	double bbfilter[MaxSymLen];
-//	unsigned int filterptr;
-
 //tx
 	FELD_STATE	tx_state;
 	double txphacc;
@@ -80,14 +76,15 @@ protected:
 	int halfwidth;
 	bool blackboard;
 	bool hardkeying;
+	double feldcolumnrate;
 
 	int preamble;
 	int postamble;
 	int prevsymb;
 	complex prev;
 	
-	double OnShape[80];
-	double OffShape[80];
+	double OnShape[MAXLEN];
+	double OffShape[MAXLEN];
 	
 	mbuffer<int, 2*RxColumnLen> col_data;
 	int col_pointer;
@@ -106,7 +103,7 @@ public:
 	~feld();
 	void	init();
 	void	rx_init();
-	void	tx_init(cSound *sc);
+	void	tx_init(SoundBase *sc);
 	void 	restart() {};
 	int		rx_process(const double *buf, int len);
 	int		tx_process();
