@@ -49,7 +49,6 @@
 #include "mixer.h"
 
 extern Fl_Double_Window *fl_digi_main;
-extern cMixer			mixer;
 
 extern ReceiveWidget		*ReceiveText;
 extern TransmitWidget		*TransmitText;
@@ -82,13 +81,15 @@ extern Fl_Button		*qsoSave;
 extern Fl_Button		*btnMacroTimer;
 extern Fl_Slider		*valRcvMixer;
 extern Fl_Slider		*valXmtMixer;
-extern Fl_Light_Button	*afconoff;
-extern Fl_Light_Button	*sqlonoff;
+extern Fl_Light_Button	*btn_afconoff;
+extern Fl_Light_Button	*btn_sqlonoff;
 extern Fl_Check_Button	*chk_afconoff;
 extern Fl_Check_Button	*chk_sqlonoff;
+extern Fl_Button		*btnAltMacros;
+
 
 extern bool				useCheckButtons;
-extern bool				altMacros;
+extern int				altMacros;
 
 extern waterfall		*wf;
 extern Digiscope		*digiscope;
@@ -96,9 +97,11 @@ extern Digiscope		*digiscope;
 
 extern void create_fl_digi_main();
 extern Fl_Menu_Item menu_[];
+extern Fl_Menu_Item *getMenuItem(const char *caption);
 extern void activate_rig_menu_item(bool b);
 extern void activate_test_menu_item(bool b);
 
+
 extern void put_freq(double frequency);
 extern void put_Bandwidth(int bandwidth);
 extern void display_metric(double metric);
@@ -128,6 +131,7 @@ extern void resetRTTY();
 extern void resetOLIVIA();
 extern void resetDOMEX();
 extern void resetSoundCard();
+extern void update_sound_config(unsigned idx);
 extern void restoreFocus();
 extern void setReverse(int);
 extern void clearQSO();
@@ -141,4 +145,9 @@ extern bool QuerySqlOnOff();
 extern void init_modem(trx_mode mode);
 extern void init_modem_sync(trx_mode mode);
 
+extern void change_modem_param(int state);
+
+extern void colorize_macro(int i);
+extern void colorize_macros();
+
 #endif
