@@ -26,6 +26,9 @@
 #ifndef _GLOBALS_H
 #define _GLOBALS_H
 
+#include <stdint.h>
+#include <string>
+
 enum state_t {
 	STATE_PAUSE = 0,
 	STATE_RX,
@@ -56,12 +59,20 @@ enum {
 	MODE_DOMINOEX22,
 
 	MODE_FELDHELL,
+	MODE_SLOWHELL,
+	MODE_HELLX5,
+	MODE_HELLX9,
 	MODE_FSKHELL,
 	MODE_FSKH105,
+	MODE_HELL80,
 
 	MODE_MFSK8,
 	MODE_MFSK16,
 
+	MODE_MT63_500,
+	MODE_MT63_1000,
+	MODE_MT63_2000,
+
 	MODE_BPSK31,
 	MODE_QPSK31,
 	MODE_PSK63,
@@ -82,14 +93,13 @@ enum {
 	MODE_THROBX2,
 	MODE_THROBX4,
 
-//	MODE_MT63,
-
 	MODE_WWV,
 	MODE_ANALYSIS,
 
 	NUM_MODES
 };
-typedef int trx_mode;
+
+typedef intptr_t trx_mode;
 
 struct mode_info_t {
 	trx_mode mode;
@@ -98,8 +108,31 @@ struct mode_info_t {
 	const char *name;
 	const char *pskmail_name;
 };
-
 extern const struct mode_info_t mode_info[NUM_MODES];
 
+class qrg_mode_t
+{
+public:
+	long long rfcarrier;
+	std::string rmode;
+	int carrier;
+	trx_mode mode;
+
+	qrg_mode_t() : rfcarrier(0), rmode("NONE"), carrier(0), mode(NUM_MODES) { }
+	qrg_mode_t(long long rfc_, std::string rm_, int c_, trx_mode m_)
+                : rfcarrier(rfc_), rmode(rm_), carrier(c_), mode(m_) { }
+	bool operator<(const qrg_mode_t& rhs) const
+        {
+		return rfcarrier < rhs.rfcarrier;
+	}
+	bool operator==(const qrg_mode_t& rhs) const
+	{
+		return rfcarrier == rhs.rfcarrier && rmode == rhs.rmode &&
+		       carrier == rhs.carrier && mode == rhs.mode;
+	}
+        std::string str(void);
+};
+std::ostream& operator<<(std::ostream& s, const qrg_mode_t& m);
+std::istream& operator>>(std::istream& s, qrg_mode_t& m);
 
 #endif
