@@ -15,8 +15,6 @@
 
 #include <hamlib/rig.h>
 
-#include "config.h"
-
 using namespace std;
 
 extern void get_rignames();
@@ -25,7 +23,7 @@ extern void get_riglist();
 extern void hamlib_close();
 extern bool hamlib_init(bool bPtt);
 extern void hamlib_set_ptt(int);
-extern void hamlib_set_qsy();
+extern void hamlib_set_qsy(long long f, long long fmid);
 extern int	hamlib_setfreq(long int);
 extern int	hamlib_setmode(rmode_t);
 extern rmode_t hamlib_getmode();
