@@ -25,10 +25,8 @@
 class modem : public morse {
 protected:
 	trx_mode mode;
-	cSound	*scard;
+	SoundBase	*scard;
 	
-	int		afcon;
-	int		squelchon;
 	bool	stopflag;
 	int		fragmentsize;
 	int		samplerate;
@@ -59,7 +57,8 @@ protected:
 	unsigned char *txptr;
 
 	double outbuf[OUTBUFSIZE];
-// these processes must be declared in the derived class
+
+	bool	historyON;
 	Digiscope::scope_mode scopemode;
 	
 	double scdata[512];
@@ -69,8 +68,9 @@ public:
 	modem();
 	virtual ~modem(){};
 
+// these processes must be declared in the derived class
 	virtual void init();
-	virtual void tx_init (cSound *sc) = 0;
+	virtual void tx_init (SoundBase *sc) = 0;
 	virtual void rx_init () = 0;
 	virtual void restart () = 0;
 	virtual int  tx_process () = 0;
@@ -85,12 +85,8 @@ public:
 
 //	void update_syncscope();
 
-	void 		set_squelch(double val) { squelch = val; }
-	double		get_squelch() { return squelch; }
-	void		set_sqlchOnOff(bool val) {squelchon = val;}
-	bool		get_sqlchOnOff() { return squelchon;}
-	void		set_afcOnOff(bool val) {afcon = val;}
-	bool		get_afcOnOff() { return afcon;}
+	void		HistoryON(bool val) {historyON = val;}
+	bool		HistoryON() { return historyON;}
 
 //	void 		set_mode(trx_mode);
 	trx_mode	get_mode();
@@ -177,9 +173,16 @@ public:
 extern modem *cw_modem;
 extern modem *mfsk8_modem;
 extern modem *mfsk16_modem;
+extern modem *mt63_500_modem;
+extern modem *mt63_1000_modem;
+extern modem *mt63_2000_modem;
 extern modem *feld_modem;
+extern modem *feld_slowmodem;
+extern modem *feld_x5modem;
+extern modem *feld_x9modem;
 extern modem *feld_FMmodem;
 extern modem *feld_FM105modem;
+extern modem *feld_80modem;
 extern modem *feld_CMTmodem;
 extern modem *psk31_modem;
 extern modem *psk63_modem;
