@@ -54,7 +54,6 @@ private:
 	int			escape;
 	int			smargin;
 	int			sinteg;
-	bool		olivia_esc;
 	int			tones;
 	int			bw;
 
@@ -74,7 +73,7 @@ public:
 	~olivia();
 	void init();
 	void rx_init();
-	void tx_init(cSound *sc);
+	void tx_init(SoundBase *sc);
 	void restart();
 	int rx_process(const double *buf, int len);
 	int tx_process();
