@@ -24,11 +24,25 @@ struct status {
 	int		speed;
 	double	reflevel;
 	double	ampspan;
+	unsigned int	VIEWERnchars;
+	unsigned int	VIEWERxpos;
+	unsigned int	VIEWERypos;
+	bool	VIEWERvisible;
+	bool	LOGenabled;
+	double  sldrSquelchValue;
+	bool	afconoff;
+	bool	sqlonoff;
+	double	RcvMixer;
+	double	XmtMixer;
+	
+	bool	bLastStateRead;
+	
 	
 public:
 	void saveModeState(trx_mode m);
 	void initLastState();
 	void saveLastState();
+	void loadLastState();
 	friend std::istream &operator>>(std::istream &stream, status &c);
 	friend std::ostream &operator<<(std::ostream &ostream, status c);
 };
