@@ -57,6 +57,7 @@ extern int fl_mutex_init(Fl_Mutex * m);
 extern int fl_cond_init(Fl_Cond * c);
 extern int fl_cond_wait(Fl_Cond *c, Fl_Mutex *m);
 extern int fl_cond_signal(Fl_Cond *c);
+extern int fl_cond_bcast(Fl_Cond *c);
 extern int fl_lock(Fl_Mutex *m);
 extern int fl_unlock(Fl_Mutex *m);
 extern int fl_join(Fl_Thread t);
@@ -70,6 +71,28 @@ typedef unsigned long Fl_Thread;
 extern int fl_create_thread(Fl_Thread * t, void *(*f) (void *), void* p);
 
 #  endif // !WIN32
+
+// we have 4 threads, only 3 of which will use qrunner
+enum { UNKNOWN_TID = -1, TRX_TID, QRZ_TID, RIGCTL_TID, FLMAIN_TID,
+       NUM_THREADS, NUM_QRUNNER_THREADS = NUM_THREADS - 1 };
+
+#if USE_TLS
+	extern __thread int thread_id_;
+#	define CREATE_THREAD_ID() thread_id_ = UNKNOWN_TID
+#	define SET_THREAD_ID(x)   thread_id_ = (x)
+#	define GET_THREAD_ID()    thread_id_
+#else
+#	ifdef WIN32 // assume no pthreads support
+#		error need TLS support
+#	endif
+	extern pthread_key_t thread_id_;
+#	define CREATE_THREAD_ID() pthread_key_create(&thread_id_, 0);
+#	define SET_THREAD_ID(x)   pthread_setspecific(thread_id_, (void *)(x))
+#	define GET_THREAD_ID()    (int)pthread_getspecific(thread_id_)
+#endif // USE_TLS
+
+#include "fl_lock.h"
+
 #endif // !Threads_h
 
 //
