@@ -37,9 +37,9 @@
 // ----------------------------------------------------------------------------
 
 extern	void	trx_start_modem(modem *);
-extern	void	trx_start(const char *scdev);
+extern	void	trx_start(void);
 extern	void	trx_close();
-extern	void	trx_reset(const char *scdev);
+extern	void	trx_reset(void);
 extern	void	trx_start_macro_timer();
 
 extern	void	wait_modem_ready_prep(void);
@@ -51,6 +51,8 @@ extern Fl_Thread	trx_thread;
 extern state_t		trx_state;
 extern modem		*active_modem;
 
-extern	cSound 	*scard;
+extern	SoundBase 	*scard;
+
+extern  bool bHistory;
 
 #endif
