@@ -30,6 +30,7 @@
 #include "fft.h"
 #include "sound.h"
 #include "globals.h"
+#include "fldigi-config.h"
 
 #include <FL/Fl.H>
 #include <FL/fl_draw.H>
@@ -99,12 +100,6 @@ enum WFmode {
 enum WFspeed {FAST = 1, NORMAL = 2, SLOW = 8};
 //enum WFspeed {NORMAL = 2, SLOW = 8};
 
-struct qrg_mode_t {
-	long long rfcarrier;
-	int carrier;
-	trx_mode mode;
-};
-
 class WFdisp : public Fl_Widget {
 public:
 
@@ -277,6 +272,7 @@ private:
 	void drawgrayWF();
 	void drawspectrum();
 	void drawsignal();
+	
 
 protected:
 public:
@@ -286,6 +282,10 @@ public:
 	int	newcarrier;
 	int	oldcarrier;
 	bool	tmp_carrier;
+	double Pwr(int i) {
+		if ( i > 0 && i < IMAGE_WIDTH) return pwr[i];
+		return 0.0;
+	}
 };
 
 class waterfall: public Fl_Group {
@@ -360,7 +360,7 @@ public:
 			qsy->deactivate();
 		wfdisp->useBands(!on);
 	}
-	
+	double Pwr(int i) { return wfdisp->Pwr(i); }	
 	
 	int handle(int event);
 /*
