@@ -32,6 +32,7 @@
 #include "mfsk.h"
 #include "modem.h"
 #include "configuration.h"
+#include "status.h"
 #include "trx.h"
 
 #include "ascii.h"
@@ -40,19 +41,15 @@
 
 #include "qrunner.h"
 
-#undef  MAX
-#define MAX(a,b)		(((a)>(b))?(a):(b))
-#undef  CLAMP
-#define CLAMP(x,low,high)       (((x)>(high))?(high):(((x)<(low))?(low):(x)))
-
 #define AFC_COUNT	32
 
+using namespace std;
 
 char mfskmsg[80];
 char txclr_tooltip[24];
 char txgry_tooltip[24];
 
-void  mfsk::tx_init(cSound *sc)
+void  mfsk::tx_init(SoundBase *sc)
 {
 	scard = sc;
 	txstate = TX_STATE_PREAMBLE;
@@ -74,6 +71,8 @@ void  mfsk::rx_init()
 			(pipe[i].vector[j]).re = (pipe[i].vector[j]).im = 0.0;
 	reset_afc();
 	s2n = 0.0;
+	memset(picheader, ' ', PICHEADER - 1);
+	picheader[PICHEADER -1] = 0;
 	put_MODEstatus(mode);
 }
 
@@ -95,7 +94,6 @@ mfsk::~mfsk()
 	if (pipe) delete [] pipe;
 	if (hbfilt) delete hbfilt;
 	if (binsfft) delete binsfft;
-//	if (wfid) delete wfid;
 }
 
 mfsk::mfsk(trx_mode mfsk_mode) : modem()
@@ -154,7 +152,6 @@ mfsk::mfsk(trx_mode mfsk_mode) : modem()
 	samplerate = MFSKSampleRate;
 	fragmentsize = symlen;
 	bandwidth = (numtones - 1) * tonespacing;
-//	wfid = new id(this);
 	
 	picRxWin = 0;
 	picRxBox = 0;
@@ -167,8 +164,9 @@ mfsk::mfsk(trx_mode mfsk_mode) : modem()
 	bitstate = 0;
 	phaseacc = 0;
 	pipeptr = 0;
-	squelch = 0;
 	metric = 0;
+	prev1symbol = prev2symbol = 0;
+	symbolpair[0] = symbolpair[1] = 0;
 
 	init();
 }
@@ -186,10 +184,14 @@ void mfsk::shutdown()
 //=====================================================================
 
 
-bool mfsk::check_picture_header()
+bool mfsk::check_picture_header(char c)
 {
 	char *p;
 
+	if (c >= ' ' && c <= 'z') {
+		memmove(picheader, picheader + 1, PICHEADER - 1);
+		picheader[PICHEADER - 2] = c;
+	}
 	picW = 0;
 	picH = 0;
 	color = false;
@@ -239,7 +241,7 @@ void mfsk::recvpic(complex z)
 		
 		if (color) {
 			pixelnbr = rgb + row + 3*col;
-			QUEUE(CMP_CB(&mfsk::updateRxPic, this, byte, pixelnbr)); //updateRxPic( byte, pixelnbr);
+			REQ(&mfsk::updateRxPic, this, byte, pixelnbr);
 			if (++col == picW) {
 				col = 0;
 				if (++rgb == 3) {
@@ -249,7 +251,7 @@ void mfsk::recvpic(complex z)
 			}
 		} else {
 			for (int i = 0; i < 3; i++)
-				QUEUE(CMP_CB(&mfsk::updateRxPic, this, byte, pixelnbr++)); //updateRxPic( byte, pixelnbr++ );
+				REQ(&mfsk::updateRxPic, this, byte, pixelnbr++);
 		}
 		picf = 0.0;
 
@@ -265,15 +267,10 @@ void mfsk::recvpic(complex z)
 
 void mfsk::recvchar(int c)
 {
-	if (c == -1)
+	if (c == -1 || c == 0)
 		return;
 
-	memmove(picheader, picheader + 1, sizeof(picheader) - 1);
-
-	picheader[sizeof(picheader) - 2] = (c == 0) ? ' ' : c;
-	picheader[sizeof(picheader) - 1] = 0;
-
-	if (check_picture_header() == true) {
+	if (check_picture_header(c) == true) {
 		if (symbolbit == 4) {
 			rxstate = RX_STATE_PICTURE_START_1;
 		}
@@ -290,7 +287,8 @@ void mfsk::recvchar(int c)
 		row = 0;
 		rgb = 0;
 
-		memset(picheader, ' ', sizeof(picheader));
+		memset(picheader, ' ', PICHEADER - 1);
+		picheader[PICHEADER -1] = 0;		
 	}
 
 	put_rx_char(c);
@@ -345,7 +343,7 @@ void mfsk::decodesymbol(unsigned char symbol)
 	}
 	display_metric(metric);
 	
-	if (squelchon && metric < squelch)
+	if (progStatus.sqlonoff && metric < progStatus.sldrSquelchValue)
 		return;
 
 	recvbit(c);
@@ -435,7 +433,7 @@ void mfsk::update_syncscope()
 {
 	int j;
 	memset(scopedata, 0, 2 * symlen * sizeof(double));
-	if (!squelchon || metric >= squelch)
+	if (!progStatus.sqlonoff || metric >= progStatus.sldrSquelchValue)
 		for (int i = 0; i < 2 * symlen; i++) {
 			j = (i + pipeptr) % (2 * symlen);
 			scopedata[i] = (pipe[j].vector[prev1symbol]).mag();
@@ -499,7 +497,7 @@ void mfsk::afc()
 	f = z.arg() * samplerate / twopi;
 	f -= (1000 + tonespacing * currsymbol);
 
-	if (afcon && (metric > squelch || squelchon == false)) {
+	if (progStatus.afconoff && (metric > progStatus.sldrSquelchValue || progStatus.sqlonoff == false)) {
 		if (fabs(f) <= tonespacing / 2.0)
 			freqerr = afcfilt->run(f / numtones);
 		set_freq(frequency + freqerr);
@@ -548,7 +546,7 @@ int mfsk::rx_process(const double *buf, int len)
 			if (counter++ == picturesize) {
 				counter = 0;
 				rxstate = RX_STATE_DATA;
-				// QUEUE_FLUSH();
+				// REQ_FLUSH();
 				put_status("");
 				string autosave_dir = HomeDir + "mfsk_pics/";
 				picRx->save_jpeg(autosave_dir.c_str());
@@ -678,7 +676,7 @@ void mfsk::sendpic(unsigned char *data, int len)
 
 	for (i = 0; i < len; i++) {
 		if (txstate == TX_STATE_PICTURE)
-			QUEUE(CMP_CB(&mfsk::updateTxPic, this, data[i])); //updateTxPic(data[i]);
+			REQ(&mfsk::updateTxPic, this, data[i]);
 		if (reverse)
 			f = get_txfreq_woffset() - bandwidth * (data[i] - 128) / 256.0;
 		else
@@ -791,7 +789,7 @@ int mfsk::tx_process()
 						sizeof(mfskmsg) - n, ", ", " left");
 				put_status(mfskmsg);
 			}
-			QUEUE_FLUSH();
+			REQ_FLUSH();
 
 			txstate = TX_STATE_DATA;
 			put_status("Send picture: done");
@@ -804,7 +802,8 @@ int mfsk::tx_process()
 			abortxmt = false;
 			rxstate = RX_STATE_DATA;
 			counter = 0;
-			memset(picheader, ' ', sizeof(picheader));
+			memset(picheader, ' ', PICHEADER - 1);
+			picheader[PICHEADER -1] = 0;
 			FL_UNLOCK_E();
 			break;
 	}
@@ -968,7 +967,7 @@ void cb_picTxSendColor( Fl_Widget *w, void *who)
 			for (ix = 0; ix < W; ix++)
 				outbuf[rowstart + rgb*W + ix] = inbuf[rowstart + rgb + ix*3];
 	}
-	sprintf(my->picheader, "\nSending Pic:%dx%dC;", W, H);
+	snprintf(my->picheader, PICHEADER - 1, "\nSending Pic:%dx%dC;", W, H);
 	my->xmtbytes = W * H * 3;
 	my->color = true;
 	my->rgb = 0;
@@ -1004,7 +1003,7 @@ void cb_picTxSendGrey( Fl_Widget *w, void *who)
 	unsigned char *inbuf = my->xmtimg;
 	for (int i = 0; i < W*H; i++)
 		outbuf[i] = ( 31 * inbuf[i*3] + 61 * inbuf[i*3 + 1] + 8 * inbuf[i*3 + 2])/100;
-	sprintf(my->picheader, "\nSending Pic:%dx%d;", W, H);
+	snprintf(my->picheader, PICHEADER - 1, "\nSending Pic:%dx%d;", W, H);
 	my->xmtbytes = W * H;
 	my->color = false;
 	my->col = 0;
