@@ -1,7 +1,7 @@
 #include <config.h>
 
 #include "configuration.h"
-#include "Config.h"
+#include "confdialog.h"
 #include "xmlreader.h"
 
 #if USE_HAMLIB
@@ -17,7 +17,6 @@
 
 configuration progdefaults = {
 	false,			// bool		changed;
-	25.0,			// double 	squelch;
 	0.0,			// double	wfRefLevel;
 	70.0,			// double	wfAmpSpan;
 	300,			// int		LowFreqCutoff;
@@ -29,8 +28,8 @@ configuration progdefaults = {
 	true,			// bool		PSKmailSweetSpot;
 	200,			// int		SearchRange;
 	40,				// int		ServerOffset;
+	6.0,			// double	ACQsn;
 // RTTY
-	25.0,			// double		rtty_squelch;
 	3,				// int			rtty_shift; = 170
 	0,				// int			rtty_baud; = 45
 	0,				// int 			rtty_bits; = 5
@@ -42,9 +41,6 @@ configuration progdefaults = {
 	true,			// bool		rtty_autocrlf;
 	72,				// int		rtty_autocount;
 	1,				// int		rtty_afcspeed;
-	true,			// bool		afconoff;
-	true,			// bool		sqlonoff;
-	30.0,			// double	sldrSquelchValue;;
 	false,			// bool		useFSKkeyline;
 	false,			// bool		useFSKkeylineDTR;	
 	true,			// bool		FSKisLSB;
@@ -76,17 +72,21 @@ configuration progdefaults = {
 // OLIVIA
 	2,				// int		oliviatones;
 	2,				// int		oliviabw;
+	8,				// int		oliviasmargin
+	4,				// int		oliviasinteg
+	false,				// bool		olivia8bit
 // DOMINOEX
 	2.0,			// double	DOMINOEX_BW;
+// MT63
+	false,			// bool 	mt63_8bit;
+	32,				// int		mt63_interleave;
 //
-	0, 				// int 		Fontnbr
-	16,				// int 		Fontsize
-	0,				// int 		Fontcolor
 	0,				// uchar 	red
 	255,			// uchar 	green
 	255,			// uchar 	blue
 	0,				// bool 	MultiColorWF;
 	1,				// int  	wfPreFilter == Blackman
+	false,			// bool		WFaveraging
 	true,			// bool 	UseCursorLines;
 	true,			// bool 	UseCursorCenterLine;
 	true,			// bool 	UseBWTracks;
@@ -108,8 +108,6 @@ configuration progdefaults = {
 //
 	true,			// bool		btnusb;
 	0, 				// int 		btnPTTis
-	0, 				// int 		btnRTSDTRis
-	0, 				// int 		btnPTTREVis
 	false,			// bool		RTSptt;
 	false,			// bool		DTRptt;
 	false,			// bool		RTSplus;
@@ -130,11 +128,16 @@ configuration progdefaults = {
 	"/dev/ttyS0",	// PTTdev
 	"fldigi ",		// secondary text
 // Sound card
-	0,			// int		btnAudioIOis
-	"",		// string	SCdevice;
+	-1,			// int		btnAudioIOis
 	"",		// string	OSSdevice;
 	"",		// string	PAdevice;
-	0,				// int		sample_rate;
+	"",		// string	PortIndevice;
+	"",		// string	PortOutDevice;
+	"",		// string	PulseServer
+	SAMPLE_RATE_UNSET,		// int		sample_rate;
+	SAMPLE_RATE_UNSET,		// int		in_sample_rate;
+	SAMPLE_RATE_UNSET,		// int		out_sample_rate;
+	"src-sinc-fastest",		// string	sample_converter;
 	0,				// int		RX_corr;
 	0,				// int		TX_corr;
 	0,				// int		TxOffset;
@@ -148,8 +151,6 @@ configuration progdefaults = {
 	0,				// int		timeout;
 	
 	"",			// string	MXdevice
-	1.0,			// double	RcvMixer;
-	1.0,			// double	XmtMixer;
 	false,			// bool		MicIn;
 	true,			// bool		LineIn;
 	false,			// bool		EnableMixer;
@@ -158,12 +159,37 @@ configuration progdefaults = {
 	{{  0,  0,  0},{  0,  0,  62},{  0,  0,126}, // default palette
 	 {  0,  0,214},{145,142,  96},{181,184, 48},
 	 {223,226,105},{254,254,   4},{255, 58,  0} },
+	 	
+// Button key color palette
+	true,			  // bool useGroupColors;
+	{  80, 144, 144}, // RGBint btnGroup1;
+	{ 144,  80,  80}, // RGBint btnGroup2;
+	{  80,  80, 144}, // RGBint btnGroup3;
+	{ 255, 255, 255}, // RGBint btnFkeyTextColor;
+
+// Rx / Tx Text Widgets
+
+	FL_SCREEN,		// int 		RxFontnbr
+	16,				// int 		RxFontsize
+	0,				// int		RxFontcolor
+	FL_SCREEN,		// int 		TxFontnbr
+	16,				// int 		TxFontsize
+	0,				// int		TxFontcolor
+	{ 255, 242, 190}, // RGBint RxColor;
+	{ 200, 235, 255}, // RGBint TxColor;
 
 	true,			// bool		alt_text_widgets;
 
-	"",			// string	strCommPorts
-        9876,			// int		rx_msgid
-        6789,			// int		tx_msgid
+	"",				// string	strCommPorts
+        9876,		// int		rx_msgid
+        6789,		// int		tx_msgid
+// PSK viewer parameters
+	true,			// bool	VIEWERmarquee
+	true,			// bool	VIEWERshowfreq
+	500,			// int		VIEWERstart
+	20,				// int		VIEWERchannels
+	20.0,			// double	VIEWERsquelch
+	15,				// int  VIEWERtimeout
 };
 
 const char *szBaudRates[] = {
@@ -183,11 +209,11 @@ enum TAG { \
 	IGNORE,
 	MYCALL, MYNAME, MYQTH, MYLOC, 
 	SQUELCH, WFREFLEVEL, WFAMPSPAN, LOWFREQCUTOFF, 
-	FONTNBR, FONTSIZE, FONTCOLOR,
 	STARTATSWEETSPOT, PSKMAILSWEETSPOT, 
 	PSKSEARCHRANGE, PSKSERVEROFFSET,
+	ACQSN,
 	CWSWEETSPOT, PSKSWEETSPOT, RTTYSWEETSPOT,
-	RTTYSQUELCH, RTTYSHIFT, RTTYBAUD,
+	RTTYSHIFT, RTTYBAUD,
 	RTTYBITS, RTTYPARITY, RTTYSTOP, RTTYREVERSE,
 	RTTYMSBFIRST, RTTYCRCLF, RTTYAUTOCRLF,
 	RTTYAUTOCOUNT, RTTYAFCSPEED,
@@ -198,7 +224,7 @@ enum TAG { \
 	CWBANDWIDTH, CWRANGE, CWLOWERLIMIT, CWUPPERLIMIT,
 	CWTRACK, CWRISETIME, CWDASH2DOT,
 	XQSK, CWPRE, CWPOST, CWID, CWIDWPM,
-	OLIVIATONES, OLIVIABW,
+	OLIVIATONES, OLIVIABW, OLIVIASMARGIN, OLIVIASINTEG, OLIVIA8BIT,
 	DOMINOEXBW, 
 	FELDFONTNBR, FELDIDLE,
 	WFPREFILTER,
@@ -208,23 +234,29 @@ enum TAG { \
 	BWTCOLORS,
 	VIEWXMTSIGNAL, SENDID, MACROID, SENDTEXTID, STRTEXTID, VIDEOWIDTH,
 	QRZTYPE, QRZUSER, QRZPASSWORD,
-	BTNUSB, BTNPTTIS, BTNRTSDTRIS, BTNPTTREVIS,
+	BTNUSB, BTNPTTIS,
 	RTSPTT, DTRPTT, RTSPLUS, DTRPLUS,
 	CHOICEHAMLIBIS, CHKUSEMEMMAPIS,
 	CHKUSEHAMLIBIS, CHKUSERIGCATIS,
 	HAMRIGNAME, HAMRIGDEVICE, HAMRIGBAUDRATE,
 	PTTDEV,
 	SECONDARYTEXT, 
-	AUDIOIO, SCDEVICE, OSSDEVICE, PADEVICE,
-	SAMPLERATE, RXCORR, TXCORR, TXOFFSET,
+	AUDIOIO, OSSDEVICE, PADEVICE, PORTINDEVICE, PORTOUTDEVICE, PULSESERVER,
+	SAMPLERATE, INSAMPLERATE, OUTSAMPLERATE, RXCORR, TXCORR, TXOFFSET,
 	USELEADINGZEROS, CONTESTSTART, CONTESTDIGITS,
 	USETIMER, MACRONUMBER, TIMEOUT,
-	MXDEVICE, RCVMIXER, XMTMIXER, PCMVOLUME,
+	MXDEVICE, 
+	PCMVOLUME,
 	MICIN, LINEIN, ENABLEMIXER, MUTEINPUT,
 	PALETTE0, PALETTE1, PALETTE2, PALETTE3, PALETTE4, 
-	PALETTE5, PALETTE6, PALETTE7, PALETTE8 
+	PALETTE5, PALETTE6, PALETTE7, PALETTE8,
+	VIEWERMARQUEE, VIEWERSHOWFREQ, VIEWERSTART, 
+	VIEWERCHANNELS, VIEWERSQUELCH, VIEWERTIMEOUT, WFAVERAGING,
+	USEGROUPCOLORS, FKEYGROUP1, FKEYGROUP2, FKEYGROUP3,
+	FKEYTEXTCOLOR,
+	RXFONTNBR, RXFONTSIZE, TXFONTNBR, TXFONTSIZE,
+	RXFONTCOLOR, TXFONTCOLOR
 };
-//	, ALT_TEXT_WIDGETS };
 	
 void writeXMLint(ofstream &f, const char * tag,  int val)
 {
@@ -281,13 +313,9 @@ void configuration::writeDefaultsXML()
 	writeXMLstr(f, "MYQTH", myQth);
 	writeXMLstr(f, "MYLOC", myLocator);
 
-	writeXMLdbl(f, "SQUELCH", squelch);
 	writeXMLdbl(f, "WFREFLEVEL", wfRefLevel);
 	writeXMLdbl(f, "WFAMPSPAN", wfAmpSpan);
 	writeXMLint(f, "LOWFREQCUTOFF", LowFreqCutoff);
-	writeXMLint(f, "FONTNBR", Fontnbr);
-	writeXMLint(f, "FONTSIZE", FontSize);
-	writeXMLint(f, "FONTCOLOR", FontColor);
 
 	writeXMLbool(f, "STARTATSWEETSPOT", StartAtSweetSpot);
 	writeXMLbool(f, "PSKMAILSWEETSPOT", PSKmailSweetSpot);
@@ -295,8 +323,8 @@ void configuration::writeDefaultsXML()
 	writeXMLint(f, "PSKSERVEROFFSET", ServerOffset);
 	writeXMLdbl(f, "CWSWEETSPOT", CWsweetspot);
 	writeXMLdbl(f, "PSKSWEETSPOT", PSKsweetspot);
+	writeXMLdbl(f, "ACQSN", ACQsn);
 	writeXMLdbl(f, "RTTYSWEETSPOT", RTTYsweetspot);
-	writeXMLdbl(f, "RTTYSQUELCH", rtty_squelch);	
 	writeXMLint(f, "RTTYSHIFT", rtty_shift);
 	writeXMLint(f, "RTTYBAUD", rtty_baud);
 	writeXMLint(f, "RTTYBITS", rtty_bits);
@@ -330,6 +358,9 @@ void configuration::writeDefaultsXML()
 	
 	writeXMLint(f, "OLIVIATONES", oliviatones);
 	writeXMLint(f, "OLIVIABW", oliviabw);
+	writeXMLint(f, "OLIVIASMARGIN", oliviasmargin);
+	writeXMLint(f, "OLIVIASINTEG", oliviasinteg);
+	writeXMLbool(f, "OLIVIA8BIT", olivia8bit);
 	writeXMLdbl(f, "DOMINOEXBW", DOMINOEX_BW);
 	writeXMLint(f, "FELDFONTNBR", feldfontnbr);
 	writeXMLbool(f, "FELDIDLE", FELD_IDLE);
@@ -361,8 +392,6 @@ void configuration::writeDefaultsXML()
 	writeXMLstr(f, "QRZPASSWORD", QRZuserpassword);
 	writeXMLbool(f, "BTNUSB", btnusb);
 	writeXMLint(f, "BTNPTTIS", btnPTTis);
-	writeXMLint(f, "BTNRTSDTRIS", btnRTSDTRis);
-	writeXMLint(f, "BTNPTTREVIS", btnPTTREVis);
 	writeXMLbool(f, "RTSPTT", RTSptt);
 	writeXMLbool(f, "DTRPTT", DTRptt);
 	writeXMLbool(f, "RTSPLUS", RTSplus);
@@ -377,11 +406,14 @@ void configuration::writeDefaultsXML()
 
 	writeXMLstr(f, "PTTDEV", PTTdev);
 	writeXMLstr(f, "SECONDARYTEXT", secText);		
-    writeXMLint(f, "AUDIOIO", btnAudioIOis);
-	writeXMLstr(f, "SCDEVICE", SCdevice);
+	writeXMLint(f, "AUDIOIO", btnAudioIOis);
 	writeXMLstr(f, "OSSDEVICE", OSSdevice);
 	writeXMLstr(f, "PADEVICE", PAdevice);
+	writeXMLstr(f, "PORTINDEVICE", PortInDevice);
+	writeXMLstr(f, "PORTOUTDEVICE", PortOutDevice);
 	writeXMLint(f, "SAMPLERATE", sample_rate);
+	writeXMLint(f, "INSAMPLERATE", in_sample_rate);
+	writeXMLint(f, "OUTSAMPLERATE", out_sample_rate);
 	writeXMLint(f, "RXCORR", RX_corr);		
 	writeXMLint(f, "TXCORR", TX_corr);
 	writeXMLint(f, "TXOFFSET", TxOffset);
@@ -392,8 +424,6 @@ void configuration::writeDefaultsXML()
 	writeXMLint(f, "MACRONUMBER", macronumber);
 	writeXMLint(f, "TIMEOUT", timeout);	
 	writeXMLstr(f, "MXDEVICE", MXdevice);
-	writeXMLdbl(f, "RCVMIXER", RcvMixer);
-	writeXMLdbl(f, "XMTMIXER", XmtMixer);
 	writeXMLdbl(f, "PCMVOLUME", PCMvolume);
 	writeXMLbool(f, "MICIN", MicIn);
 	writeXMLbool(f, "LINEIN", LineIn);
@@ -402,8 +432,28 @@ void configuration::writeDefaultsXML()
 	for (int i = 0; i < 9; i++)
 		writeXMLPalette(f, i, cfgpal[i].R, cfgpal[i].G, cfgpal[i].B);
 
-//	writeXMLbool(f, "ALT_TEXT_WIDGETS", alt_text_widgets);
+	writeXMLbool(f, "VIEWERMARQUEE", VIEWERmarquee);
+	writeXMLbool(f, "VIEWERSHOWFREQ", VIEWERshowfreq);
+	writeXMLint(f, "VIEWERSTART", VIEWERstart);
+	writeXMLint(f, "VIEWERCHANNELS", VIEWERchannels);
+	writeXMLdbl(f, "VIEWERSQUELCH", VIEWERsquelch);
+	writeXMLint(f, "VIEWERTIMEOUT", VIEWERtimeout);
+	writeXMLbool(f,"WFAVERAGEING", WFaveraging);
 
+	writeXMLbool(f,"USEGROUPCOLORS", useGroupColors);
+	writeXMLrgb(f, "FKEYGROUP1", btnGroup1.R, btnGroup1.G, btnGroup1.B);
+	writeXMLrgb(f, "FKEYGROUP2", btnGroup2.R, btnGroup2.G, btnGroup2.B);
+	writeXMLrgb(f, "FKEYGROUP3", btnGroup3.R, btnGroup3.G, btnGroup3.B);
+	writeXMLrgb(f, "FKEYTEXTCOLOR", 
+		btnFkeyTextColor.R, btnFkeyTextColor.G, btnFkeyTextColor.B);
+	
+	writeXMLint(f, "RXFONTNBR", RxFontnbr);
+	writeXMLint(f, "RXFONTSIZE", RxFontsize);
+	writeXMLint(f, "TXFONTNBR", TxFontnbr);
+	writeXMLint(f, "TXFONTSIZE", TxFontsize);
+	writeXMLrgb(f, "RXFONTCOLOR", RxColor.R, RxColor.G, RxColor.B);
+	writeXMLrgb(f, "TXFONTCOLOR", TxColor.R, TxColor.G, TxColor.B);	
+	
 	f << "</FLDIGI_DEFS>\n";
 	f.close();
 }
@@ -450,9 +500,6 @@ bool configuration::readDefaultsXML()
 					case MYLOC:
 						myLocator = xml->getNodeData();
 						break;
-					case SQUELCH:
-						squelch = atof(xml->getNodeData());
-						break;
 					case WFREFLEVEL:
 						wfRefLevel = atof(xml->getNodeData());
 						break;
@@ -462,15 +509,6 @@ bool configuration::readDefaultsXML()
 					case LOWFREQCUTOFF :
 						LowFreqCutoff = atoi(xml->getNodeData());
 						break;
-					case FONTSIZE :
-						FontSize = atoi(xml->getNodeData());
-						break;
-					case FONTCOLOR :
-						FontColor = atoi(xml->getNodeData());
-						break;
-					case FONTNBR :
-						Fontnbr = atoi(xml->getNodeData());
-						break;
 					case STARTATSWEETSPOT :
 						StartAtSweetSpot = atoi(xml->getNodeData());
 						break;
@@ -483,6 +521,9 @@ bool configuration::readDefaultsXML()
 					case PSKSERVEROFFSET :
 						ServerOffset = atoi(xml->getNodeData());
 						break;
+					case ACQSN :
+						ACQsn = atof(xml->getNodeData());
+						break;
 					case CWSWEETSPOT :
 						CWsweetspot = atof(xml->getNodeData());
 						break;
@@ -492,9 +533,6 @@ bool configuration::readDefaultsXML()
 					case RTTYSWEETSPOT :
 						RTTYsweetspot = atof(xml->getNodeData());
 						break;
-					case RTTYSQUELCH :
-						rtty_squelch = atof(xml->getNodeData());
-						break;
 					case RTTYSHIFT :
 						rtty_shift = atoi(xml->getNodeData());
 						break;
@@ -588,6 +626,15 @@ bool configuration::readDefaultsXML()
 					case OLIVIABW :
 						oliviabw = atoi(xml->getNodeData());
 						break;
+					case OLIVIASMARGIN :
+						oliviasmargin = atoi(xml->getNodeData());
+						break;
+					case OLIVIASINTEG :
+						oliviasinteg = atoi(xml->getNodeData());
+						break;
+					case OLIVIA8BIT :
+						olivia8bit = atoi(xml->getNodeData());
+						break;
 					case DOMINOEXBW :
 						DOMINOEX_BW = atof(xml->getNodeData());
 						break;
@@ -610,21 +657,18 @@ bool configuration::readDefaultsXML()
 						UseBWTracks = atoi(xml->getNodeData());
 						break;
 					case CLCOLORS :
-//						sscanf( xml->getNodeData(), "%d %d %d %d",
 						sscanf( xml->getNodeData(), "%hhu %hhu %hhu",
 							&cursorLineRGBI.R,
 							&cursorLineRGBI.G,
 							&cursorLineRGBI.B );	
 						break;
 					case CCCOLORS :
-//						sscanf( xml->getNodeData(), "%d %d %d %d",
 						sscanf( xml->getNodeData(), "%hhu %hhu %hhu",
 							&cursorCenterRGBI.R,
 							&cursorCenterRGBI.G,
 							&cursorCenterRGBI.B );	
 						break;
 					case BWTCOLORS :
-//						sscanf( xml->getNodeData(), "%d %d %d %d",
 						sscanf( xml->getNodeData(), "%hhu %hhu %hhu",
 							&bwTrackRGBI.R,
 							&bwTrackRGBI.G,
@@ -661,12 +705,6 @@ bool configuration::readDefaultsXML()
 					case BTNPTTIS :
 						btnPTTis = atoi(xml->getNodeData());
 						break;
-					case BTNRTSDTRIS :
-						btnRTSDTRis = atoi(xml->getNodeData());
-						break;
-					case BTNPTTREVIS :
-						btnPTTREVis = atoi(xml->getNodeData());
-						break;
 					case RTSPTT :
 						RTSptt = atoi(xml->getNodeData());
 						break;
@@ -709,18 +747,30 @@ bool configuration::readDefaultsXML()
 					case AUDIOIO :
 						btnAudioIOis = atoi(xml->getNodeData());
 						break;
-					case SCDEVICE :
-						SCdevice = xml->getNodeData();
-						break;
 					case OSSDEVICE :
 						OSSdevice = xml->getNodeData();
 						break;
 					case PADEVICE :
 						PAdevice = xml->getNodeData();
 						break;
+					case PORTINDEVICE :
+						PortInDevice = xml->getNodeData();
+						break;
+					case PORTOUTDEVICE :
+						PortOutDevice = xml->getNodeData();
+						break;
+					case PULSESERVER :
+						PulseServer = xml->getNodeData();
+						break;
 					case SAMPLERATE :
 						sample_rate = atoi(xml->getNodeData());
 						break;
+					case INSAMPLERATE :
+						in_sample_rate = atoi(xml->getNodeData());
+						break;
+					case OUTSAMPLERATE :
+						out_sample_rate = atoi(xml->getNodeData());
+						break;
 					case RXCORR :
 						RX_corr = atoi(xml->getNodeData());
 						break;
@@ -751,12 +801,6 @@ bool configuration::readDefaultsXML()
 					case MXDEVICE :
 						MXdevice = xml->getNodeData();
 						break;
-					case RCVMIXER :
-						RcvMixer = atof(xml->getNodeData());
-						break;
-					case XMTMIXER :
-						XmtMixer = atof(xml->getNodeData());
-						break;
 					case PCMVOLUME :
 						PCMvolume = atof(xml->getNodeData());
 						break;
@@ -808,9 +852,67 @@ bool configuration::readDefaultsXML()
 						sscanf( xml->getNodeData(), "%d %d %d",
 								&cfgpal[8].R, &cfgpal[8].G, &cfgpal[8].B );
 						break;
-//					case ALT_TEXT_WIDGETS :
-//						alt_text_widgets = atoi(xml->getNodeData());
-//						break;
+					case VIEWERMARQUEE :
+						VIEWERmarquee = atoi(xml->getNodeData());
+						break;
+					case VIEWERSHOWFREQ :
+						VIEWERshowfreq = atoi(xml->getNodeData());
+						break;
+					case VIEWERSTART :
+						VIEWERstart = atoi(xml->getNodeData());
+						break;
+					case VIEWERCHANNELS :
+						VIEWERchannels = atoi(xml->getNodeData());
+						break;
+					case VIEWERSQUELCH :
+						VIEWERsquelch = atof(xml->getNodeData());
+						break;
+					case VIEWERTIMEOUT :
+						VIEWERtimeout = atoi(xml->getNodeData());
+						break;
+					case WFAVERAGING :
+						WFaveraging = atoi(xml->getNodeData());
+						break;
+					case USEGROUPCOLORS :
+						useGroupColors = atoi(xml->getNodeData());
+					case FKEYGROUP1 :
+						sscanf( xml->getNodeData(), "%d %d %d",
+							&btnGroup1.R, &btnGroup1.G, &btnGroup1.B);
+						break;
+					case FKEYGROUP2 :
+						sscanf( xml->getNodeData(), "%d %d %d",
+							&btnGroup2.R, &btnGroup2.G, &btnGroup2.B);
+						break;
+					case FKEYGROUP3 :
+						sscanf( xml->getNodeData(), "%d %d %d",
+							&btnGroup3.R, &btnGroup3.G, &btnGroup3.B);
+						break;
+					case FKEYTEXTCOLOR : 
+						sscanf( xml->getNodeData(), "%d %d %d",
+							&btnFkeyTextColor.R, 
+							&btnFkeyTextColor.G, 
+							&btnFkeyTextColor.B);
+						break;
+					case RXFONTNBR :
+						RxFontnbr = atoi(xml->getNodeData());
+						break;
+					case RXFONTSIZE :
+						RxFontsize = atoi(xml->getNodeData());
+						break;
+					case TXFONTNBR :
+						TxFontnbr = atoi(xml->getNodeData());
+						break;
+					case TXFONTSIZE :
+						TxFontsize = atoi(xml->getNodeData());
+						break;
+					case RXFONTCOLOR :
+						sscanf( xml->getNodeData(), "%d %d %d",
+							&RxColor.R, &RxColor.G, &RxColor.B);
+						break;
+					case TXFONTCOLOR :
+						sscanf( xml->getNodeData(), "%d %d %d",
+							&TxColor.R, &TxColor.G, &TxColor.B);
+						break;
 				}
 				break;
 				
@@ -829,17 +931,14 @@ bool configuration::readDefaultsXML()
 				else if (!strcmp("WFREFLEVEL", nodeName)) 	tag = WFREFLEVEL;
 				else if (!strcmp("WFAMPSPAN", nodeName)) 	tag = WFAMPSPAN;
 				else if (!strcmp("LOWFREQCUTOFF", nodeName)) 	tag = LOWFREQCUTOFF;
-				else if (!strcmp("FONTSIZE", nodeName)) 	tag = FONTSIZE;
-				else if (!strcmp("FONTCOLOR", nodeName)) 	tag = FONTCOLOR;
-				else if (!strcmp("FONTNBR", nodeName)) 	tag = FONTNBR;
 				else if (!strcmp("STARTATSWEETSPOT", nodeName)) 	tag = STARTATSWEETSPOT;
 				else if (!strcmp("PSKMAILSWEETSPOT", nodeName)) 	tag = PSKMAILSWEETSPOT;
 				else if (!strcmp("PSKSEARCHRANGE", nodeName)) 	tag = PSKSEARCHRANGE;
 				else if (!strcmp("PSKSERVEROFFSET", nodeName)) 	tag = PSKSERVEROFFSET;
+				else if (!strcmp("ACQSN", nodeName)) tag = ACQSN;
 				else if (!strcmp("CWSWEETSPOT", nodeName)) 	tag = CWSWEETSPOT;
 				else if (!strcmp("PSKSWEETSPOT", nodeName)) 	tag = PSKSWEETSPOT;
 				else if (!strcmp("RTTYSWEETSPOT", nodeName)) 	tag = RTTYSWEETSPOT;
-				else if (!strcmp("RTTYSQUELCH", nodeName)) 	tag = RTTYSQUELCH;
 				else if (!strcmp("RTTYSHIFT", nodeName)) 	tag = RTTYSHIFT;
 				else if (!strcmp("RTTYBAUD", nodeName)) 	tag = RTTYBAUD;
 				else if (!strcmp("RTTYBITS", nodeName)) 	tag = RTTYBITS;
@@ -871,6 +970,9 @@ bool configuration::readDefaultsXML()
 				else if (!strcmp("IDWPM", nodeName)) tag = CWIDWPM;
 				else if (!strcmp("OLIVIATONES", nodeName)) 	tag = OLIVIATONES;
 				else if (!strcmp("OLIVIABW", nodeName)) 	tag = OLIVIABW;
+				else if (!strcmp("OLIVIASMARGIN", nodeName)) 	tag = OLIVIASMARGIN;
+				else if (!strcmp("OLIVIASINTEG", nodeName)) 	tag = OLIVIASINTEG;
+				else if (!strcmp("OLIVIA8BIT", nodeName)) 	tag = OLIVIA8BIT;
 				else if (!strcmp("DOMINOEXBW", nodeName)) 	tag = DOMINOEXBW;
 				else if (!strcmp("FELDFONTNBR", nodeName)) 	tag = FELDFONTNBR;
 				else if (!strcmp("FELDIDLE", nodeName)) 	tag = FELDIDLE;
@@ -892,8 +994,6 @@ bool configuration::readDefaultsXML()
 				else if (!strcmp("QRZTYPE", nodeName)) 	tag = QRZTYPE;
 				else if (!strcmp("BTNUSB", nodeName)) 	tag = BTNUSB;
 				else if (!strcmp("BTNPTTIS", nodeName)) 	tag = BTNPTTIS;
-				else if (!strcmp("BTNRTSDTRIS", nodeName)) 	tag = BTNRTSDTRIS;
-				else if (!strcmp("BTNPTTREVIS", nodeName)) 	tag = BTNPTTREVIS;
 				else if (!strcmp("RTSPTT", nodeName)) 	tag = RTSPTT;
 				else if (!strcmp("DTRPTT", nodeName)) 	tag = DTRPTT;
 				else if (!strcmp("RTSPLUS", nodeName)) 	tag = RTSPLUS;
@@ -908,10 +1008,13 @@ bool configuration::readDefaultsXML()
 				else if (!strcmp("PTTDEV", nodeName)) 	tag = PTTDEV;
 				else if (!strcmp("SECONDARYTEXT", nodeName)) 	tag = SECONDARYTEXT;
 				else if (!strcmp("AUDIOIO", nodeName)) 	tag = AUDIOIO;
-				else if (!strcmp("SCDEVICE", nodeName)) 	tag = SCDEVICE;
 				else if (!strcmp("OSSDEVICE", nodeName)) 	tag = OSSDEVICE;
 				else if (!strcmp("PADEVICE", nodeName)) 	tag = PADEVICE;
+				else if (!strcmp("PORTINDEVICE", nodeName)) 	tag = PORTINDEVICE;
+				else if (!strcmp("PORTOUTDEVICE", nodeName)) 	tag = PORTOUTDEVICE;
 				else if (!strcmp("SAMPLERATE", nodeName)) 	tag = SAMPLERATE;
+				else if (!strcmp("INSAMPLERATE", nodeName)) 	tag = INSAMPLERATE;
+				else if (!strcmp("OUTSAMPLERATE", nodeName)) 	tag = OUTSAMPLERATE;
 				else if (!strcmp("RXCORR", nodeName)) 	tag = RXCORR;
 				else if (!strcmp("TXCORR", nodeName)) 	tag = TXCORR;
 				else if (!strcmp("TXOFFSET", nodeName)) 	tag = TXOFFSET;
@@ -922,8 +1025,6 @@ bool configuration::readDefaultsXML()
 				else if (!strcmp("MACRONUMBER", nodeName)) 	tag = MACRONUMBER;
 				else if (!strcmp("TIMEOUT", nodeName)) 	tag = TIMEOUT;
 				else if (!strcmp("MXDEVICE", nodeName)) 	tag = MXDEVICE;
-				else if (!strcmp("RCVMIXER", nodeName)) 	tag = RCVMIXER;
-				else if (!strcmp("XMTMIXER", nodeName)) 	tag = XMTMIXER;
 				else if (!strcmp("PCMVOLUME", nodeName)) 	tag = PCMVOLUME;
 				else if (!strcmp("MICIN", nodeName)) 	tag = MICIN;
 				else if (!strcmp("LINEIN", nodeName)) 	tag = LINEIN;
@@ -938,7 +1039,24 @@ bool configuration::readDefaultsXML()
 				else if (!strcmp("PALETTE6", nodeName)) 	tag = PALETTE6;
 				else if (!strcmp("PALETTE7", nodeName)) 	tag = PALETTE7;
 				else if (!strcmp("PALETTE8", nodeName)) 	tag = PALETTE8;
-//				else if (!strcmp("ALT_TEXT_WIDGETS", nodeName)) 	tag = ALT_TEXT_WIDGETS;
+				else if (!strcmp("VIEWERMARQUEE", nodeName))	tag = VIEWERMARQUEE;
+				else if (!strcmp("VIEWERSHOWFREQ", nodeName))	tag = VIEWERSHOWFREQ;
+				else if (!strcmp("VIEWERSTART", nodeName))		tag = VIEWERSTART;
+				else if (!strcmp("VIEWERCHANNELS", nodeName))	tag = VIEWERCHANNELS;
+				else if (!strcmp("VIEWERSQUELCH", nodeName))	tag = VIEWERSQUELCH;
+				else if (!strcmp("VIEWERTIMEOUT", nodeName))	tag = VIEWERTIMEOUT;
+				else if (!strcmp("WFAVERAGING", nodeName))	tag = WFAVERAGING;
+				else if (!strcmp("USEGROUPCOLORS", nodeName)) tag = USEGROUPCOLORS;
+				else if (!strcmp("FKEYGROUP1", nodeName)) tag = FKEYGROUP1;
+				else if (!strcmp("FKEYGROUP2", nodeName)) tag = FKEYGROUP2;
+				else if (!strcmp("FKEYGROUP3", nodeName)) tag = FKEYGROUP3;
+				else if (!strcmp("FKEYTEXTCOLOR", nodeName)) tag = FKEYTEXTCOLOR;
+				else if (!strcmp("RXFONTNBR", nodeName)) tag = RXFONTNBR;
+				else if (!strcmp("RXFONTSIZE", nodeName)) tag = RXFONTSIZE;
+				else if (!strcmp("TXFONTNBR", nodeName)) tag = TXFONTNBR;
+				else if (!strcmp("TXFONTSIZE", nodeName)) tag = TXFONTSIZE;
+				else if (!strcmp("RXFONTCOLOR", nodeName)) tag = RXFONTCOLOR;
+				else if (!strcmp("TXFONTCOLOR", nodeName)) tag = TXFONTCOLOR;
 				else tag = IGNORE;
 				}
 				break;
@@ -985,6 +1103,9 @@ void configuration::loadDefaults() {
 // OLIVIA
 	mnuOlivia_Tones->value(oliviatones);
 	mnuOlivia_Bandwidth->value(oliviabw);
+	cntOlivia_smargin->value(oliviasmargin);
+	cntOlivia_sinteg->value(oliviasinteg);
+	btnOlivia_8bit->value(olivia8bit);
 
 	FL_UNLOCK();
 }
@@ -1029,7 +1150,6 @@ void configuration::saveDefaults() {
 	secText = txtSecondary->value();
 	PTTdev = inpTTYdev->value();
 
-	squelch = sldrSquelch->value();
 	for (int i = 0; i < 9; i++) {
 		progdefaults.cfgpal[i].R =  palette[i].R;
 		progdefaults.cfgpal[i].G =  palette[i].G;
@@ -1037,247 +1157,221 @@ void configuration::saveDefaults() {
 	}
 	FL_UNLOCK();
 	
-//	string deffname = HomeDir;
-//	deffname.append("fldigi.def");
-//	ofstream deffile(deffname.c_str(), ios::out);
-//	writeDefaults(deffile);
-
-//	deffile.close();
-	
 	writeDefaultsXML();
-	
 	changed = false;
 }
 
-int configuration::openDefaults() {
+int configuration::setDefaults() {
 #if USE_HAMLIB	
 	getRigs();
 #endif	
-	if (readDefaultsXML()) {
-//	if (readDefaults()) {
-		FL_LOCK();
-			inpMyCallsign->value(myCall.c_str());
-			inpMyName->value(myName.c_str());
-			inpMyQth->value(myQth.c_str());
-			inpMyLocator->value(myLocator.c_str());
-			UseLeadingZeros = btnUseLeadingZeros->value();
-			ContestStart = (int)nbrContestStart->value();
-			ContestDigits = (int)nbrContestDigits->value();
-			
-			txtSecondary->value(secText.c_str());
-			valDominoEX_BW->value(DOMINOEX_BW);
-			
-			for (int i = 0; i < 5; i++) {
-				btnPTT[i]->value(0);
-				btnPTT[i]->activate();
-			}
-			btnPTT[btnPTTis]->value(1);
-#if !USE_HAMLIB
-			btnPTT[1]->deactivate();
-			chkUSEHAMLIB->deactivate();
-            inpRIGdev->hide();
-            mnuBaudRate->hide();
-            cboHamlibRig->hide();
-#else
-            btnPTT[1]->activate();
-			chkUSEHAMLIB->activate();
-            inpRIGdev->show();
-            mnuBaudRate->show();
-            cboHamlibRig->show();
-			cboHamlibRig->value(HamRigName.c_str());
-#endif
-			btnRTSptt->value(RTSptt);
-			btnDTRptt->value(DTRptt);
-			btnRTSplusV->value(RTSplus);
-			btnDTRplusV->value(DTRplus);
-
-			inpTTYdev->value(PTTdev.c_str());
-
-			if(chkUSEMEMMAPis) {
-				chkUSEMEMMAP->value(1);
-				chkUSEHAMLIB->value(0);
-				chkUSERIGCAT->value(0);
-                cboHamlibRig->deactivate();
-                inpRIGdev->deactivate();
-                mnuBaudRate->deactivate();
-                btnPTT[1]->deactivate();
-                btnPTT[2]->activate();
-                btnPTT[3]->deactivate();
-			} else if (chkUSEHAMLIBis) {
-				chkUSEMEMMAP->value(0);
-				chkUSERIGCAT->value(0);
-				chkUSEHAMLIB->value(1);
-                cboHamlibRig->activate();
-                inpRIGdev->activate();
-                mnuBaudRate->activate();
-                btnPTT[1]->activate();
-                btnPTT[2]->deactivate();
-                btnPTT[3]->deactivate();
-			} else if (chkUSERIGCATis) {
-				chkUSEMEMMAP->value(0);
-				chkUSEHAMLIB->value(0);
-				chkUSERIGCAT->value(1);
-                cboHamlibRig->deactivate();
-                inpRIGdev->deactivate();
-                mnuBaudRate->deactivate();
-                btnPTT[1]->deactivate();
-                btnPTT[2]->deactivate();
-                btnPTT[3]->activate();
-			} else {
-				chkUSEMEMMAP->value(0);
-				chkUSEHAMLIB->value(0);
-				chkUSERIGCAT->value(0);
-                btnPTT[1]->deactivate();
-                btnPTT[2]->deactivate();
-                btnPTT[3]->deactivate();
-			}
-
-			inpRIGdev->value(HamRigDevice.c_str());
-			mnuBaudRate->value(HamRigBaudrate);
-
-			sldrSquelch->value(squelch);
-			
-			valCWsweetspot->value(CWsweetspot);
-			valRTTYsweetspot->value(RTTYsweetspot);
-			valPSKsweetspot->value(PSKsweetspot);
-			btnStartAtSweetSpot->value(StartAtSweetSpot);
-			btnPSKmailSweetSpot->value(PSKmailSweetSpot);
-			cntSearchRange->value(SearchRange);
-			cntServerOffset->value(ServerOffset);
-			
-			btnCursorBWcolor->color(
-				fl_rgb_color(cursorLineRGBI.R, cursorLineRGBI.G, cursorLineRGBI.B) );
-			btnCursorCenterLineColor->color(
-				fl_rgb_color(cursorCenterRGBI.R, cursorCenterRGBI.G, cursorCenterRGBI.B) );
-			btnBwTracksColor->color(
-				fl_rgb_color(bwTrackRGBI.R, bwTrackRGBI.G, bwTrackRGBI.B) );
-				
-			cntCWweight->value(CWweight);
-			sldrCWxmtWPM->value(CWspeed);
-			cntCWdefWPM->value(defCWspeed);
-			sldrCWbandwidth->value(CWbandwidth);
-			btnCWrcvTrack->value(CWtrack);
-			cntCWrange->value(CWrange);
-			cntCWlowerlimit->value(CWlowerlimit);
-			cntCWupperlimit->value(CWupperlimit);
-			cntCWlowerlimit->maximum(CWupperlimit - 20);
-			cntCWupperlimit->minimum(CWlowerlimit + 20);
-			cntCWrisetime->value(CWrisetime);
-			cntCWdash2dot->value(CWdash2dot);
-			sldrCWxmtWPM->minimum(CWlowerlimit);
-			sldrCWxmtWPM->maximum(CWupperlimit);
-			btnQSK->value(QSK);
-			cntPreTiming->maximum((int)(2400/CWspeed)/2.0); 
-			cntPreTiming->value(CWpre);
-			cntPostTiming->maximum((int)(2400/CWspeed)/2.0);
-			cntPostTiming->value(CWpost);
-			btnCWID->value(CWid);
-			
-			selHellFont->value(feldfontnbr);
-			btnFeldHellIdle->value(FELD_IDLE);
-			
-			string bandsfname = HomeDir;
-			bandsfname.append("frequencies.def");
-			ifstream bandsfile(bandsfname.c_str(), ios::in);
-			if (bandsfile) {
-				string sBand;
-				cboBand->add(" ");
-				while (!bandsfile.eof()) {
-					sBand = "";
-					bandsfile >> sBand; bandsfile.ignore();
-					if (sBand.length() > 0)
-						cboBand->add(sBand.c_str());
-				}
-				bandsfile.close();
-			} else {
-				int i = 0;
-				while (szBands[i]) {
-					cboBand->add((char *)szBands[i]);
-					i++;
-				}
-			}
-			btnQRZnotavailable->value(0);
-			btnQRZsocket->value(0);
-			btnQRZcdrom->value(0);
-			if (QRZ == 0)
-				btnQRZnotavailable->value(1);
-			else if (QRZ == 1)
-				btnQRZsocket->value(1);
-			else
-				btnQRZcdrom->value(1);
-			
-			btnRTTY_USB->value(RTTY_USB);
-			btnsendid->value(sendid);
-			btnsendvideotext->value(sendtextid);
-			
-			valRcvMixer->value(RcvMixer);
-			valXmtMixer->value(XmtMixer);
-			valPCMvolume->value(PCMvolume);
-            btnMicIn->value(MicIn);
-            btnLineIn->value(LineIn);
-
-            btnAudioIO[0]->value(0);
-            btnAudioIO[0]->value(0);
-            btnAudioIO[btnAudioIOis]->value(1);
-
-            menuOSSDev->value(OSSdevice.c_str());
-            menuPADev->value(PAdevice.c_str());
-            if (btnAudioIOis == 1)
-                menuPADev->activate();
-
-            btnMixer->value(EnableMixer);
-            resetMixerControls();
-            menuMix->value(MXdevice.c_str());
-
-	    if (sample_rate) {
-		    char s[6+1];
-		    snprintf(s, sizeof(s), "%d", sample_rate);
-		    menuSampleRate->value(menuSampleRate->find_item(s));
-	    }
-	    else
-		    menuSampleRate->value(0);
-
-			cntRxRateCorr->value(RX_corr);
-			cntTxRateCorr->value(TX_corr);
-			cntTxOffset->value(TxOffset);
-#ifdef USE_BOTH_TEXT_WIDGETS
-			btntextwidgets->value(alt_text_widgets);
-			btntextwidgets->activate();
-#else
-//			alt_text_widgets = true;
-			btntextwidgets->deactivate();
-#endif			
-		FL_UNLOCK();
-
-		enableMixer(EnableMixer);
+	FL_LOCK();
+	inpMyCallsign->value(myCall.c_str());
+	inpMyName->value(myName.c_str());
+	inpMyQth->value(myQth.c_str());
+	inpMyLocator->value(myLocator.c_str());
+	UseLeadingZeros = btnUseLeadingZeros->value();
+	ContestStart = (int)nbrContestStart->value();
+	ContestDigits = (int)nbrContestDigits->value();
 		
-		ReceiveText->setFont((Fl_Font)Fontnbr);
-		ReceiveText->setFontSize(FontSize);
-	
-		TransmitText->setFont((Fl_Font)Fontnbr);
-		TransmitText->setFontSize(FontSize);
-
-		wf->setPrefilter(wfPreFilter);
-
-		for (int i = 0; i < 9; i++) {
-			palette[i].R = (uchar)cfgpal[i].R;
-			palette[i].G = (uchar)cfgpal[i].G;
-			palette[i].B = (uchar)cfgpal[i].B;
-		}
-		wf->setcolors();
-		setColorButtons();
-
-		return 1;
-	} else {
-		for (int i = 0; i < 9; i++) {
-			palette[i].R = (uchar)cfgpal[i].R;
-			palette[i].G = (uchar)cfgpal[i].G;
-			palette[i].B = (uchar)cfgpal[i].B;
-		}
-		wf->setcolors();
-		setColorButtons();
+	txtSecondary->value(secText.c_str());
+	valDominoEX_BW->value(DOMINOEX_BW);
+			
+	for (int i = 0; i < 5; i++) {
+		btnPTT[i]->value(0);
+		btnPTT[i]->activate();
 	}
-	return 0;
+	btnPTT[btnPTTis]->value(1);
+#if !USE_HAMLIB
+	btnPTT[1]->deactivate();
+	chkUSEHAMLIB->deactivate();
+    inpRIGdev->hide();
+    mnuBaudRate->hide();
+    cboHamlibRig->hide();
+#else
+    btnPTT[1]->activate();
+	chkUSEHAMLIB->activate();
+	inpRIGdev->show();
+	mnuBaudRate->show();
+    cboHamlibRig->show();
+	cboHamlibRig->value(HamRigName.c_str());
+#endif
+	btnRTSptt->value(RTSptt);
+	btnDTRptt->value(DTRptt);
+	btnRTSplusV->value(RTSplus);
+	btnDTRplusV->value(DTRplus);
+
+	inpTTYdev->value(PTTdev.c_str());
+
+	if(chkUSEMEMMAPis) {
+		chkUSEMEMMAP->value(1); chkUSEHAMLIB->value(0); chkUSERIGCAT->value(0);
+		cboHamlibRig->deactivate();
+		inpRIGdev->deactivate();
+		mnuBaudRate->deactivate();
+		btnPTT[1]->deactivate(); btnPTT[2]->activate(); btnPTT[3]->deactivate();
+	} else if (chkUSEHAMLIBis) {
+		chkUSEMEMMAP->value(0); chkUSERIGCAT->value(0); chkUSEHAMLIB->value(1);
+		cboHamlibRig->activate();
+		inpRIGdev->activate();
+		mnuBaudRate->activate();
+		btnPTT[1]->activate(); btnPTT[2]->deactivate(); btnPTT[3]->deactivate();
+	} else if (chkUSERIGCATis) {
+		chkUSEMEMMAP->value(0); chkUSEHAMLIB->value(0); chkUSERIGCAT->value(1);
+		cboHamlibRig->deactivate();
+		inpRIGdev->deactivate();
+		mnuBaudRate->deactivate();
+		btnPTT[1]->deactivate(); btnPTT[2]->deactivate(); btnPTT[3]->activate();
+	} else {
+		chkUSEMEMMAP->value(0); chkUSEHAMLIB->value(0); chkUSERIGCAT->value(0);
+		btnPTT[1]->deactivate(); btnPTT[2]->deactivate(); btnPTT[3]->deactivate();
+	}
+
+	inpRIGdev->value(HamRigDevice.c_str());
+	mnuBaudRate->value(HamRigBaudrate);
+
+	valCWsweetspot->value(CWsweetspot);
+	valRTTYsweetspot->value(RTTYsweetspot);
+	valPSKsweetspot->value(PSKsweetspot);
+	btnStartAtSweetSpot->value(StartAtSweetSpot);
+	btnPSKmailSweetSpot->value(PSKmailSweetSpot);
+	cntSearchRange->value(SearchRange);
+	cntServerOffset->value(ServerOffset);
+	cntACQsn->value(ACQsn);
+			
+	btnCursorBWcolor->color(
+		fl_rgb_color(cursorLineRGBI.R, cursorLineRGBI.G, cursorLineRGBI.B) );
+	btnCursorCenterLineColor->color(
+		fl_rgb_color(cursorCenterRGBI.R, cursorCenterRGBI.G, cursorCenterRGBI.B) );
+	btnBwTracksColor->color(
+		fl_rgb_color(bwTrackRGBI.R, bwTrackRGBI.G, bwTrackRGBI.B) );
+				
+	cntCWweight->value(CWweight);
+	sldrCWxmtWPM->value(CWspeed);
+	cntCWdefWPM->value(defCWspeed);
+	sldrCWbandwidth->value(CWbandwidth);
+	btnCWrcvTrack->value(CWtrack);
+	cntCWrange->value(CWrange);
+	cntCWlowerlimit->value(CWlowerlimit);
+	cntCWupperlimit->value(CWupperlimit);
+	cntCWlowerlimit->maximum(CWupperlimit - 20);
+	cntCWupperlimit->minimum(CWlowerlimit + 20);
+	cntCWrisetime->value(CWrisetime);
+	cntCWdash2dot->value(CWdash2dot);
+	sldrCWxmtWPM->minimum(CWlowerlimit);
+	sldrCWxmtWPM->maximum(CWupperlimit);
+	btnQSK->value(QSK);
+	cntPreTiming->maximum((int)(2400/CWspeed)/2.0); 
+	cntPreTiming->value(CWpre);
+	cntPostTiming->maximum((int)(2400/CWspeed)/2.0);
+	cntPostTiming->value(CWpost);
+	btnCWID->value(CWid);
+			
+	selHellFont->value(feldfontnbr);
+	btnFeldHellIdle->value(FELD_IDLE);
+			
+	string bandsfname = HomeDir;
+	bandsfname.append("frequencies.def");
+	ifstream bandsfile(bandsfname.c_str(), ios::in);
+	if (bandsfile) {
+		string sBand;
+		cboBand->add(" ");
+		while (!bandsfile.eof()) {
+			sBand = "";
+			bandsfile >> sBand; bandsfile.ignore();
+			if (sBand.length() > 0)
+				cboBand->add(sBand.c_str());
+		}
+		bandsfile.close();
+	} else {
+		int i = 0;
+		while (szBands[i]) {
+			cboBand->add((char *)szBands[i]);
+			i++;
+		}
+	}
+	btnQRZnotavailable->value(0);
+	btnQRZsocket->value(0);
+	btnQRZcdrom->value(0);
+	btnHAMCALLsocket->value(0);
+	if (QRZ == 0)
+		btnQRZnotavailable->value(1);
+	else if (QRZ == 1)
+		btnQRZsocket->value(1);
+	else if (QRZ == 2)
+		btnQRZcdrom->value(1);
+	else if (QRZ == 3)
+		btnHAMCALLsocket->value(1);
+			
+	btnRTTY_USB->value(RTTY_USB);
+	btnsendid->value(sendid);
+	btnsendvideotext->value(sendtextid);
+			
+	valPCMvolume->value(PCMvolume);
+	btnMicIn->value(MicIn);
+	btnLineIn->value(LineIn);
+
+	menuOSSDev->value(OSSdevice.c_str());
+	menuPortInDev->value(PortInDevice.c_str());
+	menuPortOutDev->value(PortOutDevice.c_str());
+	inpPulseServer->value(PulseServer.c_str());
+
+	btnMixer->value(EnableMixer);
+	resetMixerControls();
+	menuMix->value(MXdevice.c_str());
+
+
+	char sr[6+1];
+	if (in_sample_rate == SAMPLE_RATE_UNSET &&
+		(in_sample_rate = sample_rate) == SAMPLE_RATE_UNSET)
+		in_sample_rate = SAMPLE_RATE_AUTO;
+	else if (in_sample_rate > SAMPLE_RATE_OTHER)
+		snprintf(sr, sizeof(sr), "%d", in_sample_rate);
+	if (in_sample_rate <= SAMPLE_RATE_NATIVE)
+		menuInSampleRate->value(in_sample_rate);
+	else
+		menuInSampleRate->value(menuInSampleRate->find_item(sr));
+
+	if (out_sample_rate == SAMPLE_RATE_UNSET &&
+		(out_sample_rate = sample_rate) == SAMPLE_RATE_UNSET)
+		out_sample_rate = SAMPLE_RATE_AUTO;
+	else if (out_sample_rate > SAMPLE_RATE_OTHER)
+		snprintf(sr, sizeof(sr), "%d", out_sample_rate);
+	if (out_sample_rate <= SAMPLE_RATE_NATIVE)
+		menuOutSampleRate->value(out_sample_rate);
+	else
+		menuOutSampleRate->value(menuOutSampleRate->find_item(sr));
+
+
+	cntRxRateCorr->value(RX_corr);
+	cntTxRateCorr->value(TX_corr);
+	cntTxOffset->value(TxOffset);
+#ifdef USE_BOTH_TEXT_WIDGETS
+	btntextwidgets->value(alt_text_widgets);
+	btntextwidgets->activate();
+#else
+	btntextwidgets->deactivate();
+#endif			
+	FL_UNLOCK();
+
+	enableMixer(EnableMixer);
+		
+	ReceiveText->setFont((Fl_Font)RxFontnbr);
+	ReceiveText->setFontSize(RxFontsize);
+	
+	TransmitText->setFont((Fl_Font)TxFontnbr);
+	TransmitText->setFontSize(TxFontsize);
+
+	wf->setPrefilter(wfPreFilter);
+
+	for (int i = 0; i < 9; i++) {
+		palette[i].R = (uchar)cfgpal[i].R;
+		palette[i].G = (uchar)cfgpal[i].G;
+		palette[i].B = (uchar)cfgpal[i].B;
+	}
+	wf->setcolors();
+	setColorButtons();
+
+	return 1;
 }
 
 void configuration::initOperator() {
@@ -1343,7 +1437,6 @@ void configuration::initInterface() {
 		wf->setQSY(1);
 		activate_rig_menu_item(false);
 	} else if (chkUSERIGCATis) { // start the rigCAT thread
-//		btnPTT[3]->activate();
 		if (rigCAT_init() == false) {
 			wf->USB(true);
 			cboBand->show();
@@ -1359,7 +1452,6 @@ void configuration::initInterface() {
 		}
 #if USE_HAMLIB
 	} else if (chkUSEHAMLIBis) { // start the hamlib thread
-//		btnPTT[1]->activate();
 		if (hamlib_init(btnPTTis == 1 ? true : false) == false) {
 			wf->USB(true);
 			cboBand->show();
