@@ -6,9 +6,10 @@
 
 #include "fl_digi.h"
 #include "configuration.h"
-#include "Config.h"
+#include "confdialog.h"
 #include "logger.h"
 #include "newinstall.h"
+#include "globals.h"
 
 #include <FL/Fl.H>
 #include "File_Selector.h"
@@ -38,7 +39,9 @@ void pMYNAME(string &, size_t &);
 void pMYQTH(string &, size_t &);
 void pMYRST(string &, size_t &);
 void pLDT(string &, size_t &);
+void pILDT(string &, size_t &);
 void pZDT(string &, size_t &);
+void pIZDT(string &, size_t &);
 void pID(string &, size_t &);
 void pTEXT(string &, size_t &);
 void pCWID(string &, size_t &);
@@ -50,6 +53,7 @@ void pDECR(string &, size_t &);
 void pINCR(string &, size_t &);
 void pLOG(string &, size_t &);
 void pTIMER(string &, size_t &);
+void pMODEM(string &, size_t &);
 
 MTAGS mtags[] = {
 {"<CALL>",		pCALL},
@@ -65,7 +69,9 @@ MTAGS mtags[] = {
 {"<MYQTH>",		pMYQTH},
 {"<MYRST>",		pMYRST},
 {"<LDT>",		pLDT},
+{"<ILDT>",		pILDT},
 {"<ZDT>",		pZDT},
+{"<IZDT>",		pIZDT},
 {"<ID>",		pID},
 {"<TEXT>",		pTEXT},
 {"<CWID>",		pCWID},
@@ -77,6 +83,7 @@ MTAGS mtags[] = {
 {"<INCR>",		pINCR},
 {"<LOG>",		pLOG},
 {"<TIMER>",		pTIMER},
+{"<MODEM>",		pMODEM},
 {0, 0}
 };
 
@@ -156,6 +163,17 @@ void pLDT(string &s, size_t &i)
 	s.replace( i, 5, szDt);
 }
 
+void pILDT(string &s, size_t &i)
+{
+	char szDt[80];
+	time_t tmptr;
+	tm sTime;
+	time (&tmptr);
+	localtime_r(&tmptr, &sTime);
+	mystrftime(szDt, 79, "%Y-%m-%d %H:%M:%S%z", &sTime);
+	s.replace( i, 6, szDt);
+}
+
 void pZDT(string &s, size_t &i)
 {
 	char szDt[80];
@@ -167,6 +185,17 @@ void pZDT(string &s, size_t &i)
 	s.replace( i, 5, szDt);
 }
 
+void pIZDT(string &s, size_t &i)
+{
+	char szDt[80];
+	time_t tmptr;
+	tm sTime;
+	time (&tmptr);
+	gmtime_r(&tmptr, &sTime);
+	mystrftime(szDt, 79, "%Y-%m-%d %H:%M:%SZ", &sTime);
+	s.replace( i, 6, szDt);
+}
+
 void pID(string &s, size_t &i)
 {
 	progdefaults.macroid = true;
@@ -209,7 +238,7 @@ void pCNTR(string &s, size_t &i)
 	int  contestval;
 	contestval = contest_count.count + progdefaults.ContestStart;
 	contest_count.Format(progdefaults.ContestDigits, progdefaults.UseLeadingZeros);
-	sprintf(contest_count.szCount, contest_count.fmt.c_str(), contestval);
+	snprintf(contest_count.szCount, sizeof(contest_count.szCount), contest_count.fmt.c_str(), contestval);
 	s.replace (i, 6, contest_count.szCount);
 }
 
@@ -219,8 +248,8 @@ void pDECR(string &s, size_t &i)
 	contest_count.count--;
 	contestval = contest_count.count + progdefaults.ContestStart;
 	s.replace (i, 6, "");
-	sprintf(contest_count.szCount, contest_count.fmt.c_str(), contestval);
-	sprintf(contest_count.szDisp,"Next Nbr: %s", contest_count.szCount);
+	snprintf(contest_count.szCount, sizeof(contest_count.szCount), contest_count.fmt.c_str(), contestval);
+	snprintf(contest_count.szDisp, sizeof(contest_count.szDisp), "Next Nbr: %s", contest_count.szCount);
 	put_status(contest_count.szDisp);
 }
 
@@ -230,8 +259,8 @@ void pINCR(string &s, size_t &i)
 	contest_count.count++;
 	contestval = contest_count.count + progdefaults.ContestStart;
 	s.replace (i, 6, "");
-	sprintf(contest_count.szCount, contest_count.fmt.c_str(), contestval);
-	sprintf(contest_count.szDisp,"Next Nbr: %s", contest_count.szCount);
+	snprintf(contest_count.szCount, sizeof(contest_count.szCount), contest_count.fmt.c_str(), contestval);
+	snprintf(contest_count.szDisp, sizeof(contest_count.szDisp), "Next Nbr: %s", contest_count.szCount);
 	put_status(contest_count.szDisp);
 }
 
@@ -256,6 +285,30 @@ void pTIMER(string &s, size_t &i)
 	progdefaults.useTimer = true;
 }
 
+void pMODEM(string &s, size_t &i)
+{
+	size_t	j, k, 
+			len = s.length();
+	string name;
+
+	if ((j = s.find('>', i)) == string::npos)
+		return;
+	while (++j < len)
+	    if (!isspace(s[j])) break;
+	k = j;
+	while (++k < len)
+	    if (isspace(s[k])  || s[k] == '<') break;
+	name = s.substr(j, k - j);
+	for (int m = 0; m < NUM_MODES; m++) {
+		if (name == mode_info[m].sname) {
+			if (active_modem->get_mode() != mode_info[m].mode)
+				init_modem_sync(mode_info[m].mode);
+			break;
+		}
+	}
+	s.erase(i, k-i);
+}
+
 int MACROTEXT::loadMacros(string filename)
 {
 	string mLine;
@@ -264,8 +317,8 @@ int MACROTEXT::loadMacros(string filename)
 	bool   inMacro = false;
 	int    mNumber = 0;
 	unsigned long int	   crlf; // 64 bit cpu's
-	char   szTemp[10];
 	char   szLine[4096];
+	bool   convert = false;
 	
 	ifstream mFile(filename.c_str());
 	
@@ -282,11 +335,13 @@ int MACROTEXT::loadMacros(string filename)
 		mFile.close();
 		return -1;
 	}
+	if (mLine.find("extended") == string::npos) {
+		convert = true;
+		changed = true;
+	}		
 // clear all of the macros
-	for (int i = 0; i < 20; i++) {
-		sprintf(szTemp,"%d", i+1);
-		name[i] = "Macro ";
-		name[i] = name[i] + szTemp;
+	for (int i = 0; i < MAXMACROS; i++) {
+		name[i] = "";
 		text[i] = "";
 	}
 	inMacro = false;
@@ -298,10 +353,11 @@ int MACROTEXT::loadMacros(string filename)
 		if (mLine.find("/$") == 0) {
 			int idx = mLine.find_first_not_of("0123456789", 3);
 			sscanf((mLine.substr(3, idx - 3)).c_str(), "%d", &mNumber);
-			if (mNumber < 0 || mNumber > 19)
+			if (mNumber < 0 || mNumber > (MAXMACROS - 1))
 				break;
-			name[mNumber] = mLine.substr(idx+1, 9);
-			if (mNumber < 10) {
+			if (convert && mNumber > 9) mNumber += 2;
+            name[mNumber] = mLine.substr(idx+1);
+			if (mNumber < 12) {
 				FL_LOCK_D();
 				btnMacro[mNumber]->label( (macros.name[mNumber]).c_str());
 				FL_UNLOCK_D();
@@ -381,92 +437,12 @@ void MACROTEXT::execute(int n)
 }
 
 string mtext = 
-"//fldigi macro definition file\n\
+"//fldigi macro definition file extended\n\
 // This file defines the macro structe(s) for the digital modem program, fldigi\n\
 // It also serves as a basis for any macros that are written by the user\n\
 //\n\
-// The top line of this file should always be the first line in every macro definition file (.mdf)\n\
-// for the fldigi program to recognize it as such.\n\
-//\n\
-// Macros are short text statements that contain imbedded references to text data used by the\n\
-// program fldigi.  The imbedded references are always prefaced by the carat(^) symbol and consist\n\
-// of single letter codes.  All references to the local system are in lower case and to the remote\n\
-// system or global values are in upper case.\n\
-//\n\
-//\n\
-// <CALL>  remote call\n\
-// <LDT>  local date time Zone\n\
-//     format : %x %H:%M %Z\n\
-//     where %x is preferred short form date ie: MM/DD/YY or DD/MM/YYYY etc\n\
-//           %H is ho with leading 0\n\
-//           %M is minute with leading 0\n\
-//           %Z is abbreviated time zone ie: EDT or GMT\n\
-// <ZDT>  GMT date time Zone\n\
-//     format : %x %H:%M %Z\n\
-// <FREQ>  my frequency\n\
-// <ID>  send Mode Idenfier - waterfall script\n\
-// <TEXT> send video text - waterfall script\n\
-// <CWID> send CW identifer at end of transmission (not for CW)\n\
-// <LOC>  remote locator\n\
-// <LOG>  submit QSO data to logbook program & clear the QSO data fields\n\
-//     Not constrained to a particular position in the macro.\n\
-//     Action takes place when macro is expanded, so effect is seen immediately\n\
-//     after executing the macro which contains this macro reference.\n\
-//\n\
-// <MODE>  my mode\n\
-// <MYCALL>  my call\n\
-// <MYLOC>  my locator\n\
-// <MYNAME>  my name\n\
-// <MYQTH>  my qth\n\
-// <MYRST>  my RST\n\
-// <NAME>  remote name\n\
-// <QTH>  remote qth\n\
-// <RST>  remote RST\n\
-// <RX>  retn to receive\n\
-// <TX>  start transmit\n\
-// <VERSION>  Fldigi + version\n\
-//\n\
-// Contest macro definitions:\n\
-// <CNTR>  substitute the contest counter - no change in value\n\
-// <DECR>  decrement the contest counter - no substitution\n\
-// <INCR>  increment the contest counter - no substitution\n\
-//\n\
-// Autorepeat macro definition:\n\
-// <TIMER>NNN autorepeat this macro after NNN seconds\n\
-// NNN must be terminated by either a space ' ' or a linefeed\n\
-// it can appear anywhere in the macro defintion.\n\
-// see macro # 19 for an example of an auto-cq repeating macro\n\
-//\n\
-//\n\
-// Local references are specified ding the program configation and can be changed during \n\
-// program operation.\n\
-//\n\
-// Remote references are all part of the qso log field definitions and are routinely changed \n\
-// from contact to contact.\n\
-//\n\
-// Global references are to things like Greenwich Mean Time\n\
-//\n\
-// Each new macro begins with a macro specifier line as: /$ nn MACRONAME\n\
-//   where 'nn' specifies the macro number.  Macros numbered 0..9 refer to function key 1 to 10\n\
-//   respectively.  Macros numbered 10..19 refer to \"alt\" function keys 1 to 10.  Undefined Macros\n\
-//   will also contain an empty character string and thus produce no output when invoked.\n\
-// MACRONAME can be as long as you want, however only the first 8 characters will be displayed on\n\
-//   the associated function key button.\n\
-//\n\
-// You can put the macro definition on multiple lines.  These lines will be concatenated\n\
-// into a single line unless you put the new-line pair \"\\n\" at the end of the line\n\
-// that you want to terminate a line ding transmission.\n\
-//\n\
-// Macro definitions do not need to be in numerical order.\n\
-// Macro definitions may be skipped or you can truncate the file to less than\n\
-// the full macro set of 20.\n\
-//\n\
-// I recommend using a copy of this file suitably modified for all of yo macro\n\
-// definition files.  Just fill in the appropriate fields and delete those you do not\n\
-// need for that macro set.\n\
-//\n\
-//\n\
-// Let the Macros begin!\n\
+// The top line of this file should always be the first line in every macro \n\
+// definition file (.mdf) for the fldigi program to recognize it as such.\n\
 //\n\
 ";
 
@@ -474,7 +450,7 @@ void MACROTEXT::saveMacros(string fname) {
 	string work;
 	ofstream mfile(fname.c_str());
 	mfile << mtext;
-	for (int i = 0; i < 20; i++) {
+	for (int i = 0; i < MAXMACROS; i++) {
 		mfile << "\n//\n// Macro # " << i+1 << "\n";
 		mfile << "/$ " << i << " " << macros.name[i].c_str() << "\n";
 		work = macros.text[i];
