@@ -4,6 +4,8 @@
 // Copyright (C) 2006
 //		Dave Freese, W1HKJ
 //		Leigh Klotz, WA5ZNU
+// Copyright (C) 2008
+//              Stelios Bounanos, M0GLD
 //
 // This file is part of fldigi.
 //
@@ -40,6 +42,7 @@
 #include <sys/ioctl.h>
 #include <math.h>
 #include <ctype.h>
+#include <errno.h>
 
 #include <FL/fl_ask.H>
 
@@ -50,7 +53,7 @@
 
 #include "qrzcall.h"
 #include "main.h"
-#include "Config.h"
+#include "confdialog.h"
 #include "fl_digi.h"
 #include "qrzlib.h"
 
@@ -58,41 +61,31 @@
 
 using namespace std;
 
-static int rotoroffset = 0;
+int rotoroffset = 0;
 
-static string xmlpage = "";
-static string sessionpage = "";
-static string host = "online.qrz.com";
-static string detail;
-static string qrzSessionKey;
-static string qrzalert;
-static string qrzerror;
-static string callsign = "";
-static string qrzname;
-static string qrzaddr1;
-static string qrzaddr2;
-static string qrzstate;
-static string qrzzip;
-static string qrzcountry;
-static string qrzborn;
-static string qrzfname;
-static string qrzqth;
-static string qrzgrid;
-static string qrzlatd;
-static string qrzlond;
-static string qrznotes;
+string host = "online.qrz.com";
+string qrzSessionKey;
+string qrzalert;
+string qrzerror;
+string callsign = "";
+string qrzname;
+string qrzaddr1;
+string qrzaddr2;
+string qrzstate;
+string qrzzip;
+string qrzcountry;
+string qrzborn;
+string qrzfname;
+string qrzqth;
+string qrzgrid;
+string qrzlatd;
+string qrzlond;
+string qrznotes;
 
-static const char *error[] = {
-	"OK",								// err 0
-	"Host not found",					// err 1
-	"Not an IP host!",					// err 2
-	"No http service",					// err 3
-	"Cannot open socket",				// err 4
-	"Cannot Connect to www.qrz.com", 	// err 5
-	"Socket write error",				// err 6
-	"Socket timeout",					// err 7
-	"Socket select error"				// err 8
-};
+const char* error_string;
+
+enum QUERYTYPE { NONE, QRZCD, QRZNET, HAMCALLNET };
+QUERYTYPE DB_query = NONE;
 
 enum TAG { \
 	IGNORE,	KEY,	ALERT,	ERROR,	CALL, \
@@ -100,26 +93,41 @@ enum TAG { \
 	ZIP,	COUNTRY,LATD,	LOND,	GRID, \
 	DOB };
 
-static char rbuffer[32768];
+int qrzdummy;
+Fl_Thread QRZ_thread;
+bool QRZ_exit = false;
+bool QRZ_enabled = false;
 
-static fd_set readfds, testfds;
-static struct timeval timeout;
-static int sockfd = -1;
-static int result;
-static struct sockaddr_in address;
-static struct hostent *hostinfo;
-static struct servent *servinfo;
+static void *CALLSIGNloop(void *args);
+
+bool parseSessionKey();
+bool parse_xml();
+
+int connect_to_server(const char* node, const char* service, int* fd);
+ssize_t read_from_server(int fd, const string& request, string& reply, struct timeval* timeout);
+
+bool getSessionKey(string& sessionpage);
+bool QRZGetXML(string& xmlpage);
+int  bearing(const char *, const char *);
+void qra(const char *, double &, double &);
+void QRZ_disp_result();
+void QRZ_COM_query();
+void HAMCALL_COM_query();
+void QRZ_CD_query();
+void QRZinit(void);
+void QRZclose(void);
+void qthappend(string &qth, string &datum);
+void QRZAlert();
+bool QRZLogin(string& sessionpage);
+void QRZquery();
+void parse_html(const string& htmlpage);
+bool HAMCALLget(string& htmlpage);
+void HAMCALLquery();
 
-static int qrzdummy;
-static Fl_Thread QRZ_thread;
-static bool QRZ_exit = false;
-static bool QRZ_enabled = false;
-static bool QRZ_query = false;
-static void *QRZloop(void *args);
 
 QRZ *qCall;
 
-bool parseSessionKey()
+bool parseSessionKey(const string& sessionpage)
 {
 	IrrXMLReader* xml = createIrrXMLReader(new IIrrXMLStringReader(sessionpage));
 	TAG tag=IGNORE;
@@ -165,11 +173,11 @@ bool parseSessionKey()
 		}
 	}
 	delete xml;
-	return 0;
+	return true;
 } 
 
 
-bool parse_xml()
+bool parse_xml(const string& xmlpage)
 {
 	IrrXMLReader* xml = createIrrXMLReader(new IIrrXMLStringReader(xmlpage));
 
@@ -303,162 +311,159 @@ bool parse_xml()
 
 // delete the xml parser after usage
 	delete xml;
-	return 0;
+	return true;
 }
 
-int getSessionKey()
+// Open a stream socket, connect it to "service" running on "node", and copy it
+// to *fd. Return 0 if successful, < 0 if getaddrinfo failed, or errno if there
+// was some other error.
+int connect_to_server(const char* node, const char* service, int* fd)
 {
-	hostinfo = gethostbyname(host.c_str());
-	if(!hostinfo)
-		return 1;
-	if(hostinfo->h_addrtype != AF_INET)
-		return 2;
-	servinfo = getservbyname("http", "tcp");
-	if(!servinfo)
-		return 3;
+	struct addrinfo hints, *ai, *aip;
 
-	sockfd = socket(AF_INET, SOCK_STREAM, 0);
-	
-	if (sockfd == -1)
-		return 4;
-	address.sin_family = AF_INET;
-	address.sin_port = servinfo->s_port;
-	address.sin_addr = *(struct in_addr *)*hostinfo->h_addr_list;
+	memset(&hints, 0, sizeof(hints));
+#ifdef AI_ADDRCONFIG
+	hints.ai_flags = AI_ADDRCONFIG;
+#endif
+	hints.ai_family = AF_UNSPEC;
+	hints.ai_socktype = SOCK_STREAM;
 
-	result = connect(sockfd, (struct sockaddr *)&address, sizeof(address));
-	if(result == -1) {
-		close(sockfd);
-		return 5;
-	}
-
-	{
-		detail = "GET /bin/xml?username=";
-		detail += progdefaults.QRZusername;
-		detail += ";password=";
-		detail += progdefaults.QRZuserpassword;
-		detail += ";version=";
-		detail += PACKAGE_NAME;
-		detail += "/";
-		detail += PACKAGE_VERSION;
-		detail += " HTTP/1.0\n";
-		detail += "Host: ";
-		detail += host;
-		detail += "\n";
-		detail += "Connection: close\n";
-		detail += "\n";
-	}
-  
-	
-	result = write(sockfd, detail.c_str() , detail.length());
-	if (result != (int)detail.length()) {
-		close(sockfd);
-		return 6;
-	}
-
-	FD_ZERO(&readfds);
-	FD_SET(sockfd, &readfds);
-	
-	while (1) {
-		testfds = readfds;
-		timeout.tv_sec = 5;		// timeout = 5 seconds
-		timeout.tv_usec = 0;
-		result = select(FD_SETSIZE, &testfds, (fd_set *)0, (fd_set *)0, &timeout);
-		if (result == 0) {
+	int res;
+	if ((res = getaddrinfo(node, service, &hints, &ai)) < 0)
+		return res;
+	for (aip = ai; aip; aip = ai->ai_next) { // use the first one that works
+		if ((*fd = socket(aip->ai_family, aip->ai_socktype, aip->ai_protocol)) == -1)
+			continue;
+		if (connect(*fd, aip->ai_addr, aip->ai_addrlen) == 0)
 			break;
-		}
-		if (result == -1) {
-			close(sockfd);
-			return 8;
-		}
-		if (FD_ISSET(sockfd, &testfds)) {
-			memset(rbuffer, 0, 32768);
-			result = read(sockfd, rbuffer, sizeof(rbuffer));
-			if (result <= 0) break;
-			sessionpage += rbuffer;
-		} else {
-			break;
-		}
 	}
-    
-	close(sockfd);
-	return 0;
+	if (!aip) { // no usable address found
+		res = errno;
+		if (*fd >= 0)
+			close(*fd);
+	}
+
+	freeaddrinfo(ai);
+	return res;
 }
 
-int QRZGetXML()
+// Write "request" to socket fd, append reply to "reply". Wait a maximum of
+// "timeout" for each operation. Return the number of bytes read, or -ETIMEDOUT
+// if a read or write timed out, or -errno if there was some other error.
+ssize_t read_from_server(int fd, const string& request, string& reply, struct timeval* timeout)
 {
-	hostinfo = gethostbyname(host.c_str());
-	if(!hostinfo)
-		return 1;
-	if(hostinfo->h_addrtype != AF_INET)
-		return 2;
-	servinfo = getservbyname("http", "tcp");
-	if(!servinfo)
-		return 3;
+	char rbuffer[32768];
+	fd_set rwset;
+	ssize_t res, n;
 
-	sockfd = socket(AF_INET, SOCK_STREAM, 0);
-	
-	if (sockfd == -1)
-		return 4;
-	address.sin_family = AF_INET;
-	address.sin_port = servinfo->s_port;
-	address.sin_addr = *(struct in_addr *)*hostinfo->h_addr_list;
+	// write request
+	n = 0;
+	for (;;) {
+		FD_ZERO(&rwset);
+		FD_SET(fd, &rwset);
+		res = select(fd + 1, 0, &rwset, 0, timeout);
+		if (res == -1)
+			return -errno;
+		else if (res == 0)
+			return -ETIMEDOUT;
 
-	result = connect(sockfd, (struct sockaddr *)&address, sizeof(address));
-	if(result == -1) {
-		close(sockfd);
-		return 5;
-	}
-
-	{
-		detail = "GET /bin/xml?s=";
-		detail += qrzSessionKey;
-		detail += ";callsign=";
-		detail += callsign;
-		detail += " HTTP/1.0\n";
-		detail += "Host: ";
-		detail += host;
-		detail += "\n";
-		detail += "Connection: close\n";
-		detail += "\n";
-	}
-	
-	result = write(sockfd, detail.c_str() , detail.length());
-	if (result != (int)detail.length()) {
-		close(sockfd);
-		return 6;
-	}
-
-	FD_ZERO(&readfds);
-	FD_SET(sockfd, &readfds);
-	
-	while (1) {
-		testfds = readfds;
-		timeout.tv_sec = 5;		// timeout = 5 seconds
-		timeout.tv_usec = 0;
-		result = select(FD_SETSIZE, &testfds, (fd_set *)0, (fd_set *)0, &timeout);
-		if (result == 0) {
+		res = write(fd, request.c_str() + n, request.length() - n);
+		if (res > 0)
+			n += res;
+		else
+			return -errno;
+		if ((size_t)n == request.length())
 			break;
+	}
+
+	// read reply
+	n = 0;
+	for (;;) {
+		FD_ZERO(&rwset);
+		FD_SET(fd, &rwset);
+		res = select(fd + 1, &rwset, 0, 0, timeout);
+		if (res == -1)
+			return -errno;
+		else if (res == 0)
+			return -ETIMEDOUT;
+
+		res = read(fd, rbuffer, sizeof(rbuffer));
+		if (res > 0) {
+			reply.append(rbuffer, (unsigned)res);
+			n += res;
 		}
-		if (result == -1) {
-			close(sockfd);
-			return 8;
-		}
-		if (FD_ISSET(sockfd, &testfds)) {
-			memset(rbuffer, 0, 32768);
-			result = read(sockfd, rbuffer, sizeof(rbuffer));
-			if (result <= 0) break;
-			xmlpage += rbuffer;
-		} else {
+		else {
+			if (res < 0)
+				return -errno;
 			break;
 		}
 	}
-    
-	close(sockfd);
-	return 0;
+
+	return n;
 }
 
-int bearing(const char *, const char *);
-void qra(const char *, double &, double &);
+bool getSessionKey(string& sessionpage)
+{
+	int r, sockfd;
+	if ((r = connect_to_server(host.c_str(), "http", &sockfd)) != 0) {
+		error_string = r > 0 ? strerror(r) : gai_strerror(r);
+		return false;
+	}
+
+	string detail;
+	detail =  "GET /bin/xml?username=";
+	detail += progdefaults.QRZusername;
+	detail += ";password=";
+	detail += progdefaults.QRZuserpassword;
+	detail += ";version=";
+	detail += PACKAGE_NAME;
+	detail += "/";
+	detail += PACKAGE_VERSION;
+	detail += " HTTP/1.0\n";
+	detail += "Host: ";
+	detail += host;
+	detail += "\n";
+	detail += "Connection: close\n";
+	detail += "\n";
+
+	struct timeval timeout = { 5, 0 }; // timeout = 5 seconds
+	ssize_t nread = read_from_server(sockfd, detail, sessionpage, &timeout);
+	close(sockfd);
+	if (nread < 0 && nread != -ETIMEDOUT)
+		error_string = strerror(-nread);
+
+	// for some strange reason we return successfully even if we time out
+	return nread == -ETIMEDOUT || nread > 0;
+}
+
+bool QRZGetXML(string& xmlpage)
+{
+	int r, sockfd;
+	if ((r = connect_to_server(host.c_str(), "http", &sockfd)) != 0) {
+		error_string = r > 0 ? strerror(r) : gai_strerror(r);
+		return false;
+	}
+
+	string detail;
+	detail = "GET /bin/xml?s=";
+	detail += qrzSessionKey;
+	detail += ";callsign=";
+	detail += callsign;
+	detail += " HTTP/1.0\n";
+	detail += "Host: ";
+	detail += host;
+	detail += "\n";
+	detail += "Connection: close\n";
+	detail += "\n";
+
+	struct timeval timeout = { 5, 0 }; // timeout = 5 seconds
+	ssize_t nread = read_from_server(sockfd, detail, xmlpage, &timeout);
+	close(sockfd);
+	if (nread < 0)
+		error_string = strerror(-nread);
+
+	return nread > 0;
+}
 
 int bearing(const char *myqra, const char *dxqra) {
 	double	lat1, lat1r, lon1;
@@ -505,15 +510,15 @@ void QRZ_disp_result()
 {
    FL_LOCK();
    {
-           if (qrzfname.length() > 0) {
-           int spacePos = qrzfname.find(" ");
+       if (qrzfname.length() > 0) {
+           string::size_type spacePos = qrzfname.find(" ");
 //    if fname is "ABC" then display "ABC"
 // or if fname is "X Y" then display "X Y"
-           if (spacePos ==-1 || (spacePos == 1)) {
+           if (spacePos == string::npos || (spacePos == 1)) {
                inpName->value(qrzfname.c_str());
            }
 // if fname is "ABC Y" then display "ABC"
-           else if (spacePos == ((int)qrzfname.length())-2) {
+           else if (spacePos == qrzfname.length() - 2) {
                string fname="";
                fname.assign(qrzfname, 0, spacePos);
                inpName->value(fname.c_str());
@@ -555,13 +560,25 @@ void QRZ_COM_query()
 			return;
 	}
 
-	xmlpage = "";
-	QRZ_query = true;
+	DB_query = QRZNET;
 	FL_LOCK();
 	inpNotes->value(" *** Request sent to qrz.com ***");
 	FL_UNLOCK();
 }
 
+void HAMCALL_COM_query()
+{
+	if (!QRZ_enabled) {
+		QRZinit();
+		if (!QRZ_enabled)
+			return;
+	}
+	DB_query = HAMCALLNET;
+	FL_LOCK();
+	inpNotes->value(" *** Request sent to www.hamcall.net ***");
+	FL_UNLOCK();	
+}
+
 void QRZ_CD_query()
 {
 	char srch[20];
@@ -594,7 +611,227 @@ void QRZ_CD_query()
 	QRZ_disp_result();
 }
 
+void QRZinit(void)
+{
+	QRZ_enabled = false;
+	if (fl_create_thread(QRZ_thread, CALLSIGNloop, &qrzdummy) < 0) {
+		fl_message("QRZ init: pthread_create failed");
+		return;
+	} 
+	QRZ_enabled = true;
+}
+
+void QRZclose(void)
+{
+	if (!QRZ_enabled) return;
+// tell the QRZ thread to kill it self
+	QRZ_exit = true;
+// and then wait for it to die
+	fl_join(QRZ_thread);
+	QRZ_enabled = false;
+	QRZ_exit = false;
+}
+
+void qthappend(string &qth, string &datum) {
+	if (datum.empty()) return;
+	if (!qth.empty()) qth += ", ";
+	qth += datum;
+}
+
+void QRZAlert()
+{
+// test alert first as QRZ.com requires it be shown
+	if (!qrzalert.empty()) {
+		FL_LOCK();
+		inpNotes->value(qrzalert.c_str());
+		qrzalert="";
+		FL_UNLOCK();
+	} else if (!qrzerror.empty()) {
+		FL_LOCK();
+		inpNotes->value(qrzerror.c_str());
+		qrzerror="";
+		FL_UNLOCK();
+	}
+}
+
+bool QRZLogin(string& sessionpage) {
+	bool ok = true;
+	if (qrzSessionKey.empty()) {
+		ok = getSessionKey(sessionpage);
+		if (ok) ok = parseSessionKey(sessionpage);
+	}
+	if (!ok) {
+		QRZAlert();
+	}
+	return ok;
+}
+
 void QRZquery()
+{
+	bool ok = true;
+
+	string qrzpage;
+
+	if (qrzSessionKey.empty())
+		ok = QRZLogin(qrzpage);
+	if (ok)
+		ok = QRZGetXML(qrzpage);
+	if (ok) {
+		if (qrzSessionKey.empty())
+			ok = QRZLogin(qrzpage);
+		if (ok)
+			ok = QRZGetXML(qrzpage);
+	}
+	if (ok) {
+		parse_xml(qrzpage);
+		if (!qrzalert.empty()) {
+			FL_LOCK();
+			inpNotes->value(qrzalert.c_str());
+			qrzalert="";
+			FL_UNLOCK();
+		} else if (!qrzerror.empty()) {
+			FL_LOCK();
+			inpNotes->value(qrzerror.c_str());
+			qrzerror="";
+			FL_UNLOCK();
+		} else {
+			qrzqth = "";
+			qthappend(qrzqth, qrzaddr1);
+			qthappend(qrzqth, qrzaddr2);
+			qthappend(qrzqth, qrzstate);
+			qthappend(qrzqth, qrzcountry);
+			QRZ_disp_result();
+		}
+	} 
+	if (!ok) {
+		FL_LOCK();
+		inpNotes->value(error_string);
+		FL_UNLOCK();
+	}
+}
+
+// Hamcall specific functions
+
+#define HAMCALL_HOST "www.hamcall.net"
+#define HAMCALL_CALL 181
+#define HAMCALL_FIRST 184
+#define HAMCALL_CITY 191
+#define HAMCALL_STATE 192
+#define HAMCALL_GRID 202
+#define HAMCALL_DOB 194
+
+void parse_html(const string& htmlpage)
+{
+	size_t p;
+	qrzborn="";
+	qrzfname="";
+	qrzqth="";
+	qrzgrid="";
+	qrzlatd="";
+	qrzlond="";
+	qrznotes="";
+	
+	if ((p = htmlpage.find(HAMCALL_FIRST)) != string::npos) {
+		p++;
+		while ((uchar)htmlpage[p] < 128 && p < htmlpage.length() )
+			qrzfname += htmlpage[p++];
+	}
+	if ((p = htmlpage.find(HAMCALL_CITY)) != string::npos) { 
+		p++;
+		while ((uchar)htmlpage[p] < 128 && p < htmlpage.length())
+			qrzqth += htmlpage[p++];
+		qrzqth += ", ";
+	}
+	if ((p = htmlpage.find(HAMCALL_STATE)) != string::npos) { 
+		p++;
+		while ((uchar)htmlpage[p] < 128 && p < htmlpage.length())
+			qrzqth += htmlpage[p++];
+	}
+	if ((p = htmlpage.find(HAMCALL_GRID)) != string::npos) { 
+		p++;
+		while ((uchar)htmlpage[p] < 128 && p < htmlpage.length())
+			qrzgrid += htmlpage[p++];
+	}
+	if ((p = htmlpage.find(HAMCALL_DOB)) != string::npos) { 
+		p++;
+		qrznotes = "DOB: ";
+		while ((uchar)htmlpage[p] < 128 && p < htmlpage.length())
+			qrznotes += htmlpage[p++];
+	}	
+}
+
+bool HAMCALLget(string& htmlpage)
+{
+	int r, sockfd;
+	if ((r = connect_to_server(HAMCALL_HOST, "http", &sockfd)) != 0) {
+		error_string = r > 0 ? strerror(r) : gai_strerror(r);
+		return false;
+	}
+
+	string url_detail;
+	url_detail =  "GET /call?username=";
+	url_detail += progdefaults.QRZusername;
+	url_detail += "&password=";
+	url_detail += progdefaults.QRZuserpassword;
+	url_detail += "&rawlookup=1&callsign=";
+	url_detail += callsign;
+	url_detail += "&program=fldigi-";
+	url_detail += VERSION;
+	url_detail += "\r\n";
+
+	struct timeval timeout = { 10, 0 }; // timeout = 10 seconds
+	ssize_t nread = read_from_server(sockfd, url_detail, htmlpage, &timeout);
+	close(sockfd);
+	if (nread < 0)
+		error_string = strerror(-nread);
+
+	return nread > 0;
+}
+
+void HAMCALLquery()
+{
+	string htmlpage;
+
+	if (HAMCALLget(htmlpage)) {
+		parse_html(htmlpage);
+		QRZ_disp_result();
+	} else {
+		FL_LOCK();
+		inpNotes->value(error_string);
+		FL_UNLOCK();
+	}
+}
+
+static void *CALLSIGNloop(void *args)
+{
+	SET_THREAD_ID(QRZ_TID);
+
+	for (;;) {
+// see if this thread has been canceled
+		if (QRZ_exit)
+			break;
+		switch (DB_query) {
+			case QRZCD :
+				DB_query = NONE;
+				break;
+			case QRZNET :
+				QRZquery();
+				DB_query = NONE;
+				break;
+			case HAMCALLNET :
+				HAMCALLquery();
+				DB_query = NONE;
+				break;
+			case NONE:
+			default :
+				break;
+		}
+		MilliSleep(100);
+	}
+	return NULL;
+}
+
+void CALLSIGNquery()
 {
 	{
 		FL_LOCK();
@@ -617,126 +854,25 @@ void QRZquery()
 	
 	if (callsign.length() == 0)
 		return;
-	if (progdefaults.QRZ == 0)
-		return;
-	
-	if (progdefaults.QRZ == 2) {
-		if (!qCall)
-			qCall = new QRZ( "callbkc" );
-		if (qCall && qCall->getQRZvalid())
-			QRZ_CD_query();
-	} else
-		QRZ_COM_query();
-}	
-
-void QRZinit(void)
-{
-	QRZ_enabled = false;
-	if (fl_create_thread(QRZ_thread, QRZloop, &qrzdummy) < 0) {
-		fl_message("QRZ init: pthread_create failed");
-		return;
-	} 
-	QRZ_enabled = true;
-}
-
-void QRZclose(void)
-{
-	if (!QRZ_enabled) return;
-// tell the QRZ thread to kill it self
-	QRZ_exit = true;
-// and then wait for it to die
-	fl_join(QRZ_thread);
-	QRZ_enabled = false;
-	QRZ_exit = false;
-}
-
-static void qthappend(string &qth, string &datum) {
-	if (datum.empty()) return;
-	if (!qth.empty()) qth += ", ";
-	qth += datum;
-}
-
-static void QRZAlert()
-{
-// test alert first as QRZ.com requires it be shown
-	if (!qrzalert.empty()) {
-		FL_LOCK();
-		inpNotes->value(qrzalert.c_str());
-		qrzalert="";
-		FL_UNLOCK();
-	} else if (!qrzerror.empty()) {
-		FL_LOCK();
-		inpNotes->value(qrzerror.c_str());
-		qrzerror="";
-		FL_UNLOCK();
-	}
-}
-
-
-static int QRZLogin() {
-	int err=0;
-	if (qrzSessionKey.empty()) {
-		err = getSessionKey();
-		if (!err) err = parseSessionKey();
-	}
-	if (! err) {
-		QRZAlert();
-	}
-	return err;
-}
-
-static void *QRZloop(void *args)
-{
-	SET_THREAD_ID(QRZ_TID);
-
-	for (;;) {
-// see if this thread has been canceled
-		if (QRZ_exit)
+	switch (progdefaults.QRZ) {
+		case 1 :
+			QRZ_COM_query();
 			break;
-		if (QRZ_query) {
-			int err=0;
-			if (qrzSessionKey.empty())
-				err = QRZLogin();
-			if (!err)
-				err = QRZGetXML();
-			if (!err) {
-				if (qrzSessionKey.empty())
-					err = QRZLogin();
-				if (!err)
-					err = QRZGetXML();
-			}
-			if (!err) {
-				parse_xml();
-				if (!qrzalert.empty()) {
-					FL_LOCK();
-					inpNotes->value(qrzalert.c_str());
-					qrzalert="";
-					FL_UNLOCK();
-				} else if (!qrzerror.empty()) {
-					FL_LOCK();
-					inpNotes->value(qrzerror.c_str());
-					qrzerror="";
-					FL_UNLOCK();
-				} else {
-					qrzqth = "";
-					qthappend(qrzqth, qrzaddr1);
-					qthappend(qrzqth, qrzaddr2);
-					qthappend(qrzqth, qrzstate);
-					qthappend(qrzqth, qrzcountry);
-					QRZ_disp_result();
-				}
-			} 
-			if (err) {
-				FL_LOCK();
-				inpNotes->value(error[err]);
-				FL_UNLOCK();
-			}
-			QRZ_query = false;
-		}
-		MilliSleep(100);
-	}
-	return NULL;
-}
+		case 2 :
+			if (!qCall)
+				qCall = new QRZ( "callbkc" );
+			if (qCall && qCall->getQRZvalid())
+				QRZ_CD_query();
+			DB_query = NONE;
+			break;
+		case 3:
+			HAMCALL_COM_query();
+			break;
+		case 0:
+		default :
+			break;
+	}			
+}	
 
 /* ---------------------------------------------------------------------- */
 
