@@ -183,6 +183,10 @@ void QRZ::OpenQRZFiles( const char *fname )
   long fsize;
   char dfname[64];
   char idxname[64];
+  int num1;
+  int num2;
+  num1 = 0;
+  num2 = 0;
 
   if( fname[0] == 0 ) {
     QRZvalid = 0;
@@ -226,8 +230,15 @@ void QRZ::OpenQRZFiles( const char *fname )
   }
   memset( index, 0, idxsize );
 
-  fread( &idxhdr.dataname, 1, 48, idxfile );
-  fread( index, 1, idxsize, idxfile ) ;
+  num1 =  fread( &idxhdr.dataname, 48, 1, idxfile );
+  num2 =  fread( index, idxsize, 1, idxfile );
+ 
+  if (num1 != 1 || num2 != 1) {
+    fclose( idxfile );
+    free( index );
+    QRZvalid = 0;
+    return;
+  }
 
   fflush( stdout );
 
@@ -895,7 +906,7 @@ char * QRZ::CSV_Record()
 {
   static char info[256];
   memset( info, 0, 256 );
-  snprintf( info, 256, "%s,%s,%s,%s,%s,%s,%s,%s,%s",
+  snprintf( info,  sizeof(info) - 1, "%s,%s,%s,%s,%s,%s,%s,%s,%s",
             GetCall(), Qopclass, Qefdate,
             Qlname, Qfname, Qmail_str, Qmail_city, Qmail_st, Qmail_zip );
   return info;
@@ -905,7 +916,7 @@ char *QRZ::Fmt_Record()
 {
   static char info[256];
   memset( info, 0, 256 );
-  sprintf( info, "%s   %s : %s\n%s %s\n%s\n%s, %s  %s\n",
+  snprintf( info, sizeof(info) - 1, "%s   %s : %s\n%s %s\n%s\n%s, %s  %s\n",
            GetCall(), Qopclass, Qefdate,
            Qfname, Qlname,
            Qmail_str,
