@@ -5,6 +5,8 @@
 
 #include "status.h"
 #include "configuration.h"
+#include "fl_digi.h"
+
 #include "waterfall.h"
 
 #include "modem.h"
@@ -22,6 +24,8 @@
 #include "rigsupport.h"
 
 extern void startup_modem(modem *m);
+extern Fl_Double_Window *dlgViewer;
+extern void openViewer();
 
 status progStatus = {
 	(int)MODE_BPSK31,	// trx_mode	lastmode;
@@ -37,7 +41,18 @@ status progStatus = {
 	1,					// int mag;
 	NORMAL,				// WFdisp::WFspeed
 	0,					// reflevel
-	-60					// ampspan
+	-60,				// ampspan
+	40,					// uint	VIEWERnchars
+	50,					// uint	VIEWERxpos
+	50,					// uint	VIEWERypos
+	false,				// bool VIEWERvisible
+	false,				// bool LOGenabled
+	30.0,				// double sldrSquelchValue
+	true,				// bool afconoff
+	true,				// bool sqlonoff
+	1.0,				// double	RcvMixer;
+	1.0,				// double	XmtMixer;
+	false				// bool bLastStateRead;
 };
 
 	
@@ -61,6 +76,21 @@ void status::saveLastState()
 	speed = wf->Speed();
 	reflevel = progdefaults.wfRefLevel;
 	ampspan = progdefaults.wfAmpSpan;
+
+	Fl_Menu_Item *mnulogging = getMenuItem("Log File");
+	if (mnulogging)
+		LOGenabled = mnulogging->value();
+	else
+		LOGenabled = false;
+	
+	if (dlgViewer) {
+		if (dlgViewer->visible()) {
+			VIEWERxpos = dlgViewer->x();
+			VIEWERypos = dlgViewer->y();
+			VIEWERvisible = true;
+		} else
+			VIEWERvisible = false;
+	}
 	
 	if (rigcontrol)
 		if (rigcontrol->visible()) {
@@ -84,11 +114,22 @@ void status::saveLastState()
 	deffile << mag << endl;
 	deffile << speed << endl;
 	deffile << reflevel << endl;
-	deffile << ampspan << endl;	
+	deffile << ampspan << endl;
+	deffile << VIEWERnchars << endl;
+	deffile << VIEWERxpos << endl;
+	deffile << VIEWERypos << endl;
+	deffile << VIEWERvisible << endl;
+	deffile << LOGenabled << endl;
+	deffile << sldrSquelchValue << endl;
+	deffile << afconoff << endl;
+	deffile << sqlonoff << endl;
+	deffile << RcvMixer << endl;
+	deffile << XmtMixer << endl;
+	
 	deffile.close();
 }
 
-void status::initLastState()
+void status::loadLastState()
 {
 	string deffname = HomeDir;
 	deffname.append("fldigi.status");
@@ -108,10 +149,28 @@ void status::initLastState()
 		deffile >> speed;
 		deffile >> reflevel;
 		deffile >> ampspan;
+		deffile >> VIEWERnchars;
+		deffile >> VIEWERxpos;
+		deffile >> VIEWERypos;
+		deffile >> VIEWERvisible;
+		deffile >> LOGenabled;
+		deffile >> sldrSquelchValue;
+		deffile >> afconoff;
+		deffile >> sqlonoff;
+		deffile >> RcvMixer;
+		deffile >> XmtMixer;
 		deffile.close();
 		progdefaults.wfRefLevel = reflevel;
 		progdefaults.wfAmpSpan = ampspan;
+		bLastStateRead = true;
 	}
+}
+
+void status::initLastState()
+{
+	if (!bLastStateRead)
+		loadLastState();
+
 	init_modem((trx_mode)lastmode);
 
 	while (!active_modem) MilliSleep(100);
@@ -123,8 +182,20 @@ void status::initLastState()
 	wf->setAmpSpan();
 	wf->movetocenter();
 	
-//	if (IMAGE_WIDTH == DEFAULT_IMAGE_WIDTH && Hwfall == DEFAULT_HWFALL &&
-//	    HNOM == DEFAULT_HNOM && WNOM == DEFAULT_WNOM) 
+	FL_LOCK_D();
+	if (useCheckButtons) {
+		chk_afconoff->value(afconoff);
+		chk_sqlonoff->value(sqlonoff);
+	} else {
+		btn_afconoff->value(afconoff);
+		btn_sqlonoff->value(sqlonoff);
+	}
+	sldrSquelch->value(sldrSquelchValue);
+	valRcvMixer->value(RcvMixer);
+	valXmtMixer->value(XmtMixer);
+
+	FL_UNLOCK_D();
+
 	{
 		fl_digi_main->resize(mainX, mainY, mainW, mainH);
 
@@ -149,5 +220,13 @@ void status::initLastState()
 		rigcontrol->resize(rigX, rigY, rdW, rdH);
 		rigcontrol->show();
 	}
+	if (VIEWERvisible == true)
+		openViewer();
 
+	if (LOGenabled) {
+		Fl_Menu_Item *mnulogging = getMenuItem("Log File");
+		if (!mnulogging)
+			return;
+		mnulogging->set();
+	}		
 }
