@@ -33,8 +33,9 @@
 
 #include "olivia.h"
 #include "sound.h"
+#include "status.h"
 
-#include "Config.h"
+#include "confdialog.h"
 
 using namespace std;
 
@@ -48,7 +49,7 @@ double olivia::nco(double freq)
 	return cos(preamblephase);
 }
 
-void olivia::tx_init(cSound *sc)
+void olivia::tx_init(SoundBase *sc)
 {
 	unsigned char c;
 
@@ -138,7 +139,7 @@ void olivia::rx_init()
 
 int olivia::unescape(int c)
 {
-	if (olivia_esc == 0)
+	if (progdefaults.olivia8bit == 0)
 		return c;
 
 	if (escape) {
@@ -177,7 +178,7 @@ int olivia::tx_process()
 			/* Replace un-representable characters with a dot */
 			if (c == -1)
                                 c = 0;
-			if (c > (olivia_esc ? 255 : 127))
+			if (c > (progdefaults.olivia8bit ? 255 : 127))
 				c = '.';
 			if (c > 127) {
 				c &= 127;
@@ -243,7 +244,7 @@ int olivia::rx_process(const double *buf, int len)
 	for (i = 0; i < len; i++)
 		rxbuffer[i] = (short int) (buf[i] * 32767.0);
 
-	Rx->SyncThreshold = squelchon ? squelch : 0.0;
+	Rx->SyncThreshold = progStatus.sqlonoff ? progStatus.sldrSquelchValue : 0.0;
 
 	Rx->Process(rxbuffer, len);
 
@@ -254,11 +255,11 @@ int olivia::rx_process(const double *buf, int len)
 	
 	double s2n = 20.0 * log10(snr);
 
-	sprintf(msg1, "s/n %4.1f", s2n);//Rx->SignalToNoiseRatio()); 
+	snprintf(msg1, sizeof(msg1), "s/n %4.1f", s2n);//Rx->SignalToNoiseRatio()); 
 	put_Status1(msg1);
-	sprintf(msg2, "Freq: %+4.1f", Rx->FrequencyOffset());
+	snprintf(msg2, sizeof(msg2), "Freq: %+4.1f", Rx->FrequencyOffset());
 	put_Status2(msg2);
-//	sprintf(msg3, "Tune: %4.1f, Time: %5.3f Hz, Block: %5.3f sec",
+//	snprintf(msg3, sizeof(msg3), "Tune: %4.1f, Time: %5.3f Hz, Block: %5.3f sec",
 //		Rx->TuneMargin(), Rx->TimeOffset(), Rx->BlockPeriod());
 //	put_status(msg3);
 
@@ -309,7 +310,7 @@ void olivia::restart()
 	Rx->Bandwidth = Tx->Bandwidth;
 	Rx->SyncMargin = smargin;
 	Rx->SyncIntegLen = sinteg;
-	Rx->SyncThreshold = squelchon ? squelch : 0.0;
+	Rx->SyncThreshold = progStatus.sqlonoff ? progStatus.sldrSquelchValue : 0.0;
 
 	Rx->SampleRate = 8000.0;//samplerate;
 	Rx->InputSampleRate = samplerate;
@@ -356,6 +357,9 @@ olivia::olivia()
 
 	mode = MODE_OLIVIA;
 //	wfid = new id(this);
+	smargin = progdefaults.oliviasmargin;
+	sinteg = progdefaults.oliviasinteg;
+	lastfreq = 0;
 	init();
 }
 
