@@ -30,10 +30,14 @@
 
 #include <stdlib.h>
 #include <stdio.h>
+#include <iomanip>
 
 #include "psk.h"
 #include "waterfall.h"
 #include "configuration.h"
+#include "status.h"
+#include "viewpsk.h"
+#include "pskeval.h"
 
 extern waterfall *wf;
 
@@ -44,6 +48,10 @@ extern waterfall *wf;
 
 #define DCDOFF  32
 
+// Change the following for DCD low pass filter adjustment
+#define SQLCOEFF 0.01
+#define SQLDECAY 50
+
 //=====================================================================
 
 #define	K		5
@@ -51,8 +59,10 @@ extern waterfall *wf;
 #define	POLY2	0x19
 
 char pskmsg[80];
+viewpsk *pskviewer = (viewpsk *)0;
+pskeval *evalpsk = (pskeval *)0;
 
-void psk::tx_init(cSound *sc)
+void psk::tx_init(SoundBase *sc)
 {
 	scard = sc;
 	phaseacc = 0;
@@ -79,7 +89,10 @@ void psk::rx_init()
 
 void psk::restart()
 {
-//	reverse = false;
+	if (!pskviewer) pskviewer = new viewpsk(mode);
+	else		    pskviewer->restart(mode);
+	if (!evalpsk) evalpsk = new pskeval;
+	evalpsk->setbw(bandwidth);
 }
 
 void psk::init()
@@ -96,12 +109,13 @@ psk::~psk()
 	if (dec) delete dec;
 	if (fir1) delete fir1;
 	if (fir2) delete fir2;
-//	if (wfid) delete wfid;
 }
 
 psk::psk(trx_mode pskmode) : modem()
 {
 	mode = pskmode;
+	
+	twopi = 2.0 * M_PI;
 
 	switch (mode) {
 	case MODE_BPSK31:
@@ -167,6 +181,7 @@ psk::psk(trx_mode pskmode) : modem()
 
 	wsincfilt(fir1c, 1.0 / symbollen, true);	// creates fir1c matched sin(x)/x filter w blackman
 	wsincfilt(fir2c, 1.0 / 16.0, true);			// creates fir2c matched sin(x)/x filter w blackman
+
 //	wsincfilt(fir1c, 1.0 / symbollen, false);	// creates fir1c matched sin(x)/x filter w hamming
 //	wsincfilt(fir2c, 1.0 / 16.0, false);		// creates fir2c matched sin(x)/x filter w hamming
 //	wsincfilt(fir2c, 1.0 / 22.0, false);    	// 1/22 with Hamming window
@@ -180,6 +195,7 @@ psk::psk(trx_mode pskmode) : modem()
 	fir2 = new C_FIR_filter();
 	fir2->init(FIRLEN, 1, fir2c, fir2c);
 
+
 	if (_qpsk) {
 		enc = new encoder(K, POLY1, POLY2);
 		dec = new viterbi(K, POLY1, POLY2);
@@ -194,9 +210,8 @@ psk::psk(trx_mode pskmode) : modem()
 	samplerate = PskSampleRate;
 	fragmentsize = symbollen;
 	bandwidth = samplerate / symbollen;
-//	wfid = new id(this);
-	
-//	pipeptr = 0;
+	snratio = s2n = imdratio = imd = 0;
+
 	if (mailserver && progdefaults.PSKmailSweetSpot)
 		sigsearch = SIGSEARCH;
 	else
@@ -204,6 +219,8 @@ psk::psk(trx_mode pskmode) : modem()
 	for (int i = 0; i < 16; i++)
 		syncbuf[i] = 0.0;
 	E1 = E2 = E3 = 0.0;
+	acquire = 0;
+	
 	init();
 }
 
@@ -288,22 +305,16 @@ int waitcount = 0;
 
 void psk::findsignal()
 {
-	double ftest, sigpwr, noise;
-	int searchBW;
+	int ftest, f1, f2;
 	
-// fast search for peak signal frequency
 	if (sigsearch > 0) {
 		sigsearch--;
-		if (mailserver) { 
-// mail server signal search
-			searchBW = progdefaults.ServerOffset;// - (int)bandwidth;
-			ftest = wf->peakFreq((int)(frequency), searchBW + (int)bandwidth/2);
-			sigpwr = wf->powerDensity(ftest,  bandwidth);
-			noise = wf->powerDensity(ftest + 2 * bandwidth, bandwidth / 2) +
-		    	    wf->powerDensity(ftest - 2 * bandwidth, bandwidth / 2) + 1e-20;
-			if (sigpwr/noise > SNTHRESHOLD) { // larger than the search threshold
+		if (mailserver) { // mail server search algorithm
+			f1 = (int)(frequency - progdefaults.ServerOffset);
+			f2 = (int)(frequency + progdefaults.ServerOffset);
+			if (evalpsk->sigpeak(ftest, f1, f2) > SNTHRESHOLD ) {
 				if (progdefaults.PSKmailSweetSpot) {
-					if (fabs(ftest - progdefaults.PSKsweetspot) < searchBW) {
+					if (fabs(ftest - progdefaults.PSKsweetspot) < progdefaults.ServerOffset) {
 						frequency = ftest;
 						set_freq(frequency);
 						freqerr = 0.0;
@@ -324,45 +335,42 @@ void psk::findsignal()
 					sigsearch = SIGSEARCH;
 				}
 			}
-		} else { 
-// normal signal search
-			searchBW = progdefaults.SearchRange;
-			ftest = wf->peakFreq((int)(frequency), searchBW);
-			sigpwr = wf->powerDensity(ftest,  bandwidth);
-			noise = wf->powerDensity(ftest + 2 * bandwidth / 2, bandwidth / 2) +
-		    	    wf->powerDensity(ftest - 2 * bandwidth / 2, bandwidth / 2) + 1e-20;
-			if (sigpwr/noise > SNTHRESHOLD) { // larger than the detection threshold)
+		} else { // normal signal search algorithm
+			f1 = (int)(frequency - progdefaults.SearchRange/2);
+			f2 = (int)(frequency + progdefaults.SearchRange/2);
+			if (evalpsk->sigpeak(ftest, f1, f2) > pow(10, progdefaults.ACQsn / 10.0) ) {
 				frequency = ftest;
 				set_freq(frequency);
 				freqerr = 0.0;
+				sigsearch = 0;
+				acquire = DCDOFF;
 			}
 		}
-	}		
+	}
 }
 
 void psk::phaseafc()
 {
 	double error;
-	error = (phase - bits * M_PI / 2);
-	if (error < M_PI / 2)
-		error += 2 * M_PI;
-	if (error > M_PI / 2)
-		error -= 2 * M_PI;
-	error *= ((samplerate / (symbollen * 2 * M_PI)/16));
+	error = (phase - bits * M_PI / 2.0);
+	if (error < -M_PI/2.0)
+		error += twopi;
+	if (error > M_PI/2.0)
+		error -= twopi;
+	error *= ((samplerate / twopi) / (16.0 * symbollen));
 	if (fabs(error) < bandwidth) {
-		freqerr = decayavg( freqerr, error, AFCDECAY);
+		freqerr = decayavg( freqerr, error, AFCDECAYSLOW);
 		frequency -= freqerr;
 		set_freq (frequency);
 	}
+	if (acquire) acquire--;
 }
 
 void psk::afc()
 {
-	if (!afcon)
+	if (!progStatus.afconoff)
 		return;
-//	if (sigsearch)
-//		findsignal();
-	else if (dcd == true)
+	if (dcd == true || acquire)
 		phaseafc();
 }
 
@@ -374,7 +382,7 @@ void psk::rx_symbol(complex symbol)
 	prevsymbol = symbol;
 
 	if (phase < 0) 
-		phase += 2 * M_PI;
+		phase += twopi;
 	if (_qpsk) {
 		bits = ((int) (phase / M_PI_2 + 0.5)) & 3;
 		n = 4;
@@ -383,9 +391,11 @@ void psk::rx_symbol(complex symbol)
 		n = 2;
 	}
 // simple low pass filter for quality of signal
-	quality.re = 0.02 * cos(n * phase) + 0.98 * quality.re;
-	quality.im = 0.02 * sin(n * phase) + 0.98 * quality.im;
-
+//	quality.re = 0.02 * cos(n * phase) + 0.98 * quality.re;
+//	quality.im = 0.02 * sin(n * phase) + 0.98 * quality.im;
+	quality.re = decayavg(quality.re, cos(n*phase), SQLDECAY);
+	quality.im = decayavg(quality.im, cos(n*phase), SQLDECAY);
+	
 	metric = 100.0 * quality.norm();
 	
 	dcdshreg = (dcdshreg << 2) | bits;
@@ -393,16 +403,18 @@ void psk::rx_symbol(complex symbol)
 	switch (dcdshreg) {
 	case 0xAAAAAAAA:	/* DCD on by preamble */
 		dcd = true;
+		acquire = 0;
 		quality = complex (1.0, 0.0);
 		break;
 
 	case 0:			/* DCD off by postamble */
 		dcd = false;
+		acquire = 0;
 		quality = complex (0.0, 0.0);
 		break;
 
 	default:
-		if (metric > squelch || squelchon == false)
+		if (metric > progStatus.sldrSquelchValue || progStatus.sqlonoff == false)
 			dcd = true;
 		else 
 			dcd = false;
@@ -437,14 +449,14 @@ void psk::update_syncscope()
 	s2n = 10.0*log10( snratio );
 	display_metric(metric);
 
-	sprintf(msg1, "s/n %2d dB", (int)(floor(s2n))); 
+	snprintf(msg1, sizeof(msg1), "s/n %2d dB", (int)(floor(s2n))); 
     put_Status1(msg1);
 
 	if (imdratio < 1)
 		imd = 10.0*log10( imdratio );
 	else
 		imd = 0.0;
-	sprintf(msg2, "imd %3d dB", (int)(floor(imd))); 
+	snprintf(msg2, sizeof(msg2), "imd %3d dB", (int)(floor(imd))); 
     put_Status2(msg2);
 
 }
@@ -454,9 +466,12 @@ char bitstatus[100];
 int psk::rx_process(const double *buf, int len)
 {
 	double delta;
-	complex z;
+	complex z, z2;//, z3;
 
-	delta = 2.0 * M_PI * frequency / samplerate;
+	if (pskviewer && !bHistory) pskviewer->rx_process(buf, len);
+	if (evalpsk) evalpsk->sigdensity();
+		
+	delta = twopi * frequency / samplerate;
 	
 	signalquality();
 
@@ -466,27 +481,30 @@ int psk::rx_process(const double *buf, int len)
 		buf++;
 		phaseacc += delta;
 		if (phaseacc > M_PI)
-			phaseacc -= 2.0 * M_PI;
+			phaseacc -= twopi;
 // Filter and downsample 
 // by 16 (psk31, qpsk31) 
 // by  8 (psk63, qpsk63)
 // by  4 (psk125, qpsk125)
+// by  2 (psk250, qpsk250)
 // first filter
 		if (fir1->run( z, z )) { // fir1 returns true every Nth sample
 // final filter
-			fir2->run( z, z ); // fir3 returns value on every sample
-			
+			fir2->run( z, z2 ); // fir2 returns value on every sample
+
+//			fir3->run( z, z3);
+//			coreafc(z3);
+						
 			int idx = (int) bitclk;
 			double sum = 0.0;
 			double ampsum = 0.0;
-			syncbuf[idx] = 0.8 * syncbuf[idx] + 0.2 * z.mag();
+			syncbuf[idx] = 0.8 * syncbuf[idx] + 0.2 * z2.mag();
 			
 			for (int i = 0; i < 8; i++) {
 				sum += (syncbuf[i] - syncbuf[i+8]);
 				ampsum += (syncbuf[i] + syncbuf[i+8]);
 			}
 // added correction as per PocketDigi
-// vastly improved performance with synchronous interference !!
 			sum = (ampsum == 0 ? 0 : sum / ampsum);
 			
 			bitclk -= sum / 5.0;
@@ -495,7 +513,7 @@ int psk::rx_process(const double *buf, int len)
 			if (bitclk < 0) bitclk += 16.0;
 			if (bitclk >= 16.0) {
 				bitclk -= 16.0;
-				rx_symbol(z);
+				rx_symbol(z2);
 				update_syncscope();
 				afc();
 			}
