@@ -27,11 +27,13 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 // ----------------------------------------------------------------------------
 
+#include <config.h>
+
 #include "ptt.h"
 #include "configuration.h"
 #include "rigMEM.h"
 #include "rigio.h"
-#ifndef NOHAMLIB
+#if USE_HAMLIB
 	#include "hamlib.h"
 #endif
 
@@ -43,13 +45,12 @@
 // "hamlib" - 1
 // "memmap" - 2
 // "rigcat" - 3
-// "/dev/ttys0" - 4
-// "/dev/ttys1" - 5
+// "tty" - 4 (SPECIFIED by progdefaults.PTTdev)
 
-PTT::PTT(int dev, int mode, bool inverted)
+PTT::PTT(int dev)//, int mode, bool inverted)
 {
 	pttfd = -1;
-	reset_(dev, mode, inverted);
+	reset_(dev);//, mode, inverted);
 }
 
 PTT::~PTT()
@@ -64,18 +65,27 @@ PTT::~PTT()
 	}
 }
 
-void PTT::reset_(int dev, int mode, bool inverted)
+void PTT::reset_(int dev)//, int mode, bool inverted)
 {
 	pttdev = dev;
-	pttinv = inverted;
-	pttmode = mode;
+//	pttinv = inverted;
+//	pttmode = mode;
 
 	if (pttdev < 4) {
-		set(0);
+		set(false);
 		return;
 	}
 
-	pttdevName = progdefaults.PTTdev;
+	if (progdefaults.PTTdev == "COM1")
+		pttdevName = "/dev/ttyS0";
+	else if (progdefaults.PTTdev == "COM2")
+		pttdevName = "/dev/ttyS1";
+	else if (progdefaults.PTTdev == "COM3")
+		pttdevName = "/dev/ttyS2";
+	else if (progdefaults.PTTdev == "COM4")
+		pttdevName = "/dev/ttyS3";
+	else
+		pttdevName = progdefaults.PTTdev;
 	
 	openptt();
 	if (pttfd == -1) {
@@ -88,14 +98,14 @@ void PTT::reset_(int dev, int mode, bool inverted)
 }
 
 
-void PTT::reset(int dev, int mode, bool inverted)
+void PTT::reset(int dev)//, int mode, bool inverted)
 {
 	if (pttfd != -1) {
 		tcsetattr (pttfd, TCSANOW, &oldtio);
 		close(pttfd);
 		pttfd = -1;
 	}
-	reset_(dev, mode, inverted);
+	reset_(dev);//, mode, inverted);
 }
 
 void PTT::set(bool ptt)
@@ -108,7 +118,7 @@ void PTT::set(bool ptt)
 		return;
 
 // Hamlib ptt
-#ifndef NOHAMLIB
+#if USE_HAMLIB
 	if (pttdev == 1) {
 		hamlib_set_ptt(ptt);
 		return;
