@@ -3,6 +3,7 @@
 // to the hamlib library
 //
 // derived from rigclass.cc distributed with hamlib
+#include <config.h>
 
 #include <hamlib/rig.h>
 #include "rigclass.h"
@@ -103,8 +104,10 @@ void Rig::close(void)
 
 void Rig::setFreq(freq_t freq, vfo_t vfo) 
 {
+	int err;
 	for (int i = 0; i < NUMTRIES; i++) {
-		if (rig_set_freq(theRig, vfo, freq) == RIG_OK)
+		err = rig_set_freq(theRig, vfo, freq);
+		if (err == RIG_OK)
 			return;
 	}
 	throw RigException ("setFreq");
@@ -117,6 +120,7 @@ freq_t Rig::getFreq(vfo_t vfo)
 		if ( rig_get_freq(theRig, vfo, &freq) == RIG_OK)
 			return freq;
 	}
+	return 0;
 	throw RigException ("getFreq");
 }
 
@@ -172,6 +176,7 @@ void Rig::getConf(token_t token, char *val)
 {
 	rig_get_conf(theRig, token, val);
 }
+
 void Rig::getConf(const char *name, char *val)
 {
 	rig_get_conf(theRig, tokenLookup(name), val);
