@@ -33,13 +33,14 @@
 #include "throb.h"
 #include "ascii.h"
 #include "configuration.h"
+#include "status.h"
 
 #undef  CLAMP
 #define CLAMP(x,low,high)       (((x)>(high))?(high):(((x)<(low))?(low):(x)))
 
 char throbmsg[80];
 
-void  throb::tx_init(cSound *sc)
+void  throb::tx_init(SoundBase *sc)
 {
 	scard = sc;
 	preamble = 4;
@@ -216,7 +217,7 @@ throb::throb(trx_mode throb_mode) : modem()
 
 	syncfilt = new C_FIR_filter();
 	syncfilt->init(symlen / DOWN_SAMPLE, 1, fp, NULL);
-	delete fp;
+	delete [] fp;
 	
 	snfilter = new Cmovavg(16);
 
@@ -340,7 +341,7 @@ int throb::findtones(complex *word, int &tone1, int &tone2)
 }
 
 void throb::show_char(int c) {
-	if (metric > squelch || squelchon == false)
+	if (metric > progStatus.sldrSquelchValue || progStatus.sqlonoff == false)
 		put_rx_char(c);
 }
 
@@ -426,7 +427,7 @@ void throb::rx(complex in)
 	else
 		decodechar (tone1, tone2);
 
-	if (afcon == true && (metric >= squelch || squelchon == false)) {
+	if (progStatus.afconoff == true && (metric >= progStatus.sldrSquelchValue || progStatus.sqlonoff == false)) {
 		complex z1, z2;
 		double f;
 
@@ -444,7 +445,7 @@ void throb::rx(complex in)
 	rxcntr = rxsymlen;
 	waitsync = 1;
 
-	sprintf(throbmsg, "S/N: %3d dB", (int)(floor(s2n)));
+	snprintf(throbmsg, sizeof(throbmsg), "S/N: %3d dB", (int)(floor(s2n)));
 	put_Status1(throbmsg);
 	display_metric(metric);
 
@@ -480,7 +481,7 @@ void throb::sync(complex in)
 	/* correct sync */
 	rxcntr += (maxpos - rxsymlen / 2) / (num_tones - 1);
 	waitsync = 0;
-	if (metric >= squelch || squelchon == false)
+	if (metric >= progStatus.sldrSquelchValue || progStatus.sqlonoff == false)
 		set_scope(dispbuf, rxsymlen);
 	else {
 		dispbuf[0] = 0.0;
