@@ -3,7 +3,7 @@
 
 #include <config.h>
 
-#include "Config.h"
+#include "confdialog.h"
 #include "modem.h"
 #include "configuration.h"
 
@@ -14,9 +14,16 @@
 modem *cw_modem = 0;
 modem *mfsk8_modem = 0;
 modem *mfsk16_modem = 0;
+modem *mt63_500_modem = 0;
+modem *mt63_1000_modem = 0;
+modem *mt63_2000_modem = 0;
 modem *feld_modem = 0;
+modem *feld_slowmodem = 0;
+modem *feld_x5modem = 0;
+modem *feld_x9modem = 0;
 modem *feld_FMmodem = 0;
 modem *feld_FM105modem = 0;
+modem *feld_80modem = 0;
 modem *feld_CMTmodem = 0;
 modem *psk31_modem = 0;
 modem *psk63_modem = 0;
@@ -57,15 +64,11 @@ modem::modem()
 	bool wfrev = wf->Reverse();
 	bool wfsb = wf->USB();
 	reverse = wfrev ^ !wfsb;
-	afcon = true;
-	squelchon = true;
+	historyON = false;
 }
 
 void modem::init()
 {
-	afcon = progdefaults.afconoff;
-	squelchon = progdefaults.sqlonoff;
-	squelch = progdefaults.sldrSquelchValue;
 	bool wfrev = wf->Reverse();
 	bool wfsb = wf->USB();
 	reverse = wfrev ^ !wfsb;
@@ -90,7 +93,7 @@ void modem::set_freq(double freq)
 	freqerr = 0.0;
 	if (freqlock == false)
 		tx_frequency = frequency;
-	QUEUE(CMP_CB(put_freq, frequency)); //put_freq(frequency);
+	REQ(put_freq, frequency);
 }
 
 void modem::set_freqlock(bool on)
@@ -197,7 +200,7 @@ mbuffer<double, 512 * 2, 2> _mdm_scdbl;
 
 void modem::ModulateXmtr(double *buffer, int len) 
 {
-	scard->write_samples(buffer, len);
+	scard->Write(buffer, len);
 
 	if (!progdefaults.viewXmtSignal)
 		return;
@@ -205,7 +208,7 @@ void modem::ModulateXmtr(double *buffer, int len)
 		_mdm_scdbl[scptr] = buffer[i] * 0.5;
 		scptr++;
 		if (scptr == 512) {
-			QUEUE(CMP_CB(&waterfall::sig_data, wf, _mdm_scdbl.c_array(), 512)); //wf->sig_data(scdata, 512);
+			REQ(&waterfall::sig_data, wf, _mdm_scdbl.c_array(), 512);
 			scptr = 0;
 			_mdm_scdbl.next(); // change buffers
 		}
@@ -214,7 +217,7 @@ void modem::ModulateXmtr(double *buffer, int len)
 
 void modem::ModulateStereo(double *left, double *right, int len)
 {
-	scard->write_stereo(left, right, len);
+	scard->Write_stereo(left, right, len);
 
 	if (!progdefaults.viewXmtSignal)
 		return;
@@ -222,7 +225,7 @@ void modem::ModulateStereo(double *left, double *right, int len)
 		_mdm_scdbl[scptr] = left[i] * 0.5;
 		scptr++;
 		if (scptr == 512) {
-			QUEUE(CMP_CB(&waterfall::sig_data, wf, _mdm_scdbl.c_array(), 512)); //wf->sig_data(scdata, 512);
+			REQ(&waterfall::sig_data, wf, _mdm_scdbl.c_array(), 512);
 			scptr = 0;
 			_mdm_scdbl.next(); // change buffers
 		}
@@ -295,8 +298,8 @@ void modem::wfid_send(long int symbol)
 		wfid_outbuf[i] = 0.0;
 		sym = symbol;
 		for (j = 0; j < NUMCOLS * progdefaults.videowidth; j++) {
-			if (sym & 1 == 1)
-				wfid_outbuf[i] += (msk & 1 == 1 ? -1 : 1 ) * sin(wfid_w[j] * i)* wfid_txpulse[i];
+			if ((sym & 1) == 1)
+				wfid_outbuf[i] += ((msk & 1) == 1 ? -1 : 1 ) * sin(wfid_w[j] * i)* wfid_txpulse[i];
 			sym = sym >> 1;
 			msk = msk >> 1;
 		}
