@@ -35,11 +35,12 @@
 #include "misc.h"
 //#include "modeIO.h"
 #include "configuration.h"
+#include "status.h"
 #include "macros.h"
 
 #include <FL/Fl.H>
 
-#include "mbuffer.h"
+#include "ringbuffer.h"
 #include "qrunner.h"
 
 using namespace std;
@@ -64,14 +65,17 @@ bool		restartOK = false;
 bool		trx_wait = false;
 
 modem		*active_modem = 0;
-cSound 		*scard;
+SoundBase 		*scard;
 
 int			_trx_tune;
-unsigned char ucdata[SCBLOCKSIZE * 4];
-short int	*sidata;
-// Double size of normal read to accept overruns; double buffered because it
-// is QUEUEd and used asynchronously by the GUI thread.
-mbuffer<double, SCBLOCKSIZE * 2, 2> _trx_scdbl;
+
+// Ringbuffer for the audio "history". A pointer into this buffer
+// is also passed to the waterfall signal drawing routines.
+#define NUMMEMBUFS 1024
+ringbuffer<double> trxrb(ceil2(NUMMEMBUFS * SCBLOCKSIZE));
+// Vector used for direct access to the ringbuffer
+ringbuffer<double>::vector_type rbvec[2];
+bool    bHistory = false;
 
 static int dummy = 0;
 static bool trxrunning = false;
@@ -82,7 +86,8 @@ static bool trxrunning = false;
 void trx_trx_receive_loop()
 {
 	int  numread;
-	sidata = (short int *)ucdata;
+	assert(powerof2(SCBLOCKSIZE));
+
 	if (!scard) {
 		MilliSleep(10);
 		return;
@@ -92,24 +97,58 @@ void trx_trx_receive_loop()
 			scard->Open(O_RDONLY, active_modem->get_samplerate());
 		}
 		catch (const SndException& e) {
-			put_status(e.what(), 1);
-			MilliSleep(10);
+			put_status(e.what(), 5);
+			scard->Close();
+#if USE_PORTAUDIO
+			if (e.error() == EBUSY && progdefaults.btnAudioIOis == SND_IDX_PORT) {
+				SoundPort::terminate();
+				SoundPort::initialize();
+			}
+#endif
+			MilliSleep(1000);
 			return;
 		}
 		active_modem->rx_init();
 
 		while (1) {
-			numread = scard->Read(_trx_scdbl, SCBLOCKSIZE);
-			if (numread == -1 || (trx_state != STATE_RX))
+			try {
+				if (trxrb.write_space() == 0) // discard some old data
+					trxrb.read_advance(SCBLOCKSIZE);
+				trxrb.get_wv(rbvec);
+				numread = 0;
+				while (numread < SCBLOCKSIZE)
+					numread += scard->Read(rbvec[0].buf + numread, SCBLOCKSIZE - numread);
+			}
+			catch (const SndException& e) {
+				scard->Close();
+				put_status(e.what(), 5);
+				MilliSleep(10);
+				return;
+			}
+			if (trx_state != STATE_RX)
 				break;
-			if (numread > 0) {
-				QUEUE(CMP_CB(&waterfall::sig_data, wf, _trx_scdbl.c_array(), numread)); //wf->sig_data(_trx_scdbl, numread);
-				active_modem->rx_process(_trx_scdbl, numread);
-				_trx_scdbl.next(); // change buffers
+
+			trxrb.write_advance(numread);
+			REQ(&waterfall::sig_data, wf, rbvec[0].buf, numread);
+
+			if (!bHistory)
+				active_modem->rx_process(rbvec[0].buf, numread);
+			else {
+				bool afc = progStatus.afconoff;
+				progStatus.afconoff = false;
+				QRUNNER_DROP(true);
+				active_modem->HistoryON(true);
+				trxrb.get_rv(rbvec);
+				if (rbvec[0].len)
+					active_modem->rx_process(rbvec[0].buf, rbvec[0].len);
+				if (rbvec[1].len)
+					active_modem->rx_process(rbvec[1].buf, rbvec[1].len);
+				QRUNNER_DROP(false);
+				progStatus.afconoff = afc;
+				bHistory = false;
+				active_modem->HistoryON(false);
 			}
 		}
-		if (!scard->full_duplex())
-			scard->Close();
 	} else
 		MilliSleep(10);
 }
@@ -135,16 +174,24 @@ void trx_trx_transmit_loop()
 		active_modem->tx_init(scard);
 
 		while (trx_state == STATE_TX) {
-			if (active_modem->tx_process() < 0)
-				trx_state = STATE_RX;
+			try {
+				if (active_modem->tx_process() < 0)
+					trx_state = STATE_RX;
+			}
+			catch (const SndException& e) {
+				scard->Close();
+				put_status(e.what(), 5);
+				MilliSleep(10);
+				return;
+			}
 		}
-		if (!scard->full_duplex())
+		if (scard->must_close())
 			scard->Close();
 	} else
 		MilliSleep(10);
 
 	push2talk->set(false);
-	QUEUE_SYNC(CMP_CB(&waterfall::set_XmtRcvBtn, wf, false)); //wf->set_XmtRcvBtn(false);
+	REQ_SYNC(&waterfall::set_XmtRcvBtn, wf, false);
 
 	if (progdefaults.useTimer == true) {
 		trx_start_macro_timer();
@@ -170,23 +217,31 @@ void trx_tune_loop()
 		push2talk->set(true);
 		active_modem->tx_init(scard);
 
-		while (trx_state == STATE_TUNE) {
-			if (_trx_tune == 0) {
-				QUEUE_SYNC(CMP_CB(&waterfall::set_XmtRcvBtn, wf, true)); //wf->set_XmtRcvBtn(true);
-				xmttune::keydown(active_modem->get_txfreq_woffset(), scard);
-				_trx_tune = 1;
-			} else
-				xmttune::tune(active_modem->get_txfreq_woffset(), scard);
+		try {
+			while (trx_state == STATE_TUNE) {
+				if (_trx_tune == 0) {
+					REQ_SYNC(&waterfall::set_XmtRcvBtn, wf, true);
+					xmttune::keydown(active_modem->get_txfreq_woffset(), scard);
+					_trx_tune = 1;
+				} else
+					xmttune::tune(active_modem->get_txfreq_woffset(), scard);
+			}
+			xmttune::keyup(active_modem->get_txfreq_woffset(), scard);
 		}
-		xmttune::keyup(active_modem->get_txfreq_woffset(), scard);
-		if (!scard->full_duplex())
+		catch (const SndException& e) {
+			scard->Close();
+			put_status(e.what(), 5);
+			MilliSleep(10);
+			return;
+		}
+		if (scard->must_close())
 			scard->Close();
 		_trx_tune = 0;
 	} else
 		MilliSleep(10);
 
 	push2talk->set(false);
-	QUEUE_SYNC(CMP_CB(&waterfall::set_XmtRcvBtn, wf, false)); //wf->set_XmtRcvBtn(false);
+	REQ_SYNC(&waterfall::set_XmtRcvBtn, wf, false);
 }
 
 void *trx_loop(void *args)
@@ -230,7 +285,7 @@ void trx_start_modem_loop()
 	active_modem->init();
 	trx_state = STATE_RX;
 	signal_modem_ready();
-	QUEUE(CMP_CB(&waterfall::opmode, wf)); //wf->opmode();
+	REQ(&waterfall::opmode, wf);
 }
 
 void trx_start_modem(modem *m)
@@ -239,28 +294,41 @@ void trx_start_modem(modem *m)
 	trx_state = STATE_NEW_MODEM;
 }
 
-string trx_scdev;
-
 void trx_reset_loop()
 {
 	if (scard)  {
 		delete scard;
 		scard = 0;
 	}
-#if USE_PORTAUDIO
-	if (progdefaults.btnAudioIOis == 1)
-		scard = new cSoundPA(trx_scdev.c_str());
-	else
-		scard = new cSoundOSS(trx_scdev.c_str());
-#else
-	scard = new cSoundOSS(trx_scdev.c_str());
+
+	switch (progdefaults.btnAudioIOis) {
+#if USE_OSS
+	case SND_IDX_OSS:
+		scard = new SoundOSS(scDevice[0].c_str());
+		break;
 #endif
+#if USE_PORTAUDIO
+	case SND_IDX_PORT:
+	    scard = new SoundPort(scDevice[0].c_str(), scDevice[1].c_str());
+		break;
+#endif
+#if USE_PULSEAUDIO
+	case SND_IDX_PULSE:
+		scard = new SoundPulse(scDevice[0].c_str());
+		break;
+#endif
+	case SND_IDX_NULL:
+		scard = new SoundNull;
+		break;
+	default:
+		abort();
+	}
+
 	trx_state = STATE_RX;	
 }
 
-void trx_reset(const char *scdev)
+void trx_reset(void)
 {
-	trx_scdev = scdev;
 	trx_state = STATE_RESTART;
 }
 
@@ -277,7 +345,7 @@ static void macro_timer(void *)
 		btnMacroTimer->hide();
 		FL_UNLOCK();
 	} else {
-		sprintf(timermsg,"Timer: %d", progdefaults.timeout);
+		snprintf(timermsg, sizeof(timermsg), "Timer: %d", progdefaults.timeout);
 		FL_LOCK();
 		btnMacroTimer->label(timermsg);
 		btnMacroTimer->redraw_label();
@@ -289,7 +357,7 @@ static void macro_timer(void *)
 void trx_start_macro_timer()
 {
 	Fl::add_timeout(1.0, macro_timer);
-	sprintf(timermsg,"Timer: %d", progdefaults.timeout);
+	snprintf(timermsg, sizeof(timermsg), "Timer: %d", progdefaults.timeout);
 	FL_LOCK();
 	btnMacroTimer->label(timermsg);
 	btnMacroTimer->redraw_label();
@@ -297,7 +365,7 @@ void trx_start_macro_timer()
 	FL_UNLOCK();
 }
 
-void trx_start(const char *scdev)
+void trx_start(void)
 {
 	if (trxrunning) {
 		std::cout<< "trx already running!\n"; fflush(stdout);
@@ -305,14 +373,29 @@ void trx_start(const char *scdev)
 	}
 	
 	if (scard) delete scard;
-#if USE_PORTAUDIO
-	if (progdefaults.btnAudioIOis == 1)
-		scard = new cSoundPA(scdev);
-	else
-		scard = new cSoundOSS(scdev);
-#else
-	scard = new cSoundOSS(scdev);
+
+	switch (progdefaults.btnAudioIOis) {
+#if USE_OSS
+	case SND_IDX_OSS:
+		scard = new SoundOSS(scDevice[0].c_str());
+		break;
 #endif
+#if USE_PORTAUDIO
+	case SND_IDX_PORT:
+		scard = new SoundPort(scDevice[0].c_str(), scDevice[1].c_str());
+		break;
+#endif
+#if USE_PULSEAUDIO
+	case SND_IDX_PULSE:
+		scard = new SoundPulse(scDevice[0].c_str());
+		break;
+#endif
+	case SND_IDX_NULL:
+		scard = new SoundNull;
+		break;
+	default:
+		abort();
+	}
 
 	trx_state = STATE_RX;
 	_trx_tune = 0;
