@@ -2,7 +2,7 @@
 
 #include "colorbox.h"
 #include "waterfall.h"
-#include "Config.h"
+#include "confdialog.h"
 #include <string>
 #include <FL/Fl_Color_Chooser.H>
 
@@ -44,7 +44,7 @@ void selectColor(int n)
 	btnColor[n]->color( fl_rgb_color( palette[n].R, palette[n].G, palette[n].B ) );
 	btnColor[n]->redraw();
 	wf->setcolors();
-	Palette->redraw();
+	WF_Palette->redraw();
 }
 
 static string palfilename = "";
@@ -62,7 +62,14 @@ void loadPalette()
 	if (!p) return;
 	if ((clrfile = fopen(p, "r")) != NULL) {
 		for (int i = 0; i < 9; i++) {
-			fscanf(clrfile, "%d;%d;%d\n", &r, &g, &b);
+			if (fscanf(clrfile, "%d;%d;%d\n", &r, &g, &b) == EOF) {
+				if (ferror(clrfile))
+					perror("fscanf");
+				else
+					cerr << p << ": unexpected EOF\n";
+				fclose(clrfile);
+				return;
+			}
 			palette[i].R = r;
 			palette[i].G = g;
 			palette[i].B = b;
@@ -75,8 +82,8 @@ void loadPalette()
 		size_t pos = palLabelStr.find_last_of('/');
 		if (pos != string::npos) palLabelStr.erase(0, pos+1);
 		palLabelStr = "Palette: " + palLabelStr;
-		Palette->label(palLabelStr.c_str());
-		Palette->redraw();
+		WF_Palette->label(palLabelStr.c_str());
+		WF_Palette->redraw();
 	}
 }
 
@@ -99,6 +106,6 @@ void savePalette()
 		size_t pos = palLabelStr.find_last_of('/');
 		if (pos != string::npos) palLabelStr.erase(0, pos+1);
 		palLabelStr = "Palette: " + palLabelStr;
-		Palette->label(palLabelStr.c_str());
+		WF_Palette->label(palLabelStr.c_str());
    	}
 }
