@@ -27,35 +27,13 @@
 // ----------------------------------------------------------------------------
 
 #include <config.h>
-
-#include "digiscope.h"
-
-#include "modem.h"
-
 #include <iostream>
 
+#include "digiscope.h"
+#include "modem.h"
+#include "trx.h"
 #include "qrunner.h"
 
-inline double MAX(double m1, double m2) {
-	if (m1 > m2) return m1;
-	return m2;
-}
-
-inline int MAX(int m1, int m2) {
-	if (m1 > m2) return m1;
-	return m2;
-}
-
-inline double MIN(double m1, double m2) {
-	if (m1 < m2) return m1;
-	return m2;
-}
-
-inline int MIN (int m1, int m2) {
-	if (m1 < m2) return m1;
-	return m2;
-}
-
 
 Digiscope::Digiscope (int X, int Y, int W, int H) :
 	Fl_Widget (X, Y, W, H) {
@@ -75,21 +53,17 @@ Digiscope::~Digiscope()
 
 void Digiscope::video(double *data, int len )
 {
+	if (active_modem->HistoryON()) return;
+	
 	if (data == NULL || len == 0)
 		return;
 	
 	FL_LOCK_D();
 	int W = w() - 4;
 	int H = h() - 4;
-// video signal display
-//	if (len < W)
-//		for (int i = 0; i < W; i++) 
-//			vidline[3*i] = vidline[3*i+1] = 
-//			vidline[3*i+2] = (unsigned char)(data[i * W / len]);
-//	else
-		for (int i = 0; i < W; i++) 
-			vidline[3*i] = vidline[3*i+1] = 
-			vidline[3*i+2] = (unsigned char)(data[i * len / W]);
+	for (int i = 0; i < W; i++) 
+		vidline[3*i] = vidline[3*i+1] = 
+		vidline[3*i+2] = (unsigned char)(data[i * len / W]);
 	vidline[3*W/2] = 255;
 	vidline[3*W/2+1] = 0;
 	vidline[3*W/2+2] = 0;
@@ -103,13 +77,15 @@ void Digiscope::video(double *data, int len )
 		memcpy (&vidbuf[3*W*linecnt], vidline, 3*W * sizeof(unsigned char));
 	linecnt++;
 
-	QUEUE(CMP_CB(&Digiscope::redraw, this)); //redraw();
+	REQ_DROP(&Digiscope::redraw, this);
 	FL_UNLOCK_D();
 	FL_AWAKE_D();
 }
 
 void Digiscope::data(double *data, int len, bool scale)
 {
+	if (active_modem->HistoryON()) return;
+	
 	if (data == 0) {
 		memset(_buf, 0, MAX_LEN * sizeof(*_buf));
 		return;
@@ -134,28 +110,32 @@ void Digiscope::data(double *data, int len, bool scale)
 			else
 				_buf[i] = 0.0;
 	}
-	QUEUE(CMP_CB(&Digiscope::redraw, this)); //redraw();
+	REQ_DROP(&Digiscope::redraw, this);
 	FL_UNLOCK_D();
 	FL_AWAKE_D();
 }
 
 void Digiscope::phase(double ph, bool hl)
 {
+	if (active_modem->HistoryON()) return;
+	
 	FL_LOCK_D();
 	_phase = ph;
 	_highlight = hl;
-	QUEUE(CMP_CB(&Digiscope::redraw, this)); //redraw();
+	REQ_DROP(&Digiscope::redraw, this);
 	FL_UNLOCK_D();
 	FL_AWAKE_D();
 }
 
 void Digiscope::rtty(double flo, double fhi, double amp)
 {
+	if (active_modem->HistoryON()) return;
+	
 	FL_LOCK_D();
 	_flo = flo;
 	_fhi = fhi;
 	_amp = amp;
-	QUEUE(CMP_CB(&Digiscope::redraw, this)); //redraw();
+	REQ_DROP(&Digiscope::redraw, this);
 	FL_UNLOCK_D();
 	FL_AWAKE_D();
 }
@@ -176,7 +156,7 @@ void Digiscope::mode(scope_mode md)
 	vidline[3*W/2+2] = 0;
 	for (int i = 0; i < H; i++)
 		memcpy(&vidbuf[3*W*i], vidline, 3*W*sizeof(unsigned char) );
-	QUEUE(CMP_CB(&Digiscope::redraw, this)); //redraw();
+	REQ_DROP(&Digiscope::redraw, this);
 	FL_UNLOCK_D();
 	FL_AWAKE_D();
 }
@@ -298,8 +278,7 @@ void Digiscope::draw_video()
 	fl_draw_image(
 		vidbuf, 
 		x() + 2, y() + 2, 
-		w() - 4, h() - 4);//, 
-//		3, 3* (w() - 4));
+		w() - 4, h() - 4);
 }
 
 void Digiscope::draw()
@@ -328,38 +307,41 @@ void Digiscope::draw()
 
 int Digiscope::handle(int event)
 {
-	if (Fl::event_inside( this )) {
-		if (event == FL_RELEASE) {
-			if (_mode == RTTY || _mode == XHAIRS) {
-				if (_mode == RTTY) {
-					_mode = XHAIRS;
-					return 1;
-				}
-				_mode = RTTY;
-				return 1;
-			}
-			if (_mode == DOMDATA || _mode == DOMWF) {
-				if (_mode == DOMDATA) {
-					_mode = DOMWF;
-					return 1;
-				}
-				_mode = DOMDATA;
-				return 1;
-			}
-			if (_mode == WWV ) {
-				int xpos = Fl::event_x() - x();
-				int ypos = Fl::event_y() - y();
-				int evb = Fl::event_button();
-				if (evb == 1)
-					wwv_modem->set1(xpos,w());//ypos);
-//					std::cout << "#1 " << xpos << ", " << ypos << std::endl; fflush(stdout);
-				if (evb == 3)
-					wwv_modem->set2(xpos,ypos);
-//					std::cout << "#2 " << xpos << ", " << ypos << std::endl; fflush(stdout);
-				return 1;
-			}
+	if (!Fl::event_inside(this))
+		return 0;
+
+	switch (event) {
+	case FL_RELEASE:
+		switch (_mode) {
+		case RTTY:
+			_mode = XHAIRS;
+			break;
+		case XHAIRS:
+			_mode = RTTY;
+			break;
+		case DOMDATA:
+			_mode = DOMWF;
+			break;
+		case DOMWF:
+			_mode = DOMDATA;
+			break;
+		case WWV:
+			event = Fl::event_button();
+			if (event == FL_LEFT_MOUSE)
+				wwv_modem->set1(Fl::event_x() - x(), w());
+			else if (event == FL_RIGHT_MOUSE)
+				wwv_modem->set2(Fl::event_x() - x(), Fl::event_y() - y());
+			break;
+		default:
+			break;
 		}
 		return 1;
+	case FL_MOUSEWHEEL:
+		change_modem_param(FL_CTRL);
+		break;
+	default:
+		break;
 	}
-	return 0;
+
+	return 1;
 }
