@@ -44,6 +44,7 @@
 
 #include "fldigi-config.h"
 #include "configuration.h"
+#include "Viewer.h"
 
 Fl_Mutex	wf_mutex = PTHREAD_MUTEX_INITIALIZER;
 
@@ -66,9 +67,6 @@ static	RGB RGBred		= {254,0,0};
 RGBI	mag2RGBI[256];
 RGB		palette[9];
 
-#define max(a,b) (a)>(b)?(a):(b)
-#define min(a,b) (a)<(b)?(a):(b)
-
 short int *tmp_fft_db;
 
 WFdisp::WFdisp (int x0, int y0, int w0, int h0, char *lbl) :
@@ -178,10 +176,10 @@ void WFdisp::makeMarker() {
 	// clamp marker to image width
 	bw = marker_width;
 	int bw_lower = -bw, bw_upper = +bw;
-	if (bw_lower + carrierfreq+0.5 < 0)
-		bw_lower -= bw_lower + carrierfreq+0.5;
-	if (bw_upper + carrierfreq+0.5 > IMAGE_WIDTH)
-		bw_upper -= bw_upper + carrierfreq+0.5 - IMAGE_WIDTH;
+	if (bw_lower + static_cast<int>(carrierfreq+0.5) < 0)
+            bw_lower -= bw_lower + static_cast<int>(carrierfreq+0.5);
+	if (bw_upper + static_cast<int>(carrierfreq+0.5) > IMAGE_WIDTH)
+            bw_upper -= bw_upper + static_cast<int>(carrierfreq+0.5) - IMAGE_WIDTH;
 	for (int y = 0; y < WFMARKER - 2; y++) {
 		for (int i = bw_lower; i <= bw_upper ; i++) {
 			clrPos = clrM + i + y * IMAGE_WIDTH;
@@ -387,13 +385,14 @@ FL_UNLOCK_D();
 //		FL_AWAKE();
 		cursormoved = false;
 	}
-	if (dispcnt == 0)
+	if (dispcnt == 0) {
 		if (srate == 8000)
 			dispcnt = wfspeed;
 		else if (srate == 11025)
 			dispcnt = wfspeed * 4 / 3;
 		else
 			dispcnt = wfspeed * 2;
+	}
 	--dispcnt;
 }
 
@@ -460,10 +459,10 @@ void WFdisp::sig_data( double *sig, int len ) {
 			dfreq = rfc + active_modem->get_txfreq();
 		else	
 			dfreq = rfc - active_modem->get_txfreq();
-		sprintf(szFrequency, "%-.3f", dfreq / 1000.0);
+		snprintf(szFrequency, sizeof(szFrequency), "%-.3f", dfreq / 1000.0);
 	} else {
 		dfreq = active_modem->get_txfreq();
-		sprintf(szFrequency, "%-.0f", dfreq);
+		snprintf(szFrequency, sizeof(szFrequency), "%-.0f", dfreq);
 	}
 	FL_LOCK_D();
 	inpFreq->value(szFrequency);
@@ -597,7 +596,7 @@ void WFdisp::drawScale() {
 			else
 				fr = (rfc - (rfc %500))/1000.0 + 0.5 - 0.5*i;
 		}
-		sprintf(szFreq,"%7.1f", fr);
+		snprintf(szFreq, sizeof(szFreq), "%7.1f", fr);
 		fw = (int)fl_width(szFreq);
 		if (usb)
 			xchar = (int) ( ( (1000.0/step) * i - fw) / 2.0 - 
@@ -620,31 +619,54 @@ void WFdisp::drawMarker() {
 		step * RGBsize, RGBwidth);
 }
 
+
 void WFdisp::update_waterfall() {
 // transfer the fft history data into the WF image
-	int sig;
 	short int *p1, *p2;
 	RGBI *p3, *p4;
 	p1 = tmp_fft_db + offset;
 	p3 = fft_img;
+	
 	for (int row = 0; row < image_height; row++) {
 		p2 = p1;
 		p4 = p3;
-		for (int col = 0; col < disp_width; col++) {
+		if (progdefaults.WFaveraging) {
 			if (step == 4)
-				sig = max( max ( max ( *p2, *(p2+1) ), *(p2+2) ), *(p2+3) );
+				for (int col = 0; col < disp_width; col++) {
+					*(p4++) = mag2RGBI[ (*p2+ *(p2+1)+ *(p2+2)+ *(p2+3))/4 ];
+					p2 += step;
+				}
 			else if (step == 2)
-				sig = max( *p2, *(p2 + 1) );
+				for (int col = 0; col < disp_width; col++) {
+					*(p4++) = mag2RGBI[ (*p2  + *(p2+1))/2 ];
+					p2 += step;
+				}
 			else 
-				sig = *p2;
-			*p4 = mag2RGBI[ sig ];
-			p2 += step;
-			p4++;
+				for (int col = 0; col < disp_width; col++) {
+					*(p4++) = mag2RGBI[ *p2 ];
+					p2 += step;
+				}
+		} else {
+			if (step == 4)
+				for (int col = 0; col < disp_width; col++) {
+					*(p4++) = mag2RGBI[ MAX( MAX ( MAX ( *p2, *(p2+1) ), *(p2+2) ), *(p2+3) ) ];
+					p2 += step;
+				}
+			else if (step == 2)
+				for (int col = 0; col < disp_width; col++) {
+					*(p4++) = mag2RGBI[ MAX( *p2, *(p2+1) ) ];
+					p2 += step;
+				}
+			else 
+				for (int col = 0; col < disp_width; col++) {
+					*(p4++) = mag2RGBI[ *p2 ];
+					p2 += step;
+				}
 		}
-		
 		p1 += IMAGE_WIDTH;
 		p3 += disp_width;
 	}
+
 	if (progdefaults.UseBWTracks) {
 		RGBI  *pos1 = fft_img + (carrierfreq - offset - bandwidth/2) / step;
 		RGBI  *pos2 = fft_img + (carrierfreq - offset + bandwidth/2) / step;
@@ -733,9 +755,9 @@ void WFdisp::drawspectrum() {
 		if (step == 1)
 			sig = tmp_fft_db[c];
 		else if (step == 2)
-			sig = max(tmp_fft_db[c], tmp_fft_db[c+1]);
+			sig = MAX(tmp_fft_db[c], tmp_fft_db[c+1]);
 		else
-			sig = max( max ( max ( tmp_fft_db[c], tmp_fft_db[c+1] ), tmp_fft_db[c+2] ), tmp_fft_db[c+3]);
+			sig = MAX( MAX ( MAX ( tmp_fft_db[c], tmp_fft_db[c+1] ), tmp_fft_db[c+2] ), tmp_fft_db[c+3]);
 		ynext = h1 * sig / 256;
 		while (ffty < ynext) { fft_sig_img[fftpixel -= IMAGE_WIDTH/step] = graylevel; ffty++;}
 		while (ffty > ynext) { fft_sig_img[fftpixel += IMAGE_WIDTH/step] = graylevel; ffty--;}
@@ -861,8 +883,8 @@ void carrier_cb(Fl_Widget *w, void *v) {
 
 void qsy_cb(Fl_Widget *w, void *v)
 {
-        static vector<struct qrg_mode_t> qsy_stack;
-        struct qrg_mode_t m = { -1, -1, 0 };
+        static vector<qrg_mode_t> qsy_stack;
+        qrg_mode_t m;
 
         if (Fl::event_button() != FL_RIGHT_MOUSE) {
                 // store
@@ -1022,7 +1044,7 @@ void btnRev_cb(Fl_Widget *w, void *v) {
 
 void btnMem_cb(Fl_Widget *, void *menu_event)
 {
-	static std::vector<struct qrg_mode_t> qrg_list;
+	static std::vector<qrg_mode_t> qrg_list;
         enum { SELECT, APPEND, REPLACE, REMOVE, CLEAR };
         int op = SELECT, elem = 0;
 
@@ -1053,14 +1075,12 @@ void btnMem_cb(Fl_Widget *, void *menu_event)
                 }
         }
 
-        struct qrg_mode_t m;
+        qrg_mode_t m;
         switch (op) {
         case SELECT:
                 m = qrg_list[elem];
-                if (active_modem != *mode_info[m.mode].modem) {
+                if (active_modem != *mode_info[m.mode].modem)
                         init_modem_sync(m.mode);
-                        QUEUE_FLUSH();
-                }
                 if (m.rfcarrier && m.rfcarrier != wf->rfcarrier()) {
                         rigCAT_set_qsy(m.rfcarrier, m.carrier);
                         rigMEM_set_qsy(m.rfcarrier, m.carrier);
@@ -1188,7 +1208,9 @@ void waterfall::Carrier(int f)
 }
 
 void waterfall::rfcarrier(long long cf) {
+extern void viewer_redraw();
 	wfdisp->rfcarrier(cf);
+	viewer_redraw();
 }
 	
 long long waterfall::rfcarrier() {
@@ -1214,6 +1236,8 @@ void waterfall::USB(bool b) {
 		return;
 	wfdisp->USB(b);
 	active_modem->set_reverse(reverse);
+extern void viewer_redraw();
+	viewer_redraw();
 }
 	
 bool waterfall::USB() {
@@ -1382,6 +1406,7 @@ int WFdisp::handle(int event)
 	if (trx_state != STATE_RX)
 		return 1;
 	int xpos = Fl::event_x() - x();
+	int eb;
 
 	switch (event) {
 	case FL_MOVE:
@@ -1394,7 +1419,7 @@ int WFdisp::handle(int event)
 		redrawCursor();
 		break;
 	case FL_DRAG: case FL_PUSH:
-		switch (Fl::event_button()) {
+		switch (eb = Fl::event_button()) {
 		case FL_RIGHT_MOUSE:
 			wantcursor = false;
 			if (event == FL_PUSH) {
@@ -1403,18 +1428,30 @@ int WFdisp::handle(int event)
 			}
 			// fall through
 		case FL_LEFT_MOUSE:
+			if (event != FL_DRAG && Fl::event_state() & FL_CTRL) {
+				bHistory = true;
+				if (eb == FL_LEFT_MOUSE) {
+				       restoreFocus();
+				       break;
+				}
+			}
 			newcarrier = cursorFreq(xpos);
 			active_modem->set_freq(newcarrier);
-			active_modem->set_sigsearch(SIGSEARCH);
+			if (!(Fl::event_state() & FL_SHIFT))
+				active_modem->set_sigsearch(SIGSEARCH);
 			redrawCursor();
 			restoreFocus();
 			break;
 		case FL_MIDDLE_MOUSE:
 			if (event == FL_DRAG)
 				break;
-			Fl_Button *b = useCheckButtons ? chk_afconoff : afconoff;
-			b->value(!active_modem->get_afcOnOff());
-			b->do_callback();
+			if (Fl::event_state() & FL_CTRL)
+				viewer_paste_freq(cursorFreq(xpos));
+			else {
+				Fl_Button *b = useCheckButtons ? chk_afconoff : btn_afconoff;
+				b->value(!b->value());
+				b->do_callback();
+			}
 		}
 		break;
 	case FL_RELEASE:
@@ -1422,7 +1459,6 @@ int WFdisp::handle(int event)
 		case FL_RIGHT_MOUSE:
 			tmp_carrier = false;
 			active_modem->set_freq(oldcarrier);
-			active_modem->set_sigsearch(3);
 			redrawCursor();
 			restoreFocus();
 			// fall through
@@ -1433,7 +1469,7 @@ int WFdisp::handle(int event)
 		break;
 
 	case FL_MOUSEWHEEL:
-		handle_mouse_wheel(event);
+		change_modem_param(Fl::event_state());
 		return handle(FL_MOVE);
 		break;
 
@@ -1487,57 +1523,3 @@ int WFdisp::handle(int event)
 
 	return 1;
 }
-
-void WFdisp::handle_mouse_wheel(int event)
-{
-	int d;
-	if ( !((d = Fl::event_dy()) || (d = Fl::event_dx())) )
-		return;
-
-	int state = Fl::event_state();
-	if (state & (FL_META | FL_ALT)) {
-		if (d > 0)
-			active_modem->searchUp();
-		else if (d < 0)
-			active_modem->searchDown();
-		return;
-	}
-	if (!(state & (FL_CTRL | FL_SHIFT)))
-		return; // suggestions?
-
-	extern Fl_Valuator *cntServerOffset, *cntSearchRange,
-			   *sldrHellBW, *sldrCWbandwidth;
-	Fl_Valuator *val = 0;
-	if (state & FL_CTRL) {
-		switch (active_modem->get_mode()) {
-		case MODE_BPSK31: case MODE_QPSK31: case MODE_PSK63: case MODE_QPSK63:
-		case MODE_PSK125: case MODE_QPSK125: case MODE_PSK250: case MODE_QPSK250:
-			val = mailserver ? cntServerOffset : cntSearchRange;
-			break;
-		case MODE_FELDHELL:
-			val = sldrHellBW;
-			break;
-		case MODE_CW:
-			val = sldrCWbandwidth;
-			break;
-		default:
-			return;
-		}
-	}
-	else if (state & FL_SHIFT)
-		val = sldrSquelch;
-
-	val->value(val->clamp(val->increment(val->value(), -d)));
-	val->do_callback();
-	if (val == cntServerOffset || val == cntSearchRange)
-		active_modem->set_sigsearch(SIGSEARCH);
-	else if (val == sldrSquelch) // sldrSquelch gives focus to TextWidget
-		take_focus();
-
-	char msg[60];
-	if (val != sldrSquelch)
-		snprintf(msg, sizeof(msg), "%s = %2.0f Hz", val->label(), val->value());
-	else
-		snprintf(msg, sizeof(msg), "Squelch = %2.0f %%", val->value());
-	put_status(msg, 2);
-}
