@@ -36,6 +36,7 @@
 #include "File_Selector.h"
 
 #include "ascii.h"
+#include "configuration.h"
 #include "qrunner.h"
 
 
@@ -51,8 +52,7 @@ using namespace std;
 /// @param l 
 FTextBase::FTextBase(int x, int y, int w, int h, const char *l)
 	: ReceiveWidget(x, y, w, h, l),
-          wrap(true), wrap_col(80), max_lines(0), scroll_hint(false),
-          adjusted_colours(false)
+          wrap(true), wrap_col(80), max_lines(0), scroll_hint(false)
 {
 	tbuf = new Fl_Text_Buffer;
 	sbuf = new Fl_Text_Buffer;
@@ -66,12 +66,7 @@ FTextBase::FTextBase(int x, int y, int w, int h, const char *l)
 	// Do we want narrower scrollbars? The default width is 16.
 	// scrollbar_width((int)floor(scrollbar_width() * 3.0/4.0));
 
-	// set some defaults
-	set_style(NATTR, FL_SCREEN, 12, FL_FOREGROUND_COLOR);
-	set_style(XMIT, FL_SCREEN, 12, FL_RED, SET_COLOR);
-	set_style(CTRL, FL_SCREEN, 12, FL_DARK_GREEN, SET_COLOR);
-	set_style(SKIP, FL_SCREEN, 12, FL_BLUE, SET_COLOR);
-	set_style(ALTR, FL_SCREEN, 12, FL_DARK_MAGENTA, SET_COLOR);
+	reset_styles(SET_FONT | SET_SIZE | SET_COLOR);
 }
 
 int FTextBase::handle(int event)
@@ -79,9 +74,9 @@ int FTextBase::handle(int event)
         if (event == FL_MOUSEWHEEL && !Fl::event_inside(this))
                 return 1;
 
-        if (!adjusted_colours && event == FL_SHOW) {
+        if (event == FL_SHOW) {
+                reset_styles(SET_COLOR);
                 adjust_colours();
-                adjusted_colours = true;
         }
 
         return ReceiveWidget::handle(event);
@@ -206,19 +201,21 @@ void FTextBase::saveFile(void)
 		tbuf->outputfile(fn, 0, tbuf->length());
 }
 
-/// Returns a character string containing the word at (\a x, \a y) relative to
-/// the widget's \c x() and \c y().
+/// Returns a character string containing the selected text, if any,
+/// or the word at (\a x, \a y) relative to the widget's \c x() and \c y().
 ///
 /// @param x 
 /// @param y 
 ///
-/// @return The word text at (x,y). <b>Must be freed by the caller</b>.
+/// @return The selection, or the word text at (x,y). <b>Must be freed by the caller</b>.
 ///
 char *FTextBase::get_word(int x, int y)
 {
-	int p = xy_to_position(x + this->x(), y + this->y(),
-                               Fl_Text_Display_mod::CURSOR_POS);
-	tbuf->select(word_start(p), word_end(p));
+	if (!tbuf->selected()) {
+		int p = xy_to_position(x + this->x(), y + this->y(),
+				       Fl_Text_Display_mod::CURSOR_POS);
+		tbuf->select(word_start(p), word_end(p));
+	}
 	char *s = tbuf->selection_text();
 	tbuf->unselect();
 
@@ -236,6 +233,7 @@ void FTextBase::show_context_menu(void)
 
 	popx = xpos - x();
 	popy = ypos - y();
+	window()->cursor(FL_CURSOR_DEFAULT);
 	m = context_menu->popup(xpos, ypos, 0, 0, 0);
 	if (!m)
 		return;
@@ -276,8 +274,7 @@ void FTextBase::adjust_colours(void)
         for (int i = 0; i < NATTR; i++) {
                 Fl_Color adj;
 
-                while ((adj = fl_contrast(styles[i].color,
-                                          FL_BACKGROUND2_COLOR)) != styles[i].color) {
+                while ((adj = fl_contrast(styles[i].color, color())) != styles[i].color) {
                         styles[i].color = (adj == FL_WHITE) ?
                                           fl_lighter(styles[i].color) :
                                           fl_darker(styles[i].color);
@@ -285,20 +282,29 @@ void FTextBase::adjust_colours(void)
         }
 }
 
+void FTextBase::reset_styles(int set)
+{
+	set_style(NATTR, FL_SCREEN, 12, FL_FOREGROUND_COLOR, set);
+	set_style(XMIT, FL_SCREEN, 12, FL_RED, set);
+	set_style(CTRL, FL_SCREEN, 12, FL_DARK_GREEN, set);
+	set_style(SKIP, FL_SCREEN, 12, FL_BLUE, set);
+	set_style(ALTR, FL_SCREEN, 12, FL_DARK_MAGENTA, set);
+}
+
 // ----------------------------------------------------------------------------
 
 
 Fl_Menu_Item FTextView::view_menu[] = {
-	{ "@-9$returnarrow &QRZ this call",	0, 0 },
+	{ "@-4>> &Look up call",		0, 0 },
 	{ "@-9-> &Call",			0, 0 },
 	{ "@-9-> &Name",			0, 0 },
 	{ "@-9-> QT&H",				0, 0 },
 	{ "@-9-> &Locator",			0, 0 },
-	{ "@-9-> &RSTin",			0, 0, 0, FL_MENU_DIVIDER },
+	{ "@-9-> &RST(r)",			0, 0, 0, FL_MENU_DIVIDER },
 	{ "Insert divider",			0, 0 },
 	{ "C&lear",				0, 0 },
 	{ "&Copy",				0, 0, 0, FL_MENU_DIVIDER },
-#ifndef NDEBUG
+#if 0 //#ifndef NDEBUG
         { "(debug) &Append file...",		0, 0, 0, FL_MENU_DIVIDER },
 #endif
 	{ "Save to &file...",			0, 0, 0, FL_MENU_DIVIDER },
@@ -372,6 +378,7 @@ int FTextView::handle(int event)
 			view_menu[RX_MENU_WRAP].flags |= FL_MENU_VALUE;
 		else
 			view_menu[RX_MENU_WRAP].flags &= ~FL_MENU_VALUE;
+		context_menu = progdefaults.QRZ ? view_menu : view_menu + 1;
 
 		show_context_menu();
 		return 1;
@@ -396,7 +403,7 @@ int FTextView::handle(int event)
 /// @param c The character
 /// @param attr The attribute (@see enum text_attr_e); RECV if omitted.
 ///
-void FTextView::add(char c, int attr)
+void FTextView::add(unsigned char c, int attr)
 {
 	if (c == '\r')
 		return;
@@ -449,14 +456,15 @@ void FTextView::add(char c, int attr)
 ///
 void FTextView::menu_cb(int val)
 {
-	handle(FL_UNFOCUS);
+	if (progdefaults.QRZ == 0)
+		++val;
 
 	switch (val) {
 		char *s;
 	case RX_MENU_QRZ_THIS:
 		menu_cb(RX_MENU_CALL);
-		extern void QRZquery();
-		QRZquery();
+		extern void CALLSIGNquery();
+		CALLSIGNquery();
 		break;
 	case RX_MENU_CALL:
 		s = get_word(popx, popy);
@@ -557,10 +565,14 @@ void FTextView::change_keybindings(void)
 
 	// walk the keybindings linked list and delete items containing elements
 	// of fdelete
+loop:
 	for (Fl_Text_Editor_mod::Key_Binding *k = key_bindings; k; k = k->next) {
-		for (int i = 0; i < n; i++)
-			if (k->function == fdelete[i])
+		for (int i = 0; i < n; i++) {
+			if (k->function == fdelete[i]) {
 				remove_key_binding(k->key, k->state);
+				goto loop;
+			}
+		}
 	}
 }
 
@@ -673,7 +685,7 @@ void FTextEdit::add(const char *s, int attr)
 /// @param s 
 /// @param attr 
 ///
-void FTextEdit::add(char c, int attr)
+void FTextEdit::add(unsigned char c, int attr)
 {
 	char s[] = { FTEXT_DEF + attr, '\0' };
 	sbuf->replace(insert_position(), insert_position() + 1, s);
@@ -724,10 +736,10 @@ int FTextEdit::nextChar(void)
 	else if (insert_position() <= txpos) // empty buffer or cursor inside transmitted text
 		c = -1;
 	else {
-		if ((c = tbuf->character(txpos))) {
+		if ((c = static_cast<unsigned char>(tbuf->character(txpos)))) {
 			++txpos;
-			QUEUE(CMP_CB(FTextEdit::changed_cb, txpos, 0, 0, 0,
-				     static_cast<const char *>(0), this));
+			REQ(FTextEdit::changed_cb, txpos, 0, 0, -1,
+			    static_cast<const char *>(0), this);
 		}
 	}
 
@@ -744,7 +756,17 @@ int FTextEdit::nextChar(void)
 int FTextEdit::handle_key(int key)
 {
 	switch (key) {
-	case FL_Escape:
+	case FL_Escape: // set stop flag and clear
+	{
+		static time_t t[2] = { 0, 0 };
+		static unsigned char i = 0;
+		if (t[i] == time(&t[!i])) { // two presses in a second: reset modem
+			trx_start_modem(active_modem);
+			t[i = !i] = 0;
+			return 1;
+		}
+		i = !i;
+	}
 		clear();
 		active_modem->set_stopflag(true);
 		return 1;
@@ -832,6 +854,22 @@ int FTextEdit::handle_key(int key)
 		}
 		return 0;
 	}
+// alt - 1 through alt - 4 changes macro sets
+	case '1':
+	case '2':
+	case '3':
+	case '4':
+		if (Fl::event_state() & FL_ALT) {
+			altMacros = key - '1';
+			for (int i = 0; i < 12; i++)
+				btnMacro[i]->label(macros.name[i + (altMacros * NUMMACKEYS)].c_str());
+			static char alt_text[4];
+			snprintf(alt_text, sizeof(alt_text), "%d", altMacros + 1);
+			btnAltMacros->label(alt_text);
+			btnAltMacros->redraw_label();
+			return 1;
+		}
+		break;
 	default:
 		break;
 	}
@@ -842,7 +880,7 @@ int FTextEdit::handle_key(int key)
 
         // read A/M-ddd, where d is a digit, as ascii characters (in base 10)
         // and insert verbatim; e.g. M-001 inserts a <soh>
-        if (Fl::event_state() & (FL_META | FL_ALT) && isdigit(key) &&
+        if (Fl::event_state() & FL_CTRL && isdigit(key) &&
             insert_position() >= txpos)
             return handle_key_ascii(key);
 
@@ -865,10 +903,10 @@ int FTextEdit::handle_key(int key)
 int FTextEdit::handle_key_macro(int key)
 {
 	key -= FL_F + 1;
-	if (key > 9)
+	if (key > 11)
 		return 0;
 
-	key += (altMacros ? 10 : 0);
+	key += altMacros * NUMMACKEYS;
 	if (!(macros.text[key]).empty())
 		macros.execute(key);
 
@@ -909,7 +947,6 @@ int FTextEdit::handle_key_ascii(int key)
 ///
 void FTextEdit::menu_cb(int val)
 {
-	handle(FL_UNFOCUS);
 	switch (val) {
 	case TX_MENU_TX:
 		active_modem->set_stopflag(false);
@@ -973,7 +1010,7 @@ void FTextEdit::changed_cb(int pos, int nins, int ndel, int nsty, const char *dt
 	FTextEdit *e = reinterpret_cast<FTextEdit *>(arg);
 
 	if (nins == 0 && ndel == 0) {
-		if (nsty == 0) { // update transmitted text style
+		if (nsty == -1) { // called by nextChar to update transmitted text style
 			char s[] = { FTEXT_DEF + XMIT, '\0' };
 			e->sbuf->replace(pos - 1, pos, s);
 			e->redisplay_range(pos - 1, pos);
@@ -981,7 +1018,7 @@ void FTextEdit::changed_cb(int pos, int nins, int ndel, int nsty, const char *dt
 		else if (nsty > 0) // restyled, e.g. selected, text
 			return e->buffer_modified_cb(pos, nins, ndel, nsty, dtext,
 						     dynamic_cast<Fl_Text_Editor_mod *>(e));
-
+                // No changes, e.g., a paste with an empty clipboard.
 		return;
 	}
 	else if (nins > 0 && e->sbuf->length() < e->tbuf->length()) {
