@@ -595,7 +595,7 @@ FL_UNLOCK_D();
 FL_AWAKE_D();
 }
 
-void textview::add_( char c, int attribute)
+void textview::add_( unsigned char c, int attribute)
 {
 	if (c == 0x08) {
 		_backspace();
@@ -644,7 +644,7 @@ void textview::add_( char c, int attribute)
 	setScrollbar();
 }
 
-void textview::add( char c, int attribute)
+void textview::add( unsigned char c, int attribute)
 {
 	if (c < ' ' || c == 127) { // we must look this up and insert it as a string
 		unsigned char i = c;
@@ -973,10 +973,10 @@ void TextEdit::clear_sent() {
 
 int TextEdit::handle_fnckey(int key) {
 	int b = key - FL_F - 1;
-	if (b > 9)
+	if (b > 11)
 		return 0;
 	
-	b += (altMacros ? 10 : 0);
+	b += altMacros * NUMMACKEYS;
 	if (!(macros.text[b]).empty())
 		macros.execute(b);
 
@@ -1060,6 +1060,17 @@ int TextEdit::handle_key() {
 		Fl::focus(this);
 		return 1;
 	}
+	if (key == '1' || key == '2' || key == '3' || key == '4')
+		if (Fl::event_state() && FL_ALT) {
+			altMacros = key - '1';
+			for (int i = 0; i < 12; i++)
+				btnMacro[i]->label(macros.name[i + (altMacros * NUMMACKEYS)].c_str());
+			static char alt_text[4];
+			snprintf(alt_text, sizeof(alt_text), "%d", altMacros + 1);
+			btnAltMacros->label(alt_text);
+			btnAltMacros->redraw_label();
+			return 1;
+		}
 	
 	const char *ch = Fl::event_text();
 	addstr(ch);
@@ -1143,7 +1154,7 @@ int TextEdit::nextChar()
 		if (xmtidx == buff.length()) return -1;
 	}
 	FL_LOCK_D();
-	QUEUE(CMP_CB(&TextEdit::update_xmit_text, this, xmtidx));
+	REQ(&TextEdit::update_xmit_text, this, xmtidx);
 	FL_UNLOCK_D();
 //    FL_AWAKE();
 	return (buff[xmtidx++]);
