@@ -25,14 +25,14 @@
 
 #include "analysis.h"
 #include "waterfall.h"
-#include "Config.h"
+#include "confdialog.h"
 #include "configuration.h"
 
 #define anal_BW         4
 
 static char msg1[80];
 
-void anal::tx_init(cSound *sc)
+void anal::tx_init(SoundBase *sc)
 {
 }
 
@@ -157,9 +157,9 @@ int anal::rx_process(const double *buf, int len)
 // filter using second moving average filter & display the result
 				fout_2 = favg->run(fout_1);
 				if (wf->USB())
-					sprintf(msg1, "Freq: %12.2f", wf->rfcarrier() + frequency + fout_2 ); 
+					snprintf(msg1, sizeof(msg1), "Freq: %12.2f", wf->rfcarrier() + frequency + fout_2 ); 
 				else
-					sprintf(msg1, "Freq: %12.2f", wf->rfcarrier() - frequency - fout_2 );
+					snprintf(msg1, sizeof(msg1), "Freq: %12.2f", wf->rfcarrier() - frequency - fout_2 );
 				put_status(msg1);
 				writeFile();
 // reset the display counter & the pipe pointer
